/* Tabellen fr Ein-/Ausgangskorb Betriebsregister
SVN Revisionsinformationen
$Revision: 1051 $
*/ 

DECLARE 
  cnt NUMBER(10);
  vCnt NUMBER(10);
  vIDX_TBS VARCHAR2(50) := NULL; 
  vUI_TBS VARCHAR2(60) := NULL; 

  FUNCTION FieldExists(pTable_name IN VARCHAR2, pColumn_name IN VARCHAR2) RETURN BOOLEAN AS
  BEGIN

    SELECT COUNT(*) INTO vCnt
    FROM user_tab_columns
    WHERE table_name = pTable_name
      AND column_name = pColumn_name;
      
    RETURN vCnt > 0; 
  
  END;

  FUNCTION TableExists(pTable_name IN VARCHAR2) RETURN BOOLEAN AS
  BEGIN

    SELECT COUNT(*) INTO vCnt
    FROM user_tables
    WHERE table_name = pTable_name;
      
    RETURN vCnt > 0; 
  
  END;
  
  PROCEDURE COMMENT_COL(pTab_Col IN VARCHAR2, pComment IN VARCHAR2) AS
  BEGIN
    EXECUTE IMMEDIATE 'COMMENT ON COLUMN ' || pTab_Col || ' IS ''' || pComment || '''';  
  END;

  PROCEDURE COMMENT_TAB(pTab IN VARCHAR2, pComment IN VARCHAR2) AS
  BEGIN
    EXECUTE IMMEDIATE 'COMMENT ON TABLE ' || pTab || ' IS ''' || pComment || '''';  
  END;
  
  FUNCTION IdxExists(pIndex_Name IN VARCHAR2) RETURN BOOLEAN AS
  BEGIN

    SELECT COUNT(*) INTO vCnt
    FROM user_indexes
    WHERE index_name = pIndex_Name;
      
    RETURN vCnt > 0; 
  
  END;  
  
  PROCEDURE CrtIdx(pSQL IN VARCHAR2) AS
  BEGIN
    EXECUTE IMMEDIATE pSQL || vIDX_TBS;
  END;

     
  FUNCTION ChkDefault( pTab IN VARCHAR2, pCol IN VARCHAR2, pDefa IN VARCHAR2) RETURN BOOLEAN AS
  vRes BOOLEAN := FALSE;
  BEGIN
    FOR c1 IN (
      SELECT d1.Data_Default
      FROM user_Tab_Columns d1
      WHERE d1.Table_Name = pTab
      AND d1.column_name = pCol
    ) LOOP
    
      CASE
      WHEN pDefa IS NULL AND c1.data_default IS NULL THEN
        vRes := TRUE;
      WHEN pDefa IS NULL AND c1.data_default = 'NULL' THEN
        vRes := TRUE;
      WHEN pDefa = TRIM( TRAILING FROM c1.data_default) THEN
        vRes := TRUE;
      ELSE vRes := FALSE;
      END CASE;
      
    END LOOP; 
    RETURN vRes;
  END;      
  
  FUNCTION NLS_CHAR(pSQL IN VARCHAR2) RETURN VARCHAR2 AS
  CR CONSTANT VARCHAR2(2 CHAR) := CHR(10);
  CRLF CONSTANT VARCHAR2(2 CHAR) := CHR(13)||CHR(10);
  vP1 PLS_INTEGER := 0; 
  vKlammer1 PLS_INTEGER := 0; 
  vKlammer2 PLS_INTEGER := 0; 
  vKlammer VARCHAR2(50 CHAR);
  vZeile VARCHAR2(4000 CHAR);
  vRes  VARCHAR2(32767 BYTE) ;
  vNTH PLS_INTEGER := 1; 
  BEGIN

    vZeile := pSql;
    LOOP
      
      vP1 := INSTR( UPPER(vZeile), ' VARCHAR2',1, vNTH);
      vNTH := vNTH + 1;
      EXIT WHEN vP1 = 0;
      
      IF vP1 > 0 then
        vKlammer1 := INSTR(vZeile,'(', vP1+9,1);
        vKlammer2 := INSTR(vZeile,')', vKlammer1,1);
        vKlammer := UPPER( SUBSTR(vZeile,vKlammer1+1, vKlammer2-vKlammer1-1) );
       
        CASE
        WHEN vKlammer LIKE '%CHAR%' then
          vKlammer := NULL; -- OK
        WHEN vKlammer LIKE '%BYTE%' then
          vKlammer := REPLACE(vKlammer, 'BYTE', 'CHAR');
         
        ELSE 
          vKlammer := vKlammer || ' CHAR';      
        END CASE;
        if vKlammer IS NOT NULL then
          vZeile := SUBSTR(vZeile, 1, vKlammer1) || vKlammer || SUBSTR(vZeile,vKlammer2);
        END IF;
           
      END IF;  

    END LOOP;
    RETURN vZeile;
  END NLS_CHAR;
  
BEGIN

  EXECUTE IMMEDIATE 'ALTER SESSION SET NLS_LENGTH_SEMANTICS = CHAR';

  -- Index-Tablespace merken
  SELECT tablespace_name INTO vIDX_TBS
  FROM user_indexes
  WHERE index_name = 'PK_D0101_ID';
  
  IF vIDX_TBS IS NOT NULL THEN
    vIDX_TBS := ' TABLESPACE ' || vIDX_TBS;
    vUI_TBS := ' USING INDEX ' || vIDX_TBS;
  END IF;

  SELECT COUNT(*) INTO cnt 
  FROM user_tables
  WHERE table_name = 'AUS_D_PROTOKOLL';
  
  IF cnt = 0 THEN 

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_ADRESSE
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           FREIBEZ VARCHAR2(255) NULL ,
           WECHSEL VARCHAR2(255) NULL ,
           D_KAT_ID VARCHAR2(32) NULL ,
           D_PADR_ID VARCHAR2(32) NULL ,
           D_VERW_ID VARCHAR2(32) NULL ,
           GUELTIG_VON DATE NULL ,
           GUELTIG_BIS DATE NULL ,
           ADR_ID VARCHAR2(20) NULL      ,
           CONSTRAINT PK_AUS_D_ADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');
    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_ADR$D_KAT_ID ON AUS_D_ADRESSE (D_KAT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_ADR$D_VERW_ID ON AUS_D_ADRESSE (D_VERW_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_ADR$D_PADR_ID ON AUS_D_ADRESSE (D_PADR_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON TABLE AUS_D_ADRESSE IS ''Krzel ADR''';

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_BEHOERDE
      ( 
           ID VARCHAR2(255) DEFAULT SYS_GUID() NOT NULL ,
           BEHOERDENKEN VARCHAR2(255) NULL      ,
           CONSTRAINT PK_AUS_D_BEHOERDE$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_BETRIEBSART
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           ART VARCHAR2(255) NULL ,
           BEZ VARCHAR2(255) NULL ,
           CODE VARCHAR2(255) NULL ,
           FACHBEREICH VARCHAR2(255) NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL ,
           GUELTIG_VON DATE NULL ,
           GUELTIG_BIS DATE NULL ,
           REF_ID VARCHAR2(32) NULL      ,
           CONSTRAINT PK_AUS_D_BTSA$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_BTA$D_BTS_ID ON AUS_D_BETRIEBSART (D_BTS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON TABLE AUS_D_BETRIEBSART IS ''Krzel BTA''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_BETRIEBSART.GUELTIG_VON IS ''Anmeldung''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_BETRIEBSART.GUELTIG_BIS IS ''Abmeldung''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_BETRIEBSART.REF_ID IS ''Referenz zu VIS_D010101.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_BETRIEBSSTAETTE
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           ZUSATZBEZ VARCHAR2(255) NULL ,
           GUELTIG_VON DATE NULL ,
           GUELTIG_BIS DATE NULL ,
           REF_ID VARCHAR2(32) NULL      ,
           CONSTRAINT PK_AUS_D_BTS$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'COMMENT ON TABLE AUS_D_BETRIEBSSTAETTE IS ''Krzel BTS''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_BETRIEBSSTAETTE.GUELTIG_VON IS ''Anmeldung''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_BETRIEBSSTAETTE.GUELTIG_BIS IS ''Abmeldung''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_BETRIEBSSTAETTE.REF_ID IS ''Referenz zu VIS_D0101.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_BEZIEHUNG
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           BEZEICHNUNG VARCHAR2(255) NULL ,
           HPERSON VARCHAR2(255) NULL ,
           TYP VARCHAR2(255) NULL      ,
           CONSTRAINT PK_AUS_D_BZH$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_FUNKTION
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           ART VARCHAR2(255) NULL ,
           TYP VARCHAR2(255) NULL ,
           D_PERS_ID VARCHAR2(32) NOT NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL ,
           GUELTIG_VON DATE NULL ,
           GUELTIG_BIS DATE NULL      ,
           CONSTRAINT PK_AUS_D_FKT$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_FKT$D_PERS_ID ON AUS_D_FUNKTION (D_PERS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_FKT$D_BTS_ID ON AUS_D_FUNKTION (D_BTS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON TABLE AUS_D_FUNKTION IS ''Krzel FKT, INH: Betreiber, HV: Hauptverantwortliche (immer natrliche Person NP)''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_FUNKTION.ID IS ''INH: fr Betreiber, HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_FUNKTION.TYP IS ''INH: Betreiber, HV: Hauptverantwortlicher, TYV: weitere Personen''';

    EXECUTE IMMEDIATE NLS_CHAR('
        CREATE  TABLE AUS_D_KATASTER
        ( 
             ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
             FLURNUMMER VARCHAR2(255) NULL ,
             FLURSTUECK VARCHAR2(255) NULL ,
             GEMARKUNG VARCHAR2(255) NULL ,
             X_WERT FLOAT NULL ,
             Y_WERT FLOAT NULL ,
             RECHTSWERT FLOAT NULL ,
             HOCHWERT FLOAT NULL      ,
             CONSTRAINT PK_AUS_D_KAT$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
        )');

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_KOMMUNIKATION
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           KOMDATA VARCHAR2(255) NULL ,
           KOMTYP VARCHAR2(255) NOT NULL      ,
           CONSTRAINT PK_AUS_D_KOM$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_KOMMUNIKATION.KOMTYP IS ''TELEFON, MOBIL, EMAIL, FAX''';

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_PERSON
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           KURZBEZ1 VARCHAR2(50) NULL ,
           KURZBEZ2 VARCHAR2(50) NULL ,
           TYP VARCHAR2(2) NULL ,
           ANREDE VARCHAR2(50) NULL ,
           TITEL VARCHAR2(50) NULL ,
           VORNAME VARCHAR2(128) NULL ,
           NACHNAME VARCHAR2(128) NULL ,
           GEBURTSDATUM DATE NULL ,
           GEBURTSORT VARCHAR2(50) NULL ,
           BEZEICHNUNG VARCHAR2(128) NULL ,
           BEZEICHNUNG2 VARCHAR2(128) NULL ,
           RECHTSFORM VARCHAR2(128) NULL ,
           PERS_ID VARCHAR2(20) NULL ,
           REF_ID VARCHAR2(32) NULL      ,
           CONSTRAINT PK_AUS_D_PERS$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_PERSON.TYP IS ''NP - natrliche Person, JP - juristische Person''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_PERSON.REF_ID IS ''VIS_D0101.ID fr TYP = JP und VIS_D010200 fr TYP = NP''';


    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_POSTADRESSE
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           HAUSNR VARCHAR2(20) NULL ,
           HAUSNRZUSATZ VARCHAR2(20) NULL ,
           ORT VARCHAR2(50) NULL ,
           ORTSTEIL VARCHAR2(50) NULL ,
           POSTFACH VARCHAR2(50) NULL ,
           STAAT VARCHAR2(3) NULL ,
           STRASSE VARCHAR2(50) NULL ,
           PLZ VARCHAR2(10) NULL      ,
           CONSTRAINT PK_AUS_D_PADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_POSTADRESSE.STAAT IS ''GLO_A24.ISO_NR''';

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_PROTOKOLL
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL ,
           D0101_ID VARCHAR2(32) NOT NULL ,
           STATUS NUMBER(10) DEFAULT 0 NOT NULL ,
           INS_DATE DATE DEFAULT SYSDATE NOT NULL ,
           USER_SID NUMBER(10) NOT NULL ,
           LASTMODIFIED DATE NOT NULL ,
           MANDANT NUMBER(10) DEFAULT (-1) NOT NULL ,
           DELETED NUMBER(10) DEFAULT 0 NOT NULL      ,
           CONSTRAINT PK_AUS_D_PROT$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_PROT$D_BTS_ID ON AUS_D_PROTOKOLL (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX IDX_AUS_D_PROT$01 ON AUS_D_PROTOKOLL (D0101_ID,LASTMODIFIED,INS_DATE)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_PROTOKOLL.STATUS IS ''0 - nicht verarbeitet, vor dem Vergleich, 2 - gesendet, zum Vergleich, 3 - nur zum Vergleich, wird nicht und wurde nicht gesendet, 4 - nur zum Vergleich mit dem Eingangskorb''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_PROTOKOLL.DELETED IS ''0 = aktiv, -1 = inaktiv, -2 = gelscht''';

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_REGISTRIERUNG
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           ART VARCHAR2(255) NULL ,
           CODE VARCHAR2(255) NULL ,
           NUMMER VARCHAR2(255) NULL ,
           ZUSATZ VARCHAR2(255) NULL ,
           GUELTIG_VON DATE NULL ,
           GUELTIG_BIS DATE NULL ,
           REF_ID VARCHAR2(32) NULL      ,
           CONSTRAINT PK_AUS_D_REG$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'COMMENT ON TABLE AUS_D_REGISTRIERUNG IS ''Krzel REG''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_REGISTRIERUNG.REF_ID IS ''Referenz zu VIS_D010102.ID, bei ART= BALVI'''' VIS_D0101.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_TAETIGKEIT
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           ART VARCHAR2(255) NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL      ,
           CONSTRAINT PK_AUS_D_TAET$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_TAET$D_BTS_ID ON AUS_D_TAETIGKEIT (D_BTS_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE AUS_D_VERWALTUNG
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           BUNDESLAND VARCHAR2(2) NULL ,
           BEZIRK VARCHAR2(3) NULL ,
           KREIS VARCHAR2(5) NULL ,
           GEMEINDE VARCHAR2(8) NULL ,
           GKZ VARCHAR2(8) NULL ,
           REGIONALSCHLUESSEL VARCHAR2(50) NULL ,
           STAAT VARCHAR2(50) NULL      ,
           CONSTRAINT PK_AUS_D_VERW$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_PERS_FKT
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           HAUPT VARCHAR2(255) NULL ,
           TYP VARCHAR2(255) NULL ,
           D_FKT_ID VARCHAR2(32) NOT NULL ,
           D_PERS_ID VARCHAR2(32) NOT NULL      ,
           CONSTRAINT PK_AUS_R_PERS_FKT$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_PERS_FK$D_FKT_ID ON AUS_R_PERS_FKT (D_FKT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_PERS_FKT$D_PERS_ID ON AUS_R_PERS_FKT (D_PERS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_PERS_FKT.D_FKT_ID IS ''INH: fr Betreiber, HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE  TABLE AUS_R_BTS_ADR
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           TYP VARCHAR2(255) NULL ,
           D_ADR_ID VARCHAR2(32) NOT NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL      ,
           CONSTRAINT PK_AUS_R_BTS_ADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS$D_ADR_ID ON AUS_R_BTS_ADR (D_ADR_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS_ADR$D_BTS ON AUS_R_BTS_ADR (D_BTS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_BTS_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb, BTRA: Abweichende Postanschrift der Betriebssttte,ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden. BTRB: Adresse eines Betriebsteils''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE  TABLE AUS_R_BTS_BEHOER
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           TYP VARCHAR2(255) NULL ,
           D_BEHOERDE_ID VARCHAR2(255) NOT NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL      ,
           CONSTRAINT PK_AUS_R_BTS_BEHOER$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS$D_BEHOERDE_ID ON AUS_R_BTS_BEHOER (D_BEHOERDE_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS_BEHOER$D_BTS_ID ON AUS_R_BTS_BEHOER (D_BTS_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE  TABLE AUS_R_BTS_BZH
      ( 
           D_BZH_ID VARCHAR2(32) NOT NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL 
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS_BZH$_D_BTS_ID ON AUS_R_BTS_BZH (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS_BZH$D_BZH_ID ON AUS_R_BTS_BZH (D_BZH_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE  TABLE AUS_R_BTS_KOM
      ( 
           D_BTS_ID VARCHAR2(32) NOT NULL ,
           D_KOM_ID VARCHAR2(32) NOT NULL 
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS_KOM$D_BTS_ID ON AUS_R_BTS_KOM (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS_KOM$D_KOM_ID ON AUS_R_BTS_KOM (D_KOM_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE  TABLE AUS_R_BTS_REG
      ( 
           D_BTS_ID VARCHAR2(32) NOT NULL ,
           D_REG_ID VARCHAR2(32) NOT NULL 
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS_REG$D_BTS_ID ON AUS_R_BTS_REG (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTS_REG$D_REG_ID ON AUS_R_BTS_REG (D_REG_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE  TABLE AUS_R_FKT_KOM
      ( 
           D_FKT_ID VARCHAR2(32) NOT NULL ,
           D_KOM_ID VARCHAR2(32) NOT NULL 
      )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_FKT_KOM$D_FKT_ID ON AUS_R_FKT_KOM (D_FKT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_FKT_KOM$D_KOM_ID ON AUS_R_FKT_KOM (D_KOM_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_FKT_KOM.D_FKT_ID IS ''INH: fr Betreiber, HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_FKT_REG
  ( 
       D_FKT_ID VARCHAR2(32) NOT NULL ,
       D_REG_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_FKT_REG$D_FKT_ID ON AUS_R_FKT_REG (D_FKT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_FKT_REG$D_REG_ID ON AUS_R_FKT_REG (D_REG_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_FKT_REG.D_FKT_ID IS ''INH: fr Betreiber,HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_FKT_ADR
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       TYP VARCHAR2(255) NULL ,
       D_ADR_ID VARCHAR2(32) NOT NULL ,
       D_FKT_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_AUS_R_FKT_ADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_FKT$D_ADR_ID ON AUS_R_FKT_ADR (D_ADR_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_FKT_ADR$D_FKT_ID ON AUS_R_FKT_ADR (D_FKT_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_FKT_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_FKT_ADR.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_PERS_ADR
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       TYP VARCHAR2(255) NULL ,
       D_ADR_ID VARCHAR2(32) NOT NULL ,
       D_PERS_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_AUS_R_PERS_ADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_PERS$D_ADR_ID ON AUS_R_PERS_ADR (D_ADR_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_PERS_ADR$D_PERS_ID ON AUS_R_PERS_ADR (D_PERS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_PERS_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_PERS_KOM
  ( 
       D_KOM_ID VARCHAR2(32) NOT NULL ,
       D_PERS_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_PERS_KOM$D_KOM_ID ON AUS_R_PERS_KOM (D_KOM_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_PERS_KOM$D_PERS_ID ON AUS_R_PERS_KOM (D_PERS_ID)';
    
    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_PERS_REG
  ( 
       D_PERS_ID VARCHAR2(32) NOT NULL ,
       D_REG_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_PERS_REG$D_PERS_ID ON AUS_R_PERS_REG (D_PERS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_PERS_REG$D_REG_ID ON AUS_R_PERS_REG (D_REG_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_D_USECASE
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       D0101_ID VARCHAR2(32) NOT NULL ,
       USECASE VARCHAR2(20) NOT NULL ,
       MANDANT NUMBER(10) NOT NULL ,
       USER_SID NUMBER(10) NOT NULL ,
       LASTMODIFIED DATE NOT NULL ,
       GUELTIG_VON DATE NOT NULL ,
       GUELTIG_BIS DATE NOT NULL ,
       AEND_ART VARCHAR2(20) NOT NULL ,
       AEND_GRUND VARCHAR2(20) NOT NULL ,
       AEND_BEM VARCHAR2(128) NULL ,
       ALTER_WERT VARCHAR2(2000) NULL ,
       NEUER_WERT VARCHAR2(2000) NULL ,
       D_BTS_ID2 VARCHAR2(32) NULL      ,
       CONSTRAINT PK_AUS_D_UC PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_UC$D_BTS_ID ON AUS_D_USECASE (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_UC$D_BTS_ID2 ON AUS_D_USECASE (D_BTS_ID2)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_USECASE.D_BTS_ID IS ''neue D_BTS_ID''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_USECASE.USECASE IS ''Verweis auf VIS_A0101 SKZ 502 Feld CODE''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_USECASE.D_BTS_ID2 IS ''alte D_BTS_ID zum Vergleich''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_D_GESPERRT
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       D0101_ID VARCHAR2(32) NOT NULL ,
       GESPERRT_JN NUMBER(1) DEFAULT 0 NOT NULL ,
       INS_DATE DATE DEFAULT SYSDATE NOT NULL ,
       MANDANT NUMBER(10) NOT NULL ,
       USER_SID NUMBER(10) NOT NULL ,
       GESPERRT_BIS DATE NOT NULL      ,
       CONSTRAINT PK_AUS_D_GESPERRT PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX IDX_AUS_D_GESPERRT$01 ON AUS_D_GESPERRT (D0101_ID,GESPERRT_BIS,INS_DATE)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_ADRESSE
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       FREIBEZ VARCHAR2(255) NULL ,
       WECHSEL VARCHAR2(255) NULL ,
       D_KAT_ID VARCHAR2(32) NULL ,
       D_PADR_ID VARCHAR2(32) NULL ,
       D_VERW_ID VARCHAR2(32) NULL ,
       GUELTIG_VON DATE NULL ,
       GUELTIG_BIS DATE NULL ,
       ADR_ID VARCHAR2(20) NULL      ,
       CONSTRAINT PK_EIN_D_ADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_ADR$D_KAT_ID ON EIN_D_ADRESSE (D_KAT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_ADR$D_PADR_ID ON EIN_D_ADRESSE (D_PADR_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_ADR$D_VERW_ID ON EIN_D_ADRESSE (D_VERW_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON TABLE EIN_D_ADRESSE IS ''Krzel ADR''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_BEHOERDE
  ( 
       ID VARCHAR2(255) DEFAULT SYS_GUID() NOT NULL ,
       BEHOERDENKEN VARCHAR2(255) NULL      ,
       CONSTRAINT PK_EIN_D_BEHOERDE$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_BETRIEBSART
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       ART VARCHAR2(255) NULL ,
       BEZ VARCHAR2(255) NULL ,
       CODE VARCHAR2(255) NULL ,
       FACHBEREICH VARCHAR2(255) NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       GUELTIG_VON DATE NULL ,
       GUELTIG_BIS DATE NULL ,
       REF_ID VARCHAR2(32) NULL      ,
       CONSTRAINT PK_EIN_D_BTSA$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_BTA$D_BTS_ID ON EIN_D_BETRIEBSART (D_BTS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON TABLE EIN_D_BETRIEBSART IS ''Krzel BTA''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_BETRIEBSART.GUELTIG_VON IS ''Anmeldung''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_BETRIEBSART.GUELTIG_BIS IS ''Abmeldung''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_BETRIEBSART.REF_ID IS ''Referenz zu VIS_D010101.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_BETRIEBSSTAETTE
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       ZUSATZBEZ VARCHAR2(255) NULL ,
       GUELTIG_VON DATE NULL ,
       GUELTIG_BIS DATE NULL ,
       REF_ID VARCHAR2(32) NULL      ,
       CONSTRAINT PK_EIN_D_BTS$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'COMMENT ON TABLE EIN_D_BETRIEBSSTAETTE IS ''Krzel BTS''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_BETRIEBSSTAETTE.GUELTIG_VON IS ''Anmeldung''
  ';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_BETRIEBSSTAETTE.GUELTIG_BIS IS ''Abmeldung''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_BETRIEBSSTAETTE.REF_ID IS ''Referenz zu VIS_D0101.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_BEZIEHUNG
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       BEZEICHNUNG VARCHAR2(255) NULL ,
       HPERSON VARCHAR2(255) NULL ,
       TYP VARCHAR2(255) NULL      ,
       CONSTRAINT PK_EIN_D_BZH$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_FUNKTION
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       ART VARCHAR2(255) NULL ,
       TYP VARCHAR2(255) NULL ,
       D_PERS_ID VARCHAR2(32) NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       GUELTIG_VON DATE NULL ,
       GUELTIG_BIS DATE NULL      ,
       CONSTRAINT PK_EIN_D_FKT$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_FKT$D_BTS_ID ON EIN_D_FUNKTION (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_FKT$D_PERS_ID ON EIN_D_FUNKTION (D_PERS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON TABLE EIN_D_FUNKTION IS ''Krzel FKT
  INH: Betreiber
  HV: Hauptverantwortliche 
         (immer natrliche Person NP)''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_FUNKTION.ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_FUNKTION.TYP IS ''INH: Betreiber
  HV: Hauptverantwortlicher
  TYV: weitere Personen''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_KATASTER
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       FLURNUMMER VARCHAR2(255) NULL ,
       FLURSTUECK VARCHAR2(255) NULL ,
       GEMARKUNG VARCHAR2(255) NULL ,
       X_WERT FLOAT NULL ,
       Y_WERT FLOAT NULL ,
       RECHTSWERT FLOAT NULL ,
       HOCHWERT FLOAT NULL      ,
       CONSTRAINT PK_EIN_D_KAT$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_KOMMUNIKATION
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       KOMDATA VARCHAR2(255) NULL ,
       KOMTYP VARCHAR2(255) NOT NULL      ,
       CONSTRAINT PK_EIN_D_KOM$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_KOMMUNIKATION.KOMTYP IS ''TELEFON, MOBIL, EMAIL, FAX''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_PERSON
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       KURZBEZ1 VARCHAR2(50) NULL ,
       KURZBEZ2 VARCHAR2(50) NULL ,
       TYP VARCHAR2(2) NULL ,
       ANREDE VARCHAR2(50) NULL ,
       TITEL VARCHAR2(50) NULL ,
       VORNAME VARCHAR2(128) NULL ,
       NACHNAME VARCHAR2(128) NULL ,
       GEBURTSDATUM DATE NULL ,
       GEBURTSORT VARCHAR2(50) NULL ,
       BEZEICHNUNG VARCHAR2(128) NULL ,
       BEZEICHNUNG2 VARCHAR2(128) NULL ,
       RECHTSFORM VARCHAR2(128) NULL ,
       PERS_ID VARCHAR2(20) NULL ,
       REF_ID VARCHAR2(32) NULL      ,
       CONSTRAINT PK_EIN_D_PERS$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_PERSON.TYP IS ''NP - natrliche Person, JP - juristische Person''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_PERSON.REF_ID IS ''VIS_D0101.ID fr TYP = JP und VIS_D010200 fr TYP = NP''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_POSTADRESSE
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       HAUSNR VARCHAR2(20) NULL ,
       HAUSNRZUSATZ VARCHAR2(20) NULL ,
       ORT VARCHAR2(50) NULL ,
       ORTSTEIL VARCHAR2(50) NULL ,
       POSTFACH VARCHAR2(50) NULL ,
       STAAT VARCHAR2(3) NULL ,
       STRASSE VARCHAR2(50) NULL ,
       PLZ VARCHAR2(10) NULL      ,
       CONSTRAINT PK_EIN_D_PADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_POSTADRESSE.STAAT IS ''GLO_A24.ISO_NR''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_PROTOKOLL
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       D0101_ID VARCHAR2(32) NOT NULL ,
       STATUS NUMBER(10) DEFAULT 0 NOT NULL ,
       INS_DATE DATE DEFAULT SYSDATE NOT NULL ,
       USER_SID NUMBER(10) NOT NULL ,
       LASTMODIFIED DATE NOT NULL ,
       MANDANT NUMBER(10) DEFAULT (-1) NOT NULL ,
       DELETED NUMBER(10) DEFAULT 0 NOT NULL      ,
       CONSTRAINT PK_EIN_D_PROT$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_PROT$D_BTS_ID ON EIN_D_PROTOKOLL (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX IDX_EIN_D_PROT$01 ON EIN_D_PROTOKOLL (D0101_ID,LASTMODIFIED,INS_DATE)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_PROTOKOLL.STATUS IS ''0 - externe nderungen;Neuanlagen,  1 - Besttigung eigenen nderungen, Neuanlagen''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_PROTOKOLL.DELETED IS ''0 = aktiv, -1 = inaktiv, -2 = gelscht''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_REGISTRIERUNG
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       ART VARCHAR2(255) NULL ,
       CODE VARCHAR2(255) NULL ,
       NUMMER VARCHAR2(255) NULL ,
       ZUSATZ VARCHAR2(255) NULL ,
       GUELTIG_VON DATE NULL ,
       GUELTIG_BIS DATE NULL ,
       REF_ID VARCHAR2(32) NULL      ,
       CONSTRAINT PK_EIN_D_REG$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'COMMENT ON TABLE EIN_D_REGISTRIERUNG IS ''Krzel REG''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_REGISTRIERUNG.REF_ID IS ''Referenz zu VIS_D010102.ID, bei ART= BALVI'''' VIS_D0101.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_TAETIGKEIT
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       ART VARCHAR2(255) NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_EIN_D_TAET$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_TAET$D_BTS_ID ON EIN_D_TAETIGKEIT (D_BTS_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_VERWALTUNG
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       BUNDESLAND VARCHAR2(2) NULL ,
       BEZIRK VARCHAR2(3) NULL ,
       KREIS VARCHAR2(5) NULL ,
       GEMEINDE VARCHAR2(8) NULL ,
       GKZ VARCHAR2(8) NULL ,
       REGIONALSCHLUESSEL VARCHAR2(50) NULL ,
       STAAT VARCHAR2(50) NULL      ,
       CONSTRAINT PK_EIN_D_VERW$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_PERS_FKT
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       HAUPT VARCHAR2(255) NULL ,
       TYP VARCHAR2(255) NULL ,
       D_FKT_ID VARCHAR2(32) NOT NULL ,
       D_PERS_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_EIN_R_PERS_FKT$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_PERS_FK$D_FKT_ID ON EIN_R_PERS_FKT (D_FKT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_PERS_FKT$D_PERS_ID ON EIN_R_PERS_FKT (D_PERS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_PERS_FKT.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_BTS_ADR
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       TYP VARCHAR2(255) NULL ,
       D_ADR_ID VARCHAR2(32) NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_EIN_R_BTS_ADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_ADR$D_BTS ON EIN_R_BTS_ADR (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS$D_ADR_ID ON EIN_R_BTS_ADR (D_ADR_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_BTS_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_BTS_BEHOER
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       TYP VARCHAR2(255) NULL ,
       D_BEHOERDE_ID VARCHAR2(255) NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_EIN_R_BTS_BEHOER$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_BEHOER$D_BTS_ID ON EIN_R_BTS_BEHOER (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS$D_BEHOERDE_ID ON EIN_R_BTS_BEHOER (D_BEHOERDE_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_BTS_BZH
  ( 
       D_BZH_ID VARCHAR2(32) NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_BZH$_D_BTS_ID ON EIN_R_BTS_BZH (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_BZH$D_BZH_ID ON EIN_R_BTS_BZH (D_BZH_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_BTS_KOM
  ( 
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       D_KOM_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_KOM$D_BTS_ID ON EIN_R_BTS_KOM (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_KOM$D_KOM_ID ON EIN_R_BTS_KOM (D_KOM_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_BTS_REG
  ( 
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       D_REG_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_REG$D_BTS_ID ON EIN_R_BTS_REG (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_REG$D_REG_ID ON EIN_R_BTS_REG (D_REG_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_FKT_KOM
  ( 
       D_FKT_ID VARCHAR2(32) NOT NULL ,
       D_KOM_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_FKT_KOM$D_FKT_ID ON EIN_R_FKT_KOM (D_FKT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_FKT_KOM$D_KOM_ID ON EIN_R_FKT_KOM (D_KOM_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_FKT_KOM.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_FKT_REG
  ( 
       D_FKT_ID VARCHAR2(32) NOT NULL ,
       D_REG_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_FKT_REG$D_FKT_ID ON EIN_R_FKT_REG (D_FKT_ID)
  ';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_FKT_REG$D_REG_ID ON EIN_R_FKT_REG (D_REG_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_FKT_REG.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_FKT_ADR
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       TYP VARCHAR2(255) NULL ,
       D_ADR_ID VARCHAR2(32) NOT NULL ,
       D_FKT_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_EIN_R_FKT_ADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_FKT_ADR$D_FKT_ID ON EIN_R_FKT_ADR (D_FKT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_FKT$D_ADR_ID ON EIN_R_FKT_ADR (D_ADR_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_FKT_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_FKT_ADR.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_PERS_ADR
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       TYP VARCHAR2(255) NULL ,
       D_ADR_ID VARCHAR2(32) NOT NULL ,
       D_PERS_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_EIN_R_PERS_ADR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_PERS_ADR$D_PERS_ID ON EIN_R_PERS_ADR (D_PERS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_PERS$D_ADR_ID ON EIN_R_PERS_ADR (D_ADR_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_PERS_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_PERS_KOM
  ( 
       D_KOM_ID VARCHAR2(32) NOT NULL ,
       D_PERS_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_PERS_KOM$D_KOM_ID ON EIN_R_PERS_KOM (D_KOM_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_PERS_KOM$D_PERS_ID ON EIN_R_PERS_KOM (D_PERS_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_PERS_REG
  ( 
       D_PERS_ID VARCHAR2(32) NOT NULL ,
       D_REG_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_PERS_REG$D_PERS_ID ON EIN_R_PERS_REG (D_PERS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_PERS_REG$D_REG_ID ON EIN_R_PERS_REG (D_REG_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_USECASE
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       D0101_ID VARCHAR2(32) NOT NULL ,
       USECASE VARCHAR2(20) NOT NULL ,
       MANDANT NUMBER(10) NOT NULL ,
       USER_NAME VARCHAR2(128) NULL ,
       USER_SID NUMBER(10) NULL ,
       LASTMODIFIED DATE NOT NULL ,
       GUELTIG_VON DATE NOT NULL ,
       GUELTIG_BIS DATE NOT NULL ,
       AEND_ART VARCHAR2(20) NOT NULL ,
       AEND_GRUND VARCHAR2(20) NOT NULL ,
       AEND_BEM VARCHAR2(128) NULL ,
       ALTER_WERT VARCHAR2(2000) NULL ,
       NEUER_WERT VARCHAR2(2000) NULL ,
       D_BTS_ID2 VARCHAR2(32) NULL ,
       ERROR_MESSAGE CLOB NULL ,
       INS_DATE DATE DEFAULT SYSDATE NOT NULL ,
       INS_USER NUMBER(10) DEFAULT (-1) NOT NULL ,
       DELETED NUMBER(10) DEFAULT 0 NOT NULL ,
       DEl_USER NUMBER(10) DEFAULT (-1) NOT NULL ,
       DEL_DATE DATE NULL ,
       FB VARCHAR2(32) DEFAULT ''%'' NOT NULL ,
       AUS_D_USECASE_ID VARCHAR2(32) NULL      ,
       CONSTRAINT PK_EIN_D_UC PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_UC$D_BTS_ID ON EIN_D_USECASE (D_BTS_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_UC$D_BTS_ID2 ON EIN_D_USECASE (D_BTS_ID2)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_USECASE.D_BTS_ID IS ''neue D_BTS_ID''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_USECASE.USECASE IS ''Verweis auf VIS_A0101 SKZ 502 Feld CODE''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_USECASE.USER_NAME IS ''Ersteller des Usecase, S50.bez wenn USER_SID zugeordnet sonst den externen Namen''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_USECASE.USER_SID IS ''Ersteller des Usecase (S50.SID)''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_USECASE.D_BTS_ID2 IS ''alte D_BTS_ID zum Vergleich''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_USECASE.DELETED IS ''-1 : besttigter Usecase''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_USECASE.AUS_D_USECASE_ID IS ''ID aus Ausgangskorb wenn aus iP gesendet''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_GESPERRT
  ( 
       ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
       D0101_ID VARCHAR2(32) NOT NULL ,
       GESPERRT_JN NUMBER(1) DEFAULT 0 NOT NULL ,
       INS_DATE DATE DEFAULT SYSDATE NOT NULL ,
       MANDANT NUMBER(10) NOT NULL ,
       USER_SID NUMBER(10) NOT NULL ,
       GESPERRT_BIS DATE NOT NULL      ,
       CONSTRAINT PK_EIN_D_GESPERRT PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX IDX_EIN_D_GESPERRT$01 ON EIN_D_GESPERRT (D0101_ID,GESPERRT_BIS,INS_DATE)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_D_ABTEILUNG
  ( 
       ID VARCHAR2(32) NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       ABTEILUNGSART VARCHAR2(128) NULL ,
       GUELTIG_VON DATE NULL ,
       GUELTIG_BIS DATE NULL ,
       NUMMER VARCHAR2(64) NULL ,
       BEZ VARCHAR2(128) NULL ,
       REF_ID VARCHAR2(32) NULL      ,
       CONSTRAINT PK_AUS_D_ABTEILUNG PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_D_ABT$BTS_ID ON AUS_D_ABTEILUNG (D_BTS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON TABLE AUS_D_ABTEILUNG IS ''Krzel ABT''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_ABTEILUNG.ABTEILUNGSART IS ''A0101_47.BEZ''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_ABTEILUNG.NUMMER IS ''D0103.ABT_NUMMER''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_ABTEILUNG.REF_ID IS ''Referenz zu VIS_D0103.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_BTA_ABT
  ( 
       D_ABT_ID VARCHAR2(32) NOT NULL ,
       D_BTA_ID VARCHAR2(32) NOT NULL ,
       REF_ID VARCHAR2(32) NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTA_ABT$D_ABT_ID ON AUS_R_BTA_ABT (D_ABT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_BTA_ABT$D_BTA_ID ON AUS_R_BTA_ABT (D_BTA_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_BTA_ABT.REF_ID IS ''Referenz zu VIS_D010301.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_ABT_ADR
  ( 
       D_ADR_ID VARCHAR2(32) NOT NULL ,
       D_ABT_ID VARCHAR2(32) NOT NULL ,
       TYP VARCHAR2(10) DEFAULT ''BTRB'' NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_ABT_ADR$D_ADR_ID ON AUS_R_ABT_ADR (D_ADR_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_ABT_ADR$D_ABT_ID ON AUS_R_ABT_ADR (D_ABT_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_D_ABTEILUNG
  ( 
       ID VARCHAR2(32) NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       ABTEILUNGSART VARCHAR2(128) NULL ,
       GUELTIG_VON DATE NULL ,
       GUELTIG_BIS DATE NULL ,
       NUMMER VARCHAR2(64) NULL ,
       BEZ VARCHAR2(128) NULL ,
       REF_ID VARCHAR2(32) NULL      ,
       CONSTRAINT PK_EIN_D_ABTEILUNG PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_D_ABT$BTS_ID ON EIN_D_ABTEILUNG (D_BTS_ID)';

   EXECUTE IMMEDIATE 'COMMENT ON TABLE EIN_D_ABTEILUNG IS ''Krzel ABT''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_ABTEILUNG.ABTEILUNGSART IS ''A0101_47.BEZ''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_ABTEILUNG.NUMMER IS ''D0103.ABT_NUMMER''';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_ABTEILUNG.REF_ID IS ''Referenz zu VIS_D0103.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_BTA_ABT
  ( 
       D_ABT_ID VARCHAR2(32) NOT NULL ,
       D_BTA_ID VARCHAR2(32) NOT NULL ,
       REF_ID VARCHAR2(32) NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTA_ABT$D_ABT_ID ON EIN_R_BTA_ABT (D_ABT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTA_ABT$D_BTA_ID ON EIN_R_BTA_ABT (D_BTA_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_BTA_ABT.REF_ID IS ''Referenz zu VIS_D010301.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_ABT_ADR
  ( 
       D_ADR_ID VARCHAR2(32) NOT NULL ,
       D_ABT_ID VARCHAR2(32) NOT NULL ,
       TYP VARCHAR2(10) DEFAULT ''BTRB'' NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_ABT_ADR$D_ABT_ID ON EIN_R_ABT_ADR (D_ABT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_ABT_ADR$D_ADR_ID ON EIN_R_ABT_ADR (D_ADR_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE AUS_R_ABT_REG
  ( 
       D_ABT_ID VARCHAR2(32) NOT NULL ,
       D_REG_ID VARCHAR2(32) NOT NULL 
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_ABT_REG$D_ABT_ID ON AUS_R_ABT_REG (D_ABT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_AUS_R_ABT_REG$D_REG_ID ON AUS_R_ABT_REG (D_REG_ID)';

    EXECUTE IMMEDIATE NLS_CHAR('CREATE TABLE EIN_R_ABT_REG
  ( 
       D_ABT_ID VARCHAR2(32) NOT NULL ,
       D_REG_ID VARCHAR2(32) NOT NULL      ,
       CONSTRAINT PK_EIN_R_ABT_REG PRIMARY KEY (D_ABT_ID,D_REG_ID) NOT DEFERRABLE Initially IMMEDIATE
  )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_ABT_REG$D_ABT_ID ON EIN_R_ABT_REG (D_ABT_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_ABT_REG$D_REG_ID ON EIN_R_ABT_REG (D_REG_ID)';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_ADRESSE ADD
  (
       CONSTRAINT AUS_D_KAT$D_ADR$KAT_ID FOREIGN KEY
       ( D_KAT_ID )
       REFERENCES AUS_D_KATASTER
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_ADRESSE ADD
  (
       CONSTRAINT AUS_D_VERW$D_ADR$VERW_ID FOREIGN KEY
       ( D_VERW_ID )
       REFERENCES AUS_D_VERWALTUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_ADRESSE ADD
  (
       CONSTRAINT AUS_D_PADR$D_ADR$PADR_ID FOREIGN KEY
       ( D_PADR_ID )
       REFERENCES AUS_D_POSTADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_BETRIEBSART ADD
  (
       CONSTRAINT AUS_D_BTS$D_BTSA$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_FUNKTION ADD
  (
       CONSTRAINT AUS_D_PERS$D_FKT$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES AUS_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_FUNKTION ADD
  (
       CONSTRAINT AUS_D_BTS$D_FKT$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_PROTOKOLL ADD
  (
       CONSTRAINT AUS_D_BTS$D_PROT$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_TAETIGKEIT ADD
  (
       CONSTRAINT AUS_D_BTS$D_TAET$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_PERS_FKT ADD
  (
       CONSTRAINT AUS_D_FKT$R_PERS_FKT$FKT_ID FOREIGN KEY
       ( D_FKT_ID )
       REFERENCES AUS_D_FUNKTION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_PERS_FKT ADD
  (
       CONSTRAINT AUS_D_PERS$R_PERS_FKT$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES AUS_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_ADR ADD
  (
       CONSTRAINT AUS_D_ADR$R_BTS_ADR$ADR_ID FOREIGN KEY
       ( D_ADR_ID )
       REFERENCES AUS_D_ADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_ADR ADD
  (
       CONSTRAINT AUS_D_BTS$R_BTS_ADR$D_BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_BEHOER ADD
  (
       CONSTRAINT AUS_D_BEHOER$R_BTS_BEH$BEH_ID FOREIGN KEY
       ( D_BEHOERDE_ID )
       REFERENCES AUS_D_BEHOERDE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_BEHOER ADD
  (
       CONSTRAINT AUS_D_BTS$R_BTS_BEHOER$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_BZH ADD
  (
       CONSTRAINT AUS_D_BTS$R_BTS_BZH$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_BZH ADD
  (
       CONSTRAINT AUS_D_BZH$R_BTS_BZH$BZH_ID FOREIGN KEY
       ( D_BZH_ID )
       REFERENCES AUS_D_BEZIEHUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_KOM ADD
  (
       CONSTRAINT AUS_D_BTS$R_BTS_KOM$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_KOM ADD
  (
       CONSTRAINT AUS_D_KOM$R_BTS_KOM$KOM_ID FOREIGN KEY
       ( D_KOM_ID )
       REFERENCES AUS_D_KOMMUNIKATION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_REG ADD
  (
       CONSTRAINT AUS_D_BTS$R_BTS_REG$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTS_REG ADD
  (
       CONSTRAINT AUS_D_REG$R_BTS_REG$REG_ID FOREIGN KEY
       ( D_REG_ID )
       REFERENCES AUS_D_REGISTRIERUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_FKT_KOM ADD
  (
       CONSTRAINT AUS_D_FKT$R_FKT_KOM$FKT_ID FOREIGN KEY
       ( D_FKT_ID )
       REFERENCES AUS_D_FUNKTION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_FKT_KOM ADD
  (
       CONSTRAINT AUS_D_KOM$R_FKT_KOM$KOM_ID FOREIGN KEY
       ( D_KOM_ID )
       REFERENCES AUS_D_KOMMUNIKATION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_FKT_REG ADD
  (
       CONSTRAINT AUS_D_FKT$R_FKT_REG$FKT_ID FOREIGN KEY
       ( D_FKT_ID )
       REFERENCES AUS_D_FUNKTION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_FKT_REG ADD
  (
       CONSTRAINT AUS_D_REG$R_FKT_REG$REG_ID FOREIGN KEY
       ( D_REG_ID )
       REFERENCES AUS_D_REGISTRIERUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_FKT_ADR ADD
  (
       CONSTRAINT AUS_D_ADR$R_FKT_ADR$ADR_ID FOREIGN KEY
       ( D_ADR_ID )
       REFERENCES AUS_D_ADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_FKT_ADR ADD
  (
       CONSTRAINT AUS_D_FKT$R_FKT_ADR$FKT_ID FOREIGN KEY
       ( D_FKT_ID )
       REFERENCES AUS_D_FUNKTION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_PERS_ADR ADD
  (
       CONSTRAINT AUS_D_ADR$R_PERS_ADR$ADR_ID FOREIGN KEY
       ( D_ADR_ID )
       REFERENCES AUS_D_ADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_PERS_ADR ADD
  (
       CONSTRAINT AUS_D_PERS$R_PERS_ADR$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES AUS_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_PERS_KOM ADD
  (
       CONSTRAINT AUS_D_KOM$R_PERS_KOM$KOM_ID FOREIGN KEY
       ( D_KOM_ID )
       REFERENCES AUS_D_KOMMUNIKATION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_PERS_KOM ADD
  (
       CONSTRAINT AUS_D_PERS$R_PERS_KOM$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES AUS_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_PERS_REG ADD
  (
       CONSTRAINT AUS_D_PERS$R_PERS_REG$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES AUS_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_PERS_REG ADD
  (
       CONSTRAINT AUS_D_REG$R_PERS_REG$REG_ID FOREIGN KEY
       ( D_REG_ID )
       REFERENCES AUS_D_REGISTRIERUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_USECASE ADD
  (
       CONSTRAINT AUS_D_BTS$D_UC$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_USECASE ADD
  (
       CONSTRAINT AUS_D_BTS$D_UC$BTS_ID2 FOREIGN KEY
       ( D_BTS_ID2 )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_ADRESSE ADD
  (
       CONSTRAINT EIN_D_KAT$D_ADR$KAT_ID FOREIGN KEY
       ( D_KAT_ID )
       REFERENCES EIN_D_KATASTER
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_ADRESSE ADD
  (
       CONSTRAINT EIN_D_PADR$D_ADR$PADR_ID FOREIGN KEY
       ( D_PADR_ID )
       REFERENCES EIN_D_POSTADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_ADRESSE ADD
  (
       CONSTRAINT EIN_D_VERW$D_ADR$VERW_ID FOREIGN KEY
       ( D_VERW_ID )
       REFERENCES EIN_D_VERWALTUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_BETRIEBSART ADD
  (
       CONSTRAINT EIN_D_BTS$D_BTSA$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_FUNKTION ADD
  (
       CONSTRAINT EIN_D_BTS$D_FKT$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_FUNKTION ADD
  (
       CONSTRAINT EIN_D_PERS$D_FKT$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES EIN_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_PROTOKOLL ADD
  (
       CONSTRAINT EIN_D_BTS$D_PROT$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_TAETIGKEIT ADD
  (
       CONSTRAINT EIN_D_BTS$D_TAET$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_PERS_FKT ADD
  (
       CONSTRAINT EIN_D_FKT$R_PERS_FKT$FKT_ID FOREIGN KEY
       ( D_FKT_ID )
       REFERENCES EIN_D_FUNKTION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_PERS_FKT ADD
  (
       CONSTRAINT EIN_D_PERS$R_PERS_FKT$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES EIN_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_ADR ADD
  (
       CONSTRAINT EIN_D_ADR$R_BTS_ADR$ADR_ID FOREIGN KEY
       ( D_ADR_ID )
       REFERENCES EIN_D_ADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_ADR ADD
  (
       CONSTRAINT EIN_D_BTS$R_BTS_ADR$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_BEHOER ADD
  (
       CONSTRAINT EIN_D_BEHOER$R_BTS_BEH$BEH_ID FOREIGN KEY
       ( D_BEHOERDE_ID )
       REFERENCES EIN_D_BEHOERDE
       ( ID )
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_BEHOER ADD
  (
       CONSTRAINT EIN_D_BTS$R_BTS_BEHOER$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_BZH ADD
  (
       CONSTRAINT EIN_D_BTS$R_BTS_BZH$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_BZH ADD
  (
       CONSTRAINT EIN_D_BZH$R_BTS_BZH$BZH_ID FOREIGN KEY
       ( D_BZH_ID )
       REFERENCES EIN_D_BEZIEHUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_KOM ADD
  (
       CONSTRAINT EIN_D_BTS$R_BTS_KOM$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_KOM ADD
  (
       CONSTRAINT EIN_D_KOM$R_BTS_KOM$KOM_ID FOREIGN KEY
       ( D_KOM_ID )
       REFERENCES EIN_D_KOMMUNIKATION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_REG ADD
  (
       CONSTRAINT EIN_D_BTS$R_BTS_REG$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTS_REG ADD
  (
       CONSTRAINT EIN_D_REG$R_BTS_REG$REG_ID FOREIGN KEY
       ( D_REG_ID )
       REFERENCES EIN_D_REGISTRIERUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_FKT_KOM ADD
  (
       CONSTRAINT EIN_D_FKT$R_FKT_KOM$FKT_ID FOREIGN KEY
       ( D_FKT_ID )
       REFERENCES EIN_D_FUNKTION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_FKT_KOM ADD
  (
       CONSTRAINT EIN_D_KOM$R_FKT_KOM$KOM_ID FOREIGN KEY
       ( D_KOM_ID )
       REFERENCES EIN_D_KOMMUNIKATION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_FKT_REG ADD
  (
       CONSTRAINT EIN_D_FKT$R_FKT_REG$FKT_ID FOREIGN KEY
       ( D_FKT_ID )
       REFERENCES EIN_D_FUNKTION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_FKT_REG ADD
  (
       CONSTRAINT EIN_D_REG$R_FKT_REG$REG_ID FOREIGN KEY
       ( D_REG_ID )
       REFERENCES EIN_D_REGISTRIERUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_FKT_ADR ADD
  (
       CONSTRAINT EIN_D_ADR$R_FKT_ADR$ADR_ID FOREIGN KEY
       ( D_ADR_ID )
       REFERENCES EIN_D_ADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_FKT_ADR ADD
  (
       CONSTRAINT EIN_D_FKT$R_FKT_ADR$FKT_ID FOREIGN KEY
       ( D_FKT_ID )
       REFERENCES EIN_D_FUNKTION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_PERS_ADR ADD
  (
       CONSTRAINT EIN_D_ADR$R_PERS_ADR$ADR_ID FOREIGN KEY
       ( D_ADR_ID )
       REFERENCES EIN_D_ADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_PERS_ADR ADD
  (
       CONSTRAINT EIN_D_PERS$R_PERS_ADR$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES EIN_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_PERS_KOM ADD
  (
       CONSTRAINT EIN_D_KOM$R_PERS_KOM$KOM_ID FOREIGN KEY
       ( D_KOM_ID )
       REFERENCES EIN_D_KOMMUNIKATION
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_PERS_KOM ADD
  (
       CONSTRAINT EIN_D_PERS$R_PERS_KOM$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES EIN_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_PERS_REG ADD
  (
       CONSTRAINT EIN_D_PERS$R_PERS_REG$PERS_ID FOREIGN KEY
       ( D_PERS_ID )
       REFERENCES EIN_D_PERSON
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_PERS_REG ADD
  (
       CONSTRAINT EIN_D_REG$R_PERS_REG$REG_ID FOREIGN KEY
       ( D_REG_ID )
       REFERENCES EIN_D_REGISTRIERUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_USECASE ADD
  (
       CONSTRAINT EIN_D_BTS$D_UC$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_USECASE ADD
  (
       CONSTRAINT EIN_D_BTS$D_UC$BTS_ID2 FOREIGN KEY
       ( D_BTS_ID2 )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_ABTEILUNG ADD
  (
       CONSTRAINT AUS_D_BTS$D_ABT$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTA_ABT ADD
  (
       CONSTRAINT AUS_D_ABT$R_BTA_ABT$ABT_ID FOREIGN KEY
       ( D_ABT_ID )
       REFERENCES AUS_D_ABTEILUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_BTA_ABT ADD
  (
       CONSTRAINT AUS_D_BTA$R_BTA_ABT$BTA_ID FOREIGN KEY
       ( D_BTA_ID )
       REFERENCES AUS_D_BETRIEBSART
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_ABT_ADR ADD
  (
       CONSTRAINT AUS_R_ADR$R_ABT_ADR$ADR_ID FOREIGN KEY
       ( D_ADR_ID )
       REFERENCES AUS_D_ADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_ABT_ADR ADD
  (
       CONSTRAINT AUS_R_ABT$R_ABT_ADR$ABT_ID FOREIGN KEY
       ( D_ABT_ID )
       REFERENCES AUS_D_ABTEILUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
  )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_ABTEILUNG ADD
    (
       CONSTRAINT EIN_D_BTS$D_ABT$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES EIN_D_BETRIEBSSTAETTE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTA_ABT ADD
    (
       CONSTRAINT EIN_D_BTA$R_BTA_ABT$BTA_ID FOREIGN KEY
       ( D_BTA_ID )
       REFERENCES EIN_D_BETRIEBSART
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_BTA_ABT ADD
    (
       CONSTRAINT EIN_D_ABT$R_BTA_ABT$ABT_ID FOREIGN KEY
       ( D_ABT_ID )
       REFERENCES EIN_D_ABTEILUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_ABT_ADR ADD
    (
       CONSTRAINT EIN_R_ADR$R_ABT_ADR$ADR_ID FOREIGN KEY
       ( D_ADR_ID )
       REFERENCES EIN_D_ADRESSE
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_ABT_ADR ADD
    (
       CONSTRAINT EIN_R_ABT$R_ABT_ADR$ABT_ID FOREIGN KEY
       ( D_ABT_ID )
       REFERENCES EIN_D_ABTEILUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_ABT_REG ADD
    (
       CONSTRAINT AUS_D_ABT$R_ABT_REG$ABT_ID FOREIGN KEY
       ( D_ABT_ID )
       REFERENCES AUS_D_ABTEILUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE 'ALTER TABLE AUS_R_ABT_REG ADD
    (
       CONSTRAINT AUS_D_REG$R_ABT_REG$REG_ID FOREIGN KEY
       ( D_REG_ID )
       REFERENCES AUS_D_REGISTRIERUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_ABT_REG ADD
    (
       CONSTRAINT EIN_D_REG$R_ABT_REG$REG_ID FOREIGN KEY
       ( D_REG_ID )
       REFERENCES EIN_D_REGISTRIERUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE 'ALTER TABLE EIN_R_ABT_REG ADD
    (
       CONSTRAINT EIN_D_ABT$R_ABT_REG$ABT_ID FOREIGN KEY
       ( D_ABT_ID )
       REFERENCES EIN_D_ABTEILUNG
       ( ID )
       ON DELETE CASCADE
       NOT DEFERRABLE Initially IMMEDIATE
    )';

  END IF;

  -- 14.06.2011
  SELECT COUNT(*) INTO cnt 
  FROM user_tab_columns
  WHERE table_name = 'AUS_D_BETRIEBSART'
    AND column_name = 'SCOPE';
  
  IF cnt = 0 THEN
  
    EXECUTE IMMEDIATE '
      ALTER TABLE AUS_D_BETRIEBSART
      MODIFY FACHBEREICH DEFAULT ''NOT_VALID''';

    EXECUTE IMMEDIATE '
      ALTER TABLE AUS_D_BETRIEBSART ADD
      (
           SCOPE VARCHAR2(32 CHAR) DEFAULT ''NOT_VALID''  NULL 
      )';

    EXECUTE IMMEDIATE '
      ALTER TABLE AUS_D_PERSON
      MODIFY PERS_ID DEFAULT ''0''';

    EXECUTE IMMEDIATE '
      ALTER TABLE AUS_D_VERWALTUNG
      MODIFY REGIONALSCHLUESSEL DEFAULT ''0000000''';

    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_BETRIEBSART ADD
      (
           SCOPE VARCHAR2(32 CHAR) DEFAULT ''NOT_VALID''  NULL 
      )';

    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_PERSON
      MODIFY PERS_ID DEFAULT ''0''';

    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_VERWALTUNG
      MODIFY REGIONALSCHLUESSEL DEFAULT ''0000000''';

  END IF; -- 14.06.2011

	-- 04.07.2011	
  SELECT COUNT(*) INTO cnt 
  FROM user_tab_columns
  WHERE table_name = 'AUS_D_USECASE'
    AND column_name = 'REF_ID';
  
  IF cnt = 0 THEN
  
    EXECUTE IMMEDIATE '
      ALTER TABLE AUS_D_USECASE
      ADD ( REF_ID VARCHAR2(32 CHAR) NULL)';
      
    EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_USECASE.REF_ID IS ''optional Referenz auf einen Datensatz im Ausgangskorb (z.B. AUS_D_BETRIEBSART.ID, AUS_D_ABTEILUNG.ID)''';    
	
	END IF; -- 04.07.2011   

  -- 28.09.2011
  SELECT COUNT(*) INTO cnt 
  FROM user_tables
  WHERE table_name = 'EIN_R_BTS_UC';
  
  IF cnt = 0 THEN  
  
    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE EIN_R_BTS_UC
    ( 
         D_UC_ID VARCHAR2(32) NOT NULL ,
         D_BTS_ID VARCHAR2(32) NOT NULL 
    )');

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_UC$D_UC_ID ON EIN_R_BTS_UC (D_UC_ID)';

    EXECUTE IMMEDIATE 'CREATE INDEX FK_EIN_R_BTS_UC$D_BTS_ID ON EIN_R_BTS_UC (D_BTS_ID)';

    EXECUTE IMMEDIATE 'COMMENT ON TABLE EIN_R_BTS_UC IS ''Dublettenbetriebe bei Besttigung ANL_MIN''';

    EXECUTE IMMEDIATE '
    ALTER TABLE EIN_R_BTS_UC ADD
    (
         CONSTRAINT Relation_295 FOREIGN KEY
         ( D_UC_ID )
         REFERENCES EIN_D_USECASE
         ( ID )
         ON DELETE CASCADE
         NOT DEFERRABLE Initially IMMEDIATE
    )';

    EXECUTE IMMEDIATE '
    ALTER TABLE EIN_R_BTS_UC ADD
    (
         CONSTRAINT Relation_297 FOREIGN KEY
         ( D_BTS_ID )
         REFERENCES EIN_D_BETRIEBSSTAETTE
         ( ID )
         ON DELETE CASCADE
         NOT DEFERRABLE Initially IMMEDIATE
    )';
  
  END IF;


	-- 25.10.2011
  FOR c1 IN (
    SELECT table_name, column_name
    FROM user_tab_columns
    WHERE table_name = 'EIN_D_USECASE'
      AND column_name = 'GUELTIG_BIS'
      AND NULLABLE = 'N'
  ) LOOP   

    EXECUTE IMMEDIATE( 'ALTER TABLE ' || c1.table_name || ' MODIFY ' || c1.column_name || ' NULL');
    
  END LOOP;

	FOR c1 IN (
    SELECT table_name, constraint_name
    FROM user_constraints
    WHERE constraint_name IN( 'RELATION_295', 'RELATION_297')
      AND table_name = 'EIN_R_BTS_UC'
  ) LOOP
    
    EXECUTE IMMEDIATE 'ALTER TABLE ' || c1.table_name || ' DROP CONSTRAINT ' || c1.constraint_name;    

  END LOOP;

  SELECT COUNT(*) INTO cnt
  FROM user_constraints
  WHERE table_name = 'EIN_R_BTS_UC'
    AND constraint_name = 'EIN_D_UC$R_BTS_UC$UC_ID';
    
  IF cnt = 0 THEN
    
    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_R_BTS_UC ADD
      (
           CONSTRAINT EIN_D_UC$R_BTS_UC$UC_ID FOREIGN KEY
           ( D_UC_ID )
           REFERENCES EIN_D_USECASE
           ( ID )
           ON DELETE CASCADE
           NOT DEFERRABLE Initially IMMEDIATE
      )';
    
  END IF;      
  
  SELECT COUNT(*) INTO cnt
  FROM user_constraints
  WHERE table_name = 'EIN_R_BTS_UC'
    AND constraint_name = 'EIN_D_BTS$R_BTS_UC$BTS_ID';
    
  IF cnt = 0 THEN
    
    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_R_BTS_UC ADD
      (
           CONSTRAINT EIN_D_BTS$R_BTS_UC$BTS_ID FOREIGN KEY
           ( D_BTS_ID )
           REFERENCES EIN_D_BETRIEBSSTAETTE
           ( ID )
           ON DELETE CASCADE
           NOT DEFERRABLE Initially IMMEDIATE
      )';
    
  END IF;

  -- 27.10.2011
  SELECT COUNT(*) INTO cnt
  FROM user_tab_columns
  WHERE table_name = 'AUS_D_BETRIEBSART'
    AND column_name = 'GEWERBSMAESSIG';
    
  IF cnt = 0 THEN
    
    EXECUTE IMMEDIATE '  
      ALTER TABLE AUS_D_BETRIEBSART ADD
      ( 
        GEWERBSMAESSIG NUMBER(10) DEFAULT 0  NOT NULL 
      )';

  END IF;
  
  SELECT COUNT(*) INTO cnt
  FROM user_tab_columns
  WHERE table_name = 'EIN_D_BETRIEBSART'
    AND column_name = 'GEWERBSMAESSIG';
    
  IF cnt = 0 THEN
    
    EXECUTE IMMEDIATE '          
      ALTER TABLE EIN_D_BETRIEBSART ADD
      (
           GEWERBSMAESSIG NUMBER(10) DEFAULT 0  NOT NULL 
      )';

  END IF;
     
  -- 12.12.2011
  SELECT COUNT(*) INTO cnt
  FROM user_tab_columns
  WHERE table_name = 'AUS_D_PROTOKOLL'
    AND column_name = 'INS_DATE'
    AND data_type = 'DATE';
  
  IF cnt = 1 THEN
    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_PROTOKOLL MODIFY INS_DATE TIMESTAMP DEFAULT SYSTIMESTAMP';
  END IF;  

  EXECUTE IMMEDIATE '
    INSERT INTO EIN_D_BETRIEBSSTAETTE (ID, ZUSATZBEZ, GUELTIG_VON, GUELTIG_BIS, REF_ID)
    SELECT ''-1'', ''Erstbefllung'', NULL, NULL, NULL
    FROM DUAL
    WHERE NOT EXISTS( SELECT 1 FROM EIN_D_BETRIEBSSTAETTE WHERE ID = ''-1'') ';  
  
  SELECT COUNT(*) INTO cnt
  FROM user_tab_columns
  WHERE table_name = 'EIN_D_USECASE'
    AND column_name = 'ZB';
  
  IF cnt = 0 THEN
    EXECUTE IMMEDIATE '  
      ALTER TABLE EIN_D_USECASE ADD
      (
           ZB VARCHAR2(5 CHAR) DEFAULT ''%''  NOT NULL 
      )';
  END IF;
  
	-- 20.12.2012
  SELECT COUNT(*) INTO cnt
  FROM user_indexes
  WHERE index_name = 'IDX_AUS_D_REG$NUMMER';
  
  IF cnt = 0 THEN
    EXECUTE IMMEDIATE 'CREATE INDEX IDX_AUS_D_REG$NUMMER ON AUS_D_REGISTRIERUNG (NUMMER)';
  END IF;  
	

	-- 02.07.2012
  -- AUS_D_USECASE.GUELTIG_BIS NULL
  SELECT COUNT(*) INTO cnt
  FROM user_tab_columns
  WHERE table_name = 'AUS_D_USECASE'
    AND column_name = 'GUELTIG_BIS'
    AND nullable = 'N';

  IF cnt = 1 THEN
    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_USECASE MODIFY GUELTIG_BIS NULL';  
  END IF;

  -- AUS_D_USECASE.GUELTIG_VON NULL
  SELECT COUNT(*) INTO cnt
  FROM user_tab_columns
  WHERE table_name = 'AUS_D_USECASE'
    AND column_name = 'GUELTIG_VON'
    AND nullable = 'N';
  
  IF cnt = 1 THEN
    EXECUTE IMMEDIATE 'ALTER TABLE AUS_D_USECASE MODIFY GUELTIG_VON NULL';  
  END IF;

  -- EIN_D_USECASE.GUELTIG_VON NULL
  SELECT COUNT(*) INTO cnt
  FROM user_tab_columns
  WHERE table_name = 'EIN_D_USECASE'
    AND column_name = 'GUELTIG_VON'
    AND nullable = 'N';
  
  IF cnt = 1 THEN
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_USECASE MODIFY GUELTIG_VON NULL';  
  END IF;

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_USECASE.AEND_ART IS ''0 - ndern, 1 : Korrektur''';

  -- 12.10.2012
  IF NOT FieldExists('EIN_D_ADRESSE', 'ART') THEN
    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_ADRESSE ADD
      (
           ART    VARCHAR2(10 CHAR) DEFAULT ''STRASSE''  NULL,
           ZUSATZ VARCHAR2(255 CHAR) NULL 
      )';
  END IF;

  IF NOT TableExists('EIN_D_FACHBEREICHE') THEN 
    EXECUTE IMMEDIATE NLS_CHAR(' 
      CREATE  TABLE EIN_D_FACHBEREICHE
      ( 
           ID VARCHAR2(32) DEFAULT SYS_GUID() NOT NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL ,
           CODE VARCHAR2(128) NOT NULL ,
           A0101_06_SID NUMBER(10) NULL ,
           GUELTIG_VON DATE NULL ,
           GUELTIG_BIS DATE NULL ,
           REF_ID VARCHAR2(32) NULL      ,
           CONSTRAINT PK_EIN_D_FB$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE
      )');
      
    EXECUTE IMMEDIATE '     
      CREATE INDEX FK_EIN_D_FB$D_BTS_ID ON EIN_D_FACHBEREICHE (D_BTS_ID)';
      
    EXECUTE IMMEDIATE ' 
      COMMENT ON TABLE EIN_D_FACHBEREICHE IS ''Fachbereiche''';
    
    EXECUTE IMMEDIATE ' 
      COMMENT ON COLUMN EIN_D_FACHBEREICHE.CODE IS ''A0101_47.BEZ''';
    
    EXECUTE IMMEDIATE ' 
      COMMENT ON COLUMN EIN_D_FACHBEREICHE.REF_ID IS ''Referenz zu VIS_D010104.ID''';

    EXECUTE IMMEDIATE NLS_CHAR('
      ALTER TABLE EIN_D_FACHBEREICHE ADD
      (
           CONSTRAINT D_BTS$D_FB$D_BTS_ID FOREIGN KEY
           ( D_BTS_ID )
           REFERENCES EIN_D_BETRIEBSSTAETTE
           ( ID )
           NOT DEFERRABLE Initially IMMEDIATE
      )');
  
  END IF;
  
  IF NOT FieldExists('EIN_D_PERSON', 'VORSATZ_NACHNAME') THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_PERSON ADD
      (
           VORSATZ_NACHNAME VARCHAR2(20 CHAR) NULL ,
           NACHSATZ_NACHNAME VARCHAR2(20 CHAR) NULL ,
           A0101_03_SID NUMBER(10) NULL  )';
  END IF;  
  
  IF NOT FieldExists('EIN_D_POSTADRESSE', 'GLO_A24_SID') THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_POSTADRESSE ADD
      ( GLO_A24_SID NUMBER(10) NULL  )';

  END IF;  

  IF NOT FieldExists('EIN_D_PROTOKOLL', 'PARAMETER') THEN

    EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_PROTOKOLL.STATUS IS ''0 - externe nderungen/Neuanlagen,  1 - Besttigung eigenen nderungen/Neuanlagen, 2 - Besttigung ANL_MIN als Dublette, 10 - Ablehnung, 20 - Betrieb als Dublette''';

    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_PROTOKOLL ADD
      (
           PARAMETER CLOB NULL, 
           QUELLE VARCHAR2(30 CHAR) NULL 
      )';      
  END IF;
  
   
  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_D_PROTOKOLL.STATUS IS ''0 - nicht verarbeitet, vor dem Vergleich, 2 - gesendet, zum Vergleich, 3 - nur zum Vergleich, wird nicht und wurde nicht gesendet, 4 - nur zum Vergleich mit dem Eingangskorb, 5 - neuer Betrieb ohne Dublettenabgleich senden''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_BTS_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_FKT_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_FKT_ADR.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_FKT_KOM.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_FKT_REG.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_PERS_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN AUS_R_PERS_FKT.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_ADRESSE.ART IS ''Adressart: STRASSE / POSTFACH''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_FUNKTION.ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_FUNKTION.TYP IS ''INH: Betreiber fr NRW sonst "Betreiber"
  HV: Hauptverantwortlicher
  TYV: weitere Personen''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_PERSON.A0101_03_SID IS ''Referenzkatalog Rechtsform''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_POSTADRESSE.GLO_A24_SID IS ''Referenz Staat''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_PROTOKOLL.PARAMETER IS ''spezielle Verfahrensparameter''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_D_PROTOKOLL.QUELLE IS ''Datenherkunft''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_BTS_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_FKT_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_FKT_ADR.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_FKT_KOM.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_FKT_REG.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_PERS_ADR.TYP IS ''BTRO: Standort der Betriebssttte, genau einmal pro Betrieb 
  BTRA: Abweichende Postanschrift der Betriebssttte
  ORG: Postanschrift einer Organisation, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Organisation vorhanden.
  PERS: Postanschrift einer Person, sie braucht nur angelegt zu werden, wenn sie eine andere ist als die vom Typ BTRO/BTRA). Diese Adressart ist hchstens einmal pro am Betrieb hngender Person vorhanden.
  BTRB: Adresse eines Betriebsteils''';

  EXECUTE IMMEDIATE 'COMMENT ON COLUMN EIN_R_PERS_FKT.D_FKT_ID IS ''INH: fr Betreiber
  HV: Hauptverantwortliche (optional), immer natrl. Person''';

  IF FieldExists('EIN_D_FUNKTION', 'D0101_ID3') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_FUNKTION DROP (D0101_ID3)';
  END IF;

  IF NOT FieldExists('EIN_D_BETRIEBSSTAETTE', 'ZB') THEN
    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_BETRIEBSSTAETTE ADD
      (
           ZB VARCHAR2(5 CHAR) 
      )';
    
  END IF;

  -- 27.11.2012
  SELECT COUNT(*) INTO vCnt
  FROM user_tab_columns
  WHERE table_name = 'EIN_D_VERWALTUNG'
    AND column_name = 'GEMEINDE'
    AND data_length < 50;
    
  IF vCnt > 0 THEN
    EXECUTE IMMEDIATE '     
      ALTER TABLE EIN_D_VERWALTUNG MODIFY GEMEINDE VARCHAR2(50 CHAR)';
    
    Comment_Col('EIN_D_VERWALTUNG.GEMEINDE', 'Beinhaltet fr BTR aus der GKZ die Gemeinde, fr BEA Bezeichnung der Gemeinde');
     
  END IF;

  SELECT COUNT(*) INTO vCnt
  FROM user_tab_columns
  WHERE table_name = 'EIN_D_VERWALTUNG'
    AND column_name = 'GKZ'
    AND data_length < 14;
  
  IF vCnt > 0 THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_VERWALTUNG MODIFY GKZ VARCHAR2(14 CHAR)';
  END IF;
  
  IF Not FieldExists('EIN_D_VERWALTUNG', 'TEILORT') THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_VERWALTUNG ADD
      (
           TEILORT VARCHAR2(50 CHAR) NULL 
      )';
  END IF;

  -- 28.11.2012
  
  IF TableExists('EIN_R_FKT_PERS') THEN
    EXECUTE IMMEDIATE 'DROP TABLE EIN_R_FKT_PERS CASCADE CONSTRAINTS';    
  END IF;
  
  IF NOT TableExists('EIN_R_PERS_PERS') THEN
    EXECUTE IMMEDIATE NLS_CHAR('
      CREATE  TABLE EIN_R_PERS_PERS
      ( 
           D_PERS_ID  VARCHAR2(32) NOT NULL,
           D_PERS_ID2 VARCHAR2(32) NOT NULL,
           TYP        VARCHAR2(20) NOT NULL, 
           CONSTRAINT D_PERS$R_PERS_PERS$D_PERS_ID FOREIGN KEY
           ( D_PERS_ID )
           REFERENCES EIN_D_PERSON
           ( ID )
           ON DELETE CASCADE
           NOT DEFERRABLE Initially IMMEDIATE,
           CONSTRAINT D_PERS$R_PERS_PERS$D_PERS_ID2 FOREIGN KEY
           ( D_PERS_ID2 )
           REFERENCES EIN_D_PERSON
           ( ID )
           ON DELETE CASCADE
           NOT DEFERRABLE Initially IMMEDIATE
      )');
  
    EXECUTE IMMEDIATE ' 
      CREATE INDEX FK_R_PERS_PERS$D_PERS_ID ON EIN_R_PERS_PERS (D_PERS_ID)';

    EXECUTE IMMEDIATE ' 
      CREATE INDEX FK_R_PERS_PERS$D_PERS_ID2 ON EIN_R_PERS_PERS (D_PERS_ID2)';

    EXECUTE IMMEDIATE ' 
      COMMENT ON TABLE EIN_R_PERS_PERS IS ''Beziehungen zwischen Personen''';

    Comment_Col('EIN_R_PERS_PERS.D_PERS_ID', 'Parent');
    Comment_Col('EIN_R_PERS_PERS.D_PERS_ID2', 'Child');
    Comment_Col('EIN_R_PERS_PERS.TYP', 'Funktionstyp der Beziehung:  Betreiber / Personal');

  END IF;
  
  -- 28.01.2013
  IF Not FieldExists('EIN_D_KATASTER', 'S09_SID') THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_KATASTER ADD
      (
           GIS_QUELLE VARCHAR2(10 CHAR) NULL,
           S09_SID NUMBER(10) DEFAULT (-1) NULL 
      )';
      
    Comment_Col('EIN_D_KATASTER.GIS_QUELLE', 'Herkunft der Koordinaten: TSN, HK, MANUELL');      
    Comment_Col('EIN_D_KATASTER.S09_SID', 'Koordinatensystem');      

  END IF;  

  -- 28.01.2013
  IF Not FieldExists('EIN_D_BETRIEBSSTAETTE', 'CODE') THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_BETRIEBSSTAETTE ADD
      (
           CODE VARCHAR2(128 CHAR) NULL 
      )';      
  END IF;  

  -- 28.02.2012
  IF NOT FieldExists('EIN_D_PERSON', 'A0101_70_SID') THEN
    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_PERSON ADD
        (
             A0101_70_SID NUMBER(10) NULL 
        )';

    Comment_Col('EIN_D_PERSON.A0101_70_SID', 'Referenzkatalog Personalfunktion');
  
    Comment_Col('EIN_D_PERSON.REF_ID', 'VIS_D0101.ID fr TYP = JP und VIS_D0102 fr TYP = NP');

  END IF;
 
  -- 22.03.2013
  IF NOT FieldExists('EIN_D_FACHBEREICHE', 'A0115_SID') THEN  
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_FACHBEREICHE ADD
      (
           A0115_SID NUMBER(10) NULL, 
           A0101_01_SID NUMBER(10) NULL, 
           ERSTKONTROLLE_TAGE NUMBER(10) NULL 
      )';

    Comment_Col('EIN_D_FACHBEREICHE.A0115_SID', 'Risikobeurteilungsart');
    Comment_Col('EIN_D_FACHBEREICHE.A0101_01_SID', 'Kontrollfristart');
    Comment_Col('EIN_D_FACHBEREICHE.ERSTKONTROLLE_TAGE', 'Erstkontrolltermin in Tagen');  
  END IF;

  -- 19.04.2013
  SELECT COUNT(*) INTO vCnt
  FROM user_tab_columns
  WHERE table_name = 'EIN_D_ADRESSE'
    AND column_name = 'FREIBEZ'
    AND data_length > 50;
  
  IF vCnt > 0 THEN
    
    EXECUTE IMMEDIATE 'UPDATE ein_d_adresse SET freibez = SUBSTR(freibez,1 ,50) WHERE LENGTH(freibez) > 50';  
  
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_ADRESSE MODIFY FREIBEZ VARCHAR2(50)';
  END IF;
  
  -- 01.08.2013
  IF NOT FieldExists('EIN_D_USECASE', 'EXTERN_MESSAGE') THEN
    EXECUTE IMMEDIATE '   
      ALTER TABLE EIN_D_USECASE ADD (
        EXTERN_MESSAGE CLOB NULL, 
        DATENHERKUNFT VARCHAR2(50 CHAR) NULL, 
        BESTAETIGT NUMBER(10) DEFAULT 0  NOT NULL )';
  
    Comment_Col('EIN_D_USECASE.EXTERN_MESSAGE','Meldungen vom WEB-Service oder Datenlieferanten');
    Comment_Col('EIN_D_USECASE.DATENHERKUNFT','Datenherkunft');
    Comment_Col('EIN_D_USECASE.BESTAETIGT','Anzahl der Besttigungen, wenn grer 0 und DELETED = 0 dann ist die Besttigung durchgefhrt aber noch nicht abgeschlossen');
  
  END IF;
  
  -- 13.01.2014
  IF NOT IdxExists('IDX_AUS_D_BTA$REF_ID') THEN
    CrtIdx('CREATE INDEX IDX_AUS_D_BTA$REF_ID ON AUS_D_BETRIEBSART (REF_ID)');  
  END IF;

  -- 06.02.2015
  IF NOT FieldExists('AUS_D_USECASE', 'REF_ID_ALT') THEN
    EXECUTE IMMEDIATE '   
      ALTER TABLE AUS_D_USECASE ADD (
        REF_ID_ALT VARCHAR2(32 CHAR) NULL)';
  
    Comment_Col('AUS_D_USECASE.REF_ID_ALT','optional, Referenz auf einen Datensatz im alten Ausgangskorb (z.B. AUS_D_BETRIEBSART.ID)');
    Comment_Col('AUS_D_USECASE.REF_ID','optional, Referenz auf einen Datensatz im aktuellen Ausgangskorb (z.B. AUS_D_BETRIEBSART.ID)');
  
  END IF;

  IF NOT TableExists('AUS_D_TIERANGABEN') THEN
    EXECUTE IMMEDIATE NLS_CHAR('   
    CREATE TABLE AUS_D_TIERANGABEN
    (  ID VARCHAR2(32) NOT NULL ,
       D_BTS_ID VARCHAR2(32) NOT NULL ,
       D_BTA_ID VARCHAR2(32) NULL ,
       BEZEICHNUNG VARCHAR2(128) NULL ,
       CODE VARCHAR2(128) NULL ,
       ANZAHL NUMBER(10) NULL ,
       GUELTIG_VON DATE NULL ,
       GUELTIG_BIS DATE NULL ,
       REF_ID VARCHAR2(32) NULL ,
       CONSTRAINT PK_AUS_D_TIR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE ' || vUI_TBS || 
    ', CONSTRAINT AUS_D_BTS$D_TIR$BTS_ID FOREIGN KEY
       ( D_BTS_ID )
       REFERENCES AUS_D_BETRIEBSSTAETTE
       ( ID )
       NOT DEFERRABLE Initially IMMEDIATE,

       CONSTRAINT AUS_D_BTA$D_TIR$BTA_ID FOREIGN KEY
       ( D_BTA_ID )
       REFERENCES AUS_D_BETRIEBSART
       ( ID )
       NOT DEFERRABLE Initially IMMEDIATE
    )');

    CrtIdx('CREATE INDEX IDX_AUS_D_TIR$REF_ID ON AUS_D_TIERANGABEN (REF_ID)');
    CrtIdx('CREATE INDEX IDX_AUS_D_TIR$BTS_ID ON AUS_D_TIERANGABEN (D_BTS_ID)');
    CrtIdx('CREATE INDEX IDX_AUS_D_TIR$BTA_ID ON AUS_D_TIERANGABEN (D_BTA_ID)');
    
    COMMENT_Tab('AUS_D_TIERANGABEN', 'Krzel TIR');
    COMMENT_COL('AUS_D_TIERANGABEN.BEZEICHNUNG', 'entspricht VIS_A0104.BEZ');
    COMMENT_COL('AUS_D_TIERANGABEN.CODE', 'entspricht VIS_A0104.CODE');
    COMMENT_COL('AUS_D_TIERANGABEN.REF_ID', 'Referenz zu VIS_D0104.ID');

  END IF;
  
  -- 13.03.2015
  IF Not FieldExists('AUS_D_PROTOKOLL', 'PRIO') THEN
    EXECUTE IMMEDIATE ' 
    ALTER TABLE AUS_D_PROTOKOLL ADD
    (  PRIO NUMBER(10) DEFAULT 99  NOT NULL )';
  
    Comment_Col('AUS_D_PROTOKOLL.PRIO', 'Prioritt fr den Export. 1 fr definierte Usecases die immer als erstes gesendet werden mssen z.B. ANMELD_BTR, 10 fr manuelles Senden, 99 Standard');
    
    CrtIdx('CREATE INDEX IDX_AUS_D_PROT$02 ON AUS_D_PROTOKOLL (PRIO,INS_DATE,STATUS,DELETED)');
  
    Comment_Col('AUS_D_PROTOKOLL.STATUS', 
                '0 - nicht verarbeitet, vor dem Vergleich,' ||
                ' 2 - gesendet, zum Vergleich,' ||
                ' 3 - nur zum Vergleich, wird nicht und wurde nicht gesendet,' ||
                ' 4 - nur zum Vergleich mit dem Eingangskorb, 5 - neuer Betrieb ohne Dublettenabgleich senden,' ||
                ' 6 - ohne Plausiprfung,' ||
                ' 10 - vor der Besttigung beim manuellen Export');
  END IF;
  
  IF Not FieldExists('AUS_D_USECASE', 'STATUS') THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE AUS_D_USECASE ADD
      ( STATUS NUMBER(1) DEFAULT 0  NOT NULL )';
        
    Comment_Col('AUS_D_USECASE.STATUS', '0 nocht nicht gesendet, 1 gesendet');      
  END IF;
  
  IF Not TableExists('EIN_D_TIERANGABEN') THEN
    EXECUTE IMMEDIATE NLS_CHAR(' 
      CREATE  TABLE EIN_D_TIERANGABEN
      ( 
           ID VARCHAR2(32) NOT NULL ,
           D_BTS_ID VARCHAR2(32) NOT NULL ,
           BEZEICHNUNG VARCHAR2(128) NULL ,
           CODE VARCHAR2(128) NULL ,
           ANZAHL NUMBER(10) NULL ,
           GUELTIG_VON DATE NULL ,
           GUELTIG_BIS DATE NULL ,
           REF_ID VARCHAR2(32) NULL ,
           D_BTA_ID VARCHAR2(32) NULL ,
           CONSTRAINT PK_EIN_D_TIR$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE  ' || vUI_TBS ||
      ',   CONSTRAINT EIN_D_BTS$D_TIR$BTS_ID FOREIGN KEY
           ( D_BTS_ID )
           REFERENCES EIN_D_BETRIEBSSTAETTE
           ( ID )
           NOT DEFERRABLE Initially IMMEDIATE ,
           
           CONSTRAINT EIN_D_BTA$D_TIR$BTA_ID FOREIGN KEY
           ( D_BTA_ID )
           REFERENCES EIN_D_BETRIEBSART
           ( ID )
           NOT DEFERRABLE Initially IMMEDIATE
      )');

    CrtIdx('CREATE INDEX IDX_EIN_D_TIR$REF_ID ON EIN_D_TIERANGABEN (REF_ID)');
    CrtIdx('CREATE INDEX IDX_EIN_D_TIR$BTS_ID ON EIN_D_TIERANGABEN (D_BTS_ID)');
    CrtIdx('CREATE INDEX IDX_EIN_D_TIR$BTA_ID ON EIN_D_TIERANGABEN (D_BTA_ID)');

    COMMENT_TAB('EIN_D_TIERANGABEN', 'Krzel TIR');

    COMMENT_Col('EIN_D_TIERANGABEN.BEZEICHNUNG', 'entspricht VIS_A0104.BEZ');
    COMMENT_Col('EIN_D_TIERANGABEN.CODE', 'entspricht VIS_A0104.CODE');
    COMMENT_Col('EIN_D_TIERANGABEN.REF_ID', 'Referenz zu VIS_D0104.ID');
  END IF;

  -- 29.05.2015
  IF NOT IdxExists('IDX_EIN_D_UC$D0101_ID') THEN
  
    CrtIdx('CREATE INDEX idx_ein_d_uc$d0101_id ON ein_d_usecase (d0101_id, usecase)');
  
  END IF;

  -- 02.06.2015
  -- HIT-Felder auf 30 Zeichen krzen
  FOR c1 IN (
    SELECT *
    FROM user_tab_columns
    WHERE table_name = 'AUS_D_PERSON'
    AND column_name IN ('KURZBEZ1', 'KURZBEZ2')
    AND data_length > 30  
  ) LOOP
  
    EXECUTE IMMEDIATE '
    UPDATE aus_d_person
    SET kurzbez1 = SUBSTR(kurzbez1, 1,30)
      , kurzbez2 = SUBSTR(kurzbez2, 1,30)
    WHERE LENGTH(kurzbez1) > 30 OR LENGTH(kurzbez2) > 30';
  
    EXECUTE IMMEDIATE ' 
    ALTER TABLE aus_d_person MODIFY ( 
      kurzbez1 VARCHAR2(30 CHAR),    
      kurzbez2 VARCHAR2(30 CHAR ) )';
  
  END LOOP;
  
  -- 20.08.2015
  -- todo 58548090
  EXECUTE IMMEDIATE '
  UPDATE ein_d_usecase
  SET aend_art = ''3''
  WHERE usecase = ''AUTOEXPORT''
  AND aend_art <> ''3'' ';
  
  EXECUTE IMMEDIATE '
  UPDATE ein_d_usecase
  SET datenherkunft = ''BALVI iP''
  WHERE usecase = ''AUTOEXPORT''
  AND datenherkunft IS NULL
  AND aend_art IN (''3'', ''4'')';

  Comment_Col('ein_d_usecase.aend_art', '0 - ndern, 1 - Korrektur, 2 - Ablehnung, 3 - Fehler vom Export BALVI, 4 - Fehler vom Register');

  IF NOT IdxExists('IDX_EIN_D_UC$D0101_ID_AA') THEN  
    CrtIdx('CREATE INDEX idx_ein_d_uc$d0101_id_AA ON ein_d_usecase (d0101_id, aend_art)');
  END IF;

  -- todo 61103090: 24.03.2016
  FOR c1 IN (
    SELECT *
    FROM user_tab_columns
    WHERE table_name = 'EIN_D_BETRIEBSART'
    AND column_name IN ('BEZ')
    AND char_length < 2000  
  ) LOOP
    EXECUTE IMMEDIATE ' 
      ALTER TABLE ' || c1.table_name || ' MODIFY ' || c1.column_name || ' VARCHAR2(2000 CHAR)';              
  END LOOP;
  
  Comment_col('EIN_D_BETRIEBSART.SCOPE', 'XGEWERBE: Originale Code vom Gewerbeamt');

  IF NOT IdxExists('IDX_EIN_D_REG$NUMMER') THEN
    CrtIdx('CREATE INDEX IDX_EIN_D_REG$NUMMER ON EIN_D_REGISTRIERUNG (NUMMER)');
  END IF;

  -- 01.07.2016
  IF NOT FieldExists('EIN_D_PROTOKOLL', 'MESSAGE_ID') THEN
    
    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_PROTOKOLL ADD
      (    MESSAGE_ID VARCHAR2(32 CHAR) NULL, 
           SOURCE_ID VARCHAR2(36 CHAR) NULL 
      )';
      
    CrtIdx('CREATE INDEX IDX_EIN_D_PROT$MSG_SRC_ID ON EIN_D_PROTOKOLL (MESSAGE_ID,SOURCE_ID)');

    COMMENT_COL('EIN_D_PROTOKOLL.MESSAGE_ID', 'generierter Hash-Wert fr XGewerbe');
    COMMENT_COL('EIN_D_PROTOKOLL.SOURCE_ID', 'fr XGewerbe externe ID');    
    COMMENT_COL('EIN_D_PROTOKOLL.STATUS', '0 - externe nderungen/Neuanlagen,  1 - Besttigung eigenen nderungen/Neuanlagen, 2 - Besttigung ANL_MIN als Dublette, 10 - Ablehnung, 20 - Betrieb als Dublette, 30 - Abschluverarbeitung fr XGEWERBE noch offen');
    COMMENT_COL('EIN_D_PROTOKOLL.PARAMETER', 'spezielle Verfahrensparameter: XGEWERBE_DUBLETTE=0/1 Dulette vorhanden; XGEWERBE_GEWERBENR=0/1 GewerbeNr. vorhanden');
    COMMENT_COL('EIN_D_PROTOKOLL.QUELLE', 'Verfahren');
    
  END IF;

  -- 09.11.2016
  IF NOT FieldExists('EIN_D_FACHBEREICHE', 'A0150_SID') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_FACHBEREICHE ADD (A0150_SID NUMBER(10) )';
    COMMENT_COL('EIN_D_FACHBEREICHE.A0150_SID', 'berwachungsbezirk fr XGewerbe');    
  END IF;
  
  -- Todo: 62018090
  IF NOT FieldExists('EIN_D_PERSON', 'GEBURTSLAND') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_PERSON ADD (GEBURTSLAND VARCHAR2(50 CHAR) )';
  END IF;
    
  IF NOT FieldExists('EIN_D_PERSON', 'GEBURTSNAME') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_PERSON ADD (GEBURTSNAME VARCHAR2(50 CHAR) )';
  END IF;
  
  IF Not TableExists('EIN_D_MERKMAL') THEN
    EXECUTE IMMEDIATE '   
      CREATE  TABLE EIN_D_MERKMAL
      ( 
           ID VARCHAR2(32 CHAR) NOT NULL ,
           D_BTS_ID VARCHAR2(32 CHAR) NOT NULL ,
           BEZEICHNUNG VARCHAR2(128 CHAR) NULL ,
           CODE VARCHAR2(128 CHAR) NULL ,
           WERT VARCHAR2(128 CHAR) NULL ,
           REF_ID VARCHAR2(32 CHAR) NULL      ,
           CONSTRAINT PK_EIN_D_MRK$ID PRIMARY KEY (ID) NOT DEFERRABLE Initially IMMEDIATE  ' || vUI_TBS ||',

           CONSTRAINT D_BTS$D_MRK$D_BTS_ID FOREIGN KEY
           ( D_BTS_ID )
           REFERENCES EIN_D_BETRIEBSSTAETTE
           ( ID )
           ON DELETE CASCADE
           NOT DEFERRABLE Initially IMMEDIATE

      )';

    CrtIdx('CREATE INDEX IDX_EIN_D_MRK$REF_ID ON EIN_D_MERKMAL (REF_ID)');
    CrtIdx('CREATE INDEX IDX_EIN_D_MRK$D_BTS_ID ON EIN_D_MERKMAL (D_BTS_ID)');
    COMMENT_TAB('EIN_D_MERKMAL', 'Krzel MRK');
  
  END IF;

  Comment_Col('EIN_D_FUNKTION.TYP', 
'INH: Betreiber fr NRW sonst "Betreiber"
HV: Hauptverantwortlicher
TYV: weitere Personen
Betreiber[n]: Betreiber n.-Ordnung (1..n)
GesetzlicherVertreter[n]
Hauptansprechpartner[n]
Bearbeiter
kuenftigerBetreiber
fruehererBetreiber');

  Comment_Col('EIN_D_FUNKTION.ID', '');
 
  IF NOT FieldExists('AUS_D_PERSON', 'VORSATZ_NACHNAME') THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE AUS_D_PERSON ADD
      (    VORSATZ_NACHNAME VARCHAR2(30 CHAR) NULL ,
           NACHSATZ_NACHNAME VARCHAR2(30 CHAR) NULL )';
  END IF; 
 
  IF Not FieldExists('EIN_D_PROTOKOLL', 'GEWERBE_BETRIEB_ID') THEN
    EXECUTE IMMEDIATE '
    ALTER TABLE EIN_D_PROTOKOLL ADD
    (
         GEWERBE_BETRIEB_ID VARCHAR2(36 CHAR) NULL, 
         QUELLE_DATUM DATE NULL ,
         KORREKTUR_JN NUMBER(1) DEFAULT 0  NOT NULL 
    )';

    COMMENT_COL('EIN_D_PROTOKOLL.GEWERBE_BETRIEB_ID', 'technische ID der Betriebssttte beim Gewerbeamt');
    COMMENT_COL('EIN_D_PROTOKOLL.QUELLE_DATUM', 'Erstellungsdatum vom Quellsystem');
    COMMENT_COL('EIN_D_PROTOKOLL.KORREKTUR_JN', 'Korrekturlieferung');

    COMMENT_COL('EIN_D_PROTOKOLL.PARAMETER', 'spezielle Verfahrensparameter: XGEWERBE_DUBLETTE=0/1 Dulette vorhanden; XGEWERBE_GEWERBENR=0/1 GewerbeNr. vorhanden');
    COMMENT_COL('EIN_D_PROTOKOLL.QUELLE', 'Verfahren');
  END IF;

  -- 14.03.2017
  FOR c1 IN (
    SELECT d1.table_name, d1.column_name, d1.data_length
    FROM user_tab_columns d1
    WHERE d1.table_name IN ('EIN_D_PERSON', 'AUS_D_PERSON')
    AND d1.column_name = 'GEBURTSORT'
    AND d1.char_length < 60
  ) LOOP
    EXECUTE IMMEDIATE 'ALTER TABLE '|| c1.table_name ||' MODIFY ' ||c1.column_name|| ' VARCHAR2(60 CHAR)';
  END LOOP;

  FOR c1 IN (
    SELECT d1.table_name, d1.column_name, d1.data_length
    FROM user_tab_columns d1
    WHERE d1.table_name = 'VIS_D0102'
    AND d1.column_name = 'GEB_ORT'
    AND d1.char_length < 60
  ) LOOP
    EXECUTE IMMEDIATE 'ALTER TABLE vis_d0102 MODIFY geb_ort VARCHAR2(60 CHAR)';
  END LOOP;
  
  --30.03.2017
  IF Not FieldExists('EIN_D_POSTADRESSE', 'STRASSE2') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE ein_d_postadresse ADD ( strasse2 VARCHAR2(100 CHAR) )';
    Comment_col('EIN_D_POSTADRESSE.STRASSE2', 'enthlt in XGEWERBE den kompletten Straennamen');
  END IF;
  
  IF Not FieldExists('EIN_D_FUNKTION', 'BETEILIGT_AN') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE ein_d_funktion ADD ( beteiligt_an VARCHAR2(250 CHAR) )';
    Comment_col('EIN_D_FUNKTION.BETEILIGT_AN', 'Betreiber ist beteiligt an einem anderen Betreiber, beinhaltet die Bezeichnung des Betreibers');
  END IF;
  
  FOR c1 IN (
    SELECT d1.table_name, d1.column_name, d1.data_length
    FROM user_tab_columns d1
    WHERE d1.table_name = 'EIN_D_USECASE'
    AND d1.column_name = 'AEND_BEM'
    AND d1.char_length < 2000
  ) LOOP
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_USECASE MODIFY AEND_BEM VARCHAR2(2000 CHAR)';

    COMMENT_COL('EIN_D_USECASE.AUS_D_USECASE_ID', 'ID aus Ausgangskorb wenn aus iP gesendet, Klammerung der Dublette ber diese ID, ein_d_protokoll.status = 2 enthlt Betrieb aus ANMELD_BTR  und ein_d_protokoll.status = 20 die potentiellen Dubletten dazu');

  END LOOP;
  
  IF Not FieldExists('EIN_D_POSTADRESSE', 'ADRESSZUSATZ') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_POSTADRESSE ADD ( ADRESSZUSATZ VARCHAR2(255 CHAR) )';
  END IF;

  IF Not FieldExists('VIS_D0102', 'ADRESSZUSATZ') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE vis_d0102 ADD ( ADRESSZUSATZ VARCHAR2(255 CHAR) )';
  END IF;
  
  IF Not FieldExists('VIS_D0102', 'GLO_A24_SID') THEN
    EXECUTE IMMEDIATE '   
      ALTER TABLE VIS_D0102 ADD
      (
       GLO_A24_SID NUMBER(10) DEFAULT 120 NOT NULL , 
       CONSTRAINT GLO_A24_D0102$GLO_A24_SID FOREIGN KEY
     ( GLO_A24_SID ) REFERENCES GLO_A24 ( SID ) 
     )';

    CrtIdx('CREATE INDEX IDX_D0102_GLO_A24_SID ON VIS_D0102 (GLO_A24_SID)' );

    Comment_Col('VIS_D0102.GLO_A24_SID', 'LAND');

  END IF;

  IF Not FieldExists('EIN_D_BETRIEBSART', 'LBEZ') THEN

    EXECUTE IMMEDIATE '   
      ALTER TABLE EIN_D_BETRIEBSART ADD ( LBEZ CLOB )';
    
    Comment_Col('EIN_D_BETRIEBSART.LBEZ', 'enthlt fr XGEWERBE die komplette Ttigkeitsbezeichnung');
    
  END IF;

  IF Not FieldExists('EIN_D_PROTOKOLL', 'GKZ') THEN

    EXECUTE IMMEDIATE '   
      ALTER TABLE EIN_D_PROTOKOLL ADD ( GKZ VARCHAR2(8 CHAR) )';
    
    Comment_Col('EIN_D_PROTOKOLL.GKZ', 'GKZ der Sitzgemeinde der Betriebssttte');
    
    EXECUTE IMMEDIATE q'[ 
    UPDATE (
    SELECT prt.gkz
    , ( 
      SELECT MAX(verw.gkz) 
      FROM ein_d_verwaltung verw
      JOIN ein_d_adresse adr ON adr.d_verw_id = verw.id
      JOIN ein_r_bts_adr r1 ON r1.d_adr_id = adr.id
      AND r1.typ = 'Standortadresse'
      WHERE r1.d_bts_id = prt.d_bts_id ) verw_gkz    
    FROM ein_d_protokoll prt
    WHERE prt.gkz IS NULL
    ) SET gkz = SUBSTR(verw_gkz,1, 8)
    WHERE verw_gkz IS NOT NULL ]';
        
  END IF;

  -- 31.07.2017
  IF Not FieldExists('AUS_D_POSTADRESSE', 'POSTFACH_JN') THEN

    EXECUTE IMMEDIATE '   
      ALTER TABLE AUS_D_POSTADRESSE ADD ( POSTFACH_JN NUMBER(10) DEFAULT 0 NOT NULL )';
    
    Comment_Col('AUS_D_POSTADRESSE.POSTFACH_JN', 'Kennzeichen fr Postfachadresse');
    
    EXECUTE IMMEDIATE q'[ 
    UPDATE (
    SELECT postfach_jn
    FROM AUS_D_POSTADRESSE
    WHERE postfach IS NOT NULL 
    ) SET postfach_jn = 1]';
        
  END IF;

  IF Not FieldExists('EIN_D_POSTADRESSE', 'POSTFACH_JN') THEN

    EXECUTE IMMEDIATE '   
      ALTER TABLE EIN_D_POSTADRESSE ADD ( POSTFACH_JN NUMBER(10) DEFAULT 0 NOT NULL )';
    
    Comment_Col('EIN_D_POSTADRESSE.POSTFACH_JN', 'Kennzeichen fr Postfachadresse');
    
    EXECUTE IMMEDIATE q'[ 
    UPDATE (
    SELECT postfach_jn
    FROM EIN_D_POSTADRESSE
    WHERE postfach IS NOT NULL 
    ) SET postfach_jn = 1]';
        
  END IF;

  -- 10.08.2017
  -- todo 11291124
  IF Not FieldExists('EIN_D_PROTOKOLL', 'QUELLE_BEARBEITER') THEN
    EXECUTE IMMEDIATE ' 
      ALTER TABLE EIN_D_PROTOKOLL ADD (
           QUELLE_BEARBEITER VARCHAR2(250 CHAR) NULL, 
           QUELLE_TELEFON VARCHAR2(50 CHAR) NULL, 
           QUELLE_EMAIL VARCHAR2(250 CHAR) NULL 
    )';

    COMMENT_COL('EIN_D_PROTOKOLL.PARAMETER', 'spezielle Verfahrensparameter: XGEWERBE_DUBLETTE=0/1 Dulette vorhanden; XGEWERBE_GEWERBENR=0/1 GewerbeNr. vorhanden');
    COMMENT_COL('EIN_D_PROTOKOLL.QUELLE', 'Verfahren');
    COMMENT_COL('EIN_D_PROTOKOLL.QUELLE_BEARBEITER', 'fr XGewerbe Bearbeiter vom Gewerbeamt');
    COMMENT_COL('EIN_D_PROTOKOLL.QUELLE_TELEFON', 'fr XGewerbe Telefon vom Gewerbeamt');
    COMMENT_COL('EIN_D_PROTOKOLL.QUELLE_EMAIL', 'fr XGewerbe E-Mail vom Gewerbeamt');

    -- Daten in neue Felder bertragen 
    EXECUTE IMMEDIATE q'[ 
      begin
        for c1 in (
          select * from (
            select fkt.d_bts_id, prt.rowid prt_rowid, prt.quelle_bearbeiter, prt.quelle_telefon, prt.quelle_email
            , prs.nachname, prs.vorname, rtrim( prs.nachname || ', ' || prs.vorname, ', ') bearbeiter
            , kom.komtyp, KOM.KOMDATA
            from ein_d_protokoll prt
            join ein_d_funktion fkt on fkt.d_bts_id = prt.d_bts_id
            and fkt.typ = 'Bearbeiter'
            join ein_d_person prs on prs.id = fkt.d_pers_id
            left join ein_r_fkt_kom r1 
              join ein_d_kommunikation kom on kom.id = r1.d_kom_id
              and kom.komtyp IN ('EMAIL', 'TELEFON')
            on r1.d_fkt_id = fkt.id
            where prt.quelle = 'XGEWERBE'
          ) 
            PIVOT( MIN(komdata)
                FOR KOMTYP IN ( 
                  'TELEFON' AS telefon,
                  'EMAIL' as email ) )  
        ) loop
        
          update ein_d_protokoll
          set quelle_telefon = c1.telefon
            , quelle_email = c1.email
            , quelle_bearbeiter = c1.bearbeiter
          where rowid = c1.prt_rowid;
        end loop;
              
      end; ]';

  END IF;

  -- 16.01.2018
  -- ein_d_protokoll und ein_d_usecase lastmodified DEFAULT SYSDATE
  IF Not ChkDefault('EIN_D_PROTOKOLL', 'LASTMODIFIED', 'SYSDATE') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_PROTOKOLL MODIFY LASTMODIFIED DEFAULT SYSDATE';
    COMMENT_COL('EIN_D_PROTOKOLL.PARAMETER', 'spezielle Verfahrensparameter: XGEWERBE_DUBLETTE=0/1 Dulette vorhanden; XGEWERBE_GEWERBENR=0/1 GewerbeNr. vorhanden');
    COMMENT_COL('EIN_D_PROTOKOLL.QUELLE', 'Verfahren');
  END IF;
  
  IF Not ChkDefault('EIN_D_USECASE', 'LASTMODIFIED', 'SYSDATE') THEN
    EXECUTE IMMEDIATE 'ALTER TABLE EIN_D_USECASE MODIFY LASTMODIFIED DEFAULT SYSDATE';
  END IF;


  IF Not FieldExists('EIN_D_USECASE', 'BEARBEITUNG_JN') THEN
    EXECUTE IMMEDIATE '
      ALTER TABLE EIN_D_USECASE ADD
      (
         BEARBEITUNG_JN NUMBER(10) DEFAULT 0  NOT NULL 
      )';
    Comment_Col('EIN_D_USECASE.BEARBEITUNG_JN', 'Fr xGewerbeanzieige Status der Meldung in Bearbeitung.');
  END IF;

  -- 10.01.2019
  COMMENT_COL('AUS_D_USECASE.AEND_ART', '0 - ndern, 1 : Korrektur, 2 : Ablehnung aus Eingangskorb');
  COMMENT_COL('AUS_D_USECASE.STATUS', '0 noch nicht gesendet, 1 gesendet');

  IF Not IdxExists('IDX_AUS_D_UC$D0101_ID') THEN
    CrtIdx('CREATE INDEX IDX_AUS_D_UC$D0101_ID ON AUS_D_USECASE (D0101_ID)');
  END IF;

END;
/
