<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                xmlns:raw="http://www.destatis.de/schema/datml-raw/2.0/de"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:d="http://www.destatis.de/schema/datml-raw/2.0/de"
                version="2.0">
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>
   <xsl:output method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>
   <xsl:template match="/">
      <xsl:variable name="berichtszeitraum"
                    as="xs:string?"
                    select="d:DatML-RAW-D/d:nachricht/d:berichtszeitraum/concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00'))"/>
      <xsl:if test="not(matches($berichtszeitraum, '^\d\d\d\d-\d\d$'))">
         <xsl:message terminate="yes">In der Nachricht konnte kein Berichtszeitraum erkannt werden. Prüfung wurde abgebrochen.</xsl:message>
      </xsl:if>
      <xsl:choose>
         <xsl:when test="'2018-05' le $berichtszeitraum">
            <xsl:apply-templates select="/" mode="M_00041840059999000001"/>
         </xsl:when>
         <xsl:when test="'2017-05' le $berichtszeitraum">
            <xsl:apply-templates select="/" mode="M_00041740059999000001"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:message terminate="yes">Für den Berichtszeitraum <xsl:value-of select="$berichtszeitraum"/> liegen keine Validierungsregeln vor. Prüfung wurde abgebrochen.</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   <xsl:template xmlns:sdf="http://www.destatis.de/schema/datml-sdf/2.0"
                 xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001schematron-select-full-path"
                 match="*">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="local-name()"/>
         <xsl:choose>
            <xsl:when test="local-name()='satz' and d:mm[@name='UUID']/d:wert">
               <xsl:text>[mm[@name='UUID' and wert='</xsl:text>
               <xsl:value-of select="d:mm[@name='UUID']/d:wert"/>
               <xsl:text>']]</xsl:text>
            </xsl:when>
            <xsl:when test="local-name()='satz'">
               <xsl:text>[</xsl:text>
               <xsl:value-of select="position()"/>
               <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:when test="local-name()='mmgr' or local-name()='mm'">
               <xsl:text>[@name='</xsl:text>
               <xsl:value-of select="@name"/>
               <xsl:text>']</xsl:text>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[name(.) = name(current())] or       following-sibling::*[name(.) = name(current())]">
               <xsl:text>[</xsl:text>
               <xsl:value-of select="count(preceding-sibling::*[name(.) = name(current())]) + 1"/>
               <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:otherwise/>
         </xsl:choose>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="/"/>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="text()">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.text-', 1 + count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="comment()">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.comment-', 1 + count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="processing-instruction()">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.processing-instruction-', 1 + count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="@*">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-from-path"
                 match="*"
                 priority="-0.5">
      <xsl:apply-templates mode="M_00041840059999000001generate-id-from-path" select="parent::*"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.', name(), '-', 1 + count(preceding-sibling::*[name() = name(current())]), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-2"
                 match="/">U</xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-2"
                 match="*"
                 priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-2"
                 match="node()">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001generate-id-2"
                 match="@*">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(), ':', '.')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041840059999000001"
                 match="text()"
                 priority="-1"/>
   <xsl:template mode="M_00041840059999000001" match="/">
      <rep:pruefprotokoll xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll">
         <xsl:sequence select="/d:DatML-RAW-D/(d:optionen|d:protokoll|d:absender|d:empfaenger)"/>
         <svrl:schematron-output title="GWA-Schematron-Validierer für XGewerbeanzeige (Version 1.3)"
                                 schemaVersion="00041840059999000001">
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">APPLICATION</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Anwendbarkeit der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M2" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">MESSAGEDATAGROUP</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Erforderliche und zulässige Hilfsmerkmale</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M3" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">KNOWN_VARIABLES</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Nur Merkmale der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M4" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">KNOWN_VARIABLEGROUP</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Nur Merkmalsgruppen der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M5" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">VARIABLE_TYPES</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Datentypen der Merkmale</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M6" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">OCCURRENCES_AND_CONDITIONS</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Häufigkeiten und Bedingungen</xsl:attribute>
               <xsl:apply-templates mode="M_00041840059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041840059999000001M7" select="/"/>
         </svrl:schematron-output>
      </rep:pruefprotokoll>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M2"
                 match="d:nachricht/d:erhebung"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:kennung[@klasse = 'ERHID'] = '0004'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:kennung[@klasse = 'ERHID'] = '0004'">
               <xsl:attribute name="id">APPLICATION_ERHID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Element d:kennung muss vorhanden sein und den Wert 0004 haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M2"
                 match="d:nachricht/d:berichtszeitraum"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="/d:DatML-RAW-D/d:optionen/d:test or concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00')) ge '2018-05'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="/d:DatML-RAW-D/d:optionen/d:test or concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00')) ge '2018-05'">
               <xsl:attribute name="id">APPLICATION_BERICHTSZEITRAUM</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Der Berichtszeitraum der Nachricht (<xsl:text/>
                  <xsl:value-of select="concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00'))"/>
                  <xsl:text/>) darf nicht vor der Wirksamkeit dieser Lieferbeschreibung liegen (ausgenommen Testlieferungen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M2" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M2" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M3" match="d:nachricht" priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerichtseinheitID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerichtseinheitID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerichtseinheitIDZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerichtseinheitIDZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_BerichtseinheitIDZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitIDZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'GemeindeName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'GemeindeName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_GemeindeName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'Bemerkungen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'Bemerkungen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_Bemerkungen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Bemerkungen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerEmpfaenger']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerEmpfaenger']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_BerEmpfaenger</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerEmpfaenger: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M3"
                 match="d:nachricht/d:hmm"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_MESSAGEDATAGROUP</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Hilfsmerkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M3" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M3" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M4" match="d:mm" priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'AnschriftZusatz', 'AnzahlBeteiligte', 'AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte', 'ArtHandwerkskarte', 'Auflagen', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonOrt', 'AusgestelltVonPLZ', 'AusgestelltVonSchluessel', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'Begriff', 'Bemerkungen', 'BerEmpfaenger', 'BerichtseinheitID', 'BerichtseinheitIDZusatz', 'BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'BetriebsstaettenBezeichnung', 'DatumMeldung', 'Doktorgrad', 'EMailAdresse', 'EingetragenerName', 'EintragungArt', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'Familienname', 'FaxNummer', 'FaxVorwahl', 'GbRGesellschafter', 'Geburtsdatum', 'Geburtsland', 'Geburtsname', 'Geburtsort', 'GemeindeMeldungNr', 'GemeindeName', 'GemeindeSchluessel', 'GemeindeZusatz', 'GerichtSchluessel', 'Geschlecht', 'GewerbebetriebID', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GrundUmmeldungSchluessel', 'GueltigAb', 'HausNrBis', 'HausNrVon', 'Inhalt', 'IstBeteiligtAn', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'KorrekturGrundSchluessel', 'MeldungArt', 'NATSchluesselVerzeichnis', 'NameFirmaGewerbetreibender', 'NameOrganisation', 'NamenZusatz', 'NationSchluessel', 'NeuAusgeuebt', 'NiederlassungArt', 'Ort', 'Ortsteil', 'PLZ', 'PersonFunktion', 'RechtsformSchluessel', 'SGSSchluesselVerzeichnis', 'SatzErstellung', 'Satzart', 'Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel', 'Status', 'Stichwort', 'Strasse', 'Strassenschluessel', 'TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'TaetigkeitSchwerpunkt', 'TaetigkeitenZusammengefasst', 'TelefonNummer', 'TelefonVorwahl', 'UUID', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomentSchluessel', 'VerdachtsmomenteText', 'Vorname', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'AnschriftZusatz', 'AnzahlBeteiligte', 'AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte', 'ArtHandwerkskarte', 'Auflagen', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonOrt', 'AusgestelltVonPLZ', 'AusgestelltVonSchluessel', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'Begriff', 'Bemerkungen', 'BerEmpfaenger', 'BerichtseinheitID', 'BerichtseinheitIDZusatz', 'BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'BetriebsstaettenBezeichnung', 'DatumMeldung', 'Doktorgrad', 'EMailAdresse', 'EingetragenerName', 'EintragungArt', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'Familienname', 'FaxNummer', 'FaxVorwahl', 'GbRGesellschafter', 'Geburtsdatum', 'Geburtsland', 'Geburtsname', 'Geburtsort', 'GemeindeMeldungNr', 'GemeindeName', 'GemeindeSchluessel', 'GemeindeZusatz', 'GerichtSchluessel', 'Geschlecht', 'GewerbebetriebID', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GrundUmmeldungSchluessel', 'GueltigAb', 'HausNrBis', 'HausNrVon', 'Inhalt', 'IstBeteiligtAn', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'KorrekturGrundSchluessel', 'MeldungArt', 'NATSchluesselVerzeichnis', 'NameFirmaGewerbetreibender', 'NameOrganisation', 'NamenZusatz', 'NationSchluessel', 'NeuAusgeuebt', 'NiederlassungArt', 'Ort', 'Ortsteil', 'PLZ', 'PersonFunktion', 'RechtsformSchluessel', 'SGSSchluesselVerzeichnis', 'SatzErstellung', 'Satzart', 'Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel', 'Status', 'Stichwort', 'Strasse', 'Strassenschluessel', 'TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'TaetigkeitSchwerpunkt', 'TaetigkeitenZusammengefasst', 'TelefonNummer', 'TelefonVorwahl', 'UUID', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomentSchluessel', 'VerdachtsmomenteText', 'Vorname', 'WebAdresse')">
               <xsl:attribute name="id">KNOWN_VARIABLE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>:  Ist in der Liefervereinbarung nicht als Merkmal definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M4" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M4" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M4" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M4" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M5" match="d:mmgr" priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift', 'Aufenthaltsgenehmigung', 'Autor', 'BeteiligteFirma', 'BeteiligtePerson', 'Betrieb', 'Erlaubnis', 'FrueheresGewerbe', 'Gewerbe', 'GruendeUmmeldung', 'Handwerkskarte', 'Hauptniederlassung', 'KuenftigesGewerbe', 'Schwerpunkt', 'SpezifischeInformation', 'Staatangehoerigkeiten', 'Taetigkeit', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'VertretungsberechtigtePerson', 'WeitereNeuAusgeuebteTaetigkeiten', 'WeitereTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift', 'Aufenthaltsgenehmigung', 'Autor', 'BeteiligteFirma', 'BeteiligtePerson', 'Betrieb', 'Erlaubnis', 'FrueheresGewerbe', 'Gewerbe', 'GruendeUmmeldung', 'Handwerkskarte', 'Hauptniederlassung', 'KuenftigesGewerbe', 'Schwerpunkt', 'SpezifischeInformation', 'Staatangehoerigkeiten', 'Taetigkeit', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'VertretungsberechtigtePerson', 'WeitereNeuAusgeuebteTaetigkeiten', 'WeitereTaetigkeiten')">
               <xsl:attribute name="id">KNOWN_VARIABLEGROUPS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>:  Ist in der Liefervereinbarung nicht als Merkmalsgruppe definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M5" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M5" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M5" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M5" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltAm', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'DatumMeldung', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'GueltigAb')]/d:wert"
                 priority="1054">
      <xsl:variable name="day" select="substring(., 1, 2)"/>
      <xsl:variable name="month" select="substring(., 3, 2)"/>
      <xsl:variable name="year" select="substring(., 5, 4)"/>
      <xsl:variable name="date" select="string-join(($year, $month, $day), '-')"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^\d{8}$') and $date castable as xs:date"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^\d{8}$') and $date castable as xs:date">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_DATEFORMAT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein gültiges Datum (<xsl:text/>
                  <xsl:value-of select="$date"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonPLZ', 'Begriff', 'EintragungPLZ', 'FaxVorwahl', 'HausNrBis', 'HausNrVon', 'PLZ', 'TelefonVorwahl')]/d:wert"
                 priority="1053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 10"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 10">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 10.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'NeuAusgeuebt')]/d:wert"
                 priority="1052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('0', '1')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('0', '1')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_JA_NEIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonOrt', 'Doktorgrad', 'Familienname', 'Geburtsland', 'Geburtsname', 'Staatsangehoerigkeit', 'Vorname')]/d:wert"
                 priority="1051">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 50"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 50">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_50</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 50.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('BetriebsstaettenBezeichnung', 'EingetragenerName', 'IstBeteiligtAn', 'NameFirmaGewerbetreibender', 'Stichwort')]/d:wert"
                 priority="1050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 250"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 250">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_250</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 250.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AnschriftZusatz', 'GemeindeMeldungNr', 'NamenZusatz', 'Strassenschluessel')]/d:wert"
                 priority="1049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 30"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 30">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_30</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 30.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EintragungOrt', 'Geburtsort', 'Ort', 'Ortsteil')]/d:wert"
                 priority="1048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 60"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 60">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_60</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 60.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AnlaesseUmmeldung', 'ArtHandwerkskarte', 'UrsacheAbmeldung')]/d:wert"
                 priority="1047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 150"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 150">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_150</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 150.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EintragungNrSonstige', 'FaxNummer', 'TelefonNummer')]/d:wert"
                 priority="1046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 20"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 20">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 20.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte')]/d:wert"
                 priority="1045">
      <xsl:variable name="val"
                    select="if (. castable as xs:integer and xs:integer(.) ge 0) then xs:integer(.) else 'NaN'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) ne 'NaN'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) ne 'NaN'">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein xs:nonNegativeInteger.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) le 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) le 5">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_DIGITS_5</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>:  darf maximal 5 Stellen haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonName', 'Strasse')]/d:wert"
                 priority="1044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 100"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 100">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_100</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 100.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EMailAdresse', 'WebAdresse')]/d:wert"
                 priority="1043">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 80"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 80">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_80</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 80.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GewerbebetriebID', 'UUID')]/d:wert"
                 priority="1042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 36"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 36">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_GewerbebetriebID_LENGTH_IS_36</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 36.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AGSSchluesselVerzeichnis')]/d:wert"
                 priority="1041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 60 and string-length(.) le 79"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 60 and string-length(.) le 79">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_AGSSchluesselVerzeichnis_MAX_LENGTH_IS_60_TO_79</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 60 … 79.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags_.*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags_.*$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags_.*</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AnzahlBeteiligte')]/d:wert"
                 priority="1040">
      <xsl:variable name="val"
                    select="if (. castable as xs:integer and xs:integer(.) ge 0) then xs:integer(.) else 'NaN'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) ne 'NaN'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) ne 'NaN'">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein xs:nonNegativeInteger.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) le 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) le 3">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_DIGITS_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>:  darf maximal 3 Stellen haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Auflagen')]/d:wert"
                 priority="1039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 300"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 300">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_300</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 300.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonSchluessel')]/d:wert"
                 priority="1038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('00001', '00002', '00003', '00004', '00005', '00006', '00007', '00008', '00009', '00011', '00012', '00015', '00016', '00018', '00019', '00021', '00023', '00024', '00025', '00026', '00027', '00031', '00032', '00033', '00034', '00035', '00037', '00038', '00043', '00044', '00045', '00051', '00052', '00053', '00054', '00061', '00062', '00063', '00064', '00065', '00066', '00067', '00068', '00071', '00072', '00074', '00075', '00076', '00078', '00081', '00091', '00092', '00093')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('00001', '00002', '00003', '00004', '00005', '00006', '00007', '00008', '00009', '00011', '00012', '00015', '00016', '00018', '00019', '00021', '00023', '00024', '00025', '00026', '00027', '00031', '00032', '00033', '00034', '00035', '00037', '00038', '00043', '00044', '00045', '00051', '00052', '00053', '00054', '00061', '00062', '00063', '00064', '00065', '00066', '00067', '00068', '00071', '00072', '00074', '00075', '00076', '00078', '00081', '00091', '00092', '00093')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_HANDWERKSKAMMERN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('BerichtseinheitID')]/d:wert"
                 priority="1037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 5 and string-length(.) le 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 5 and string-length(.) le 8">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_5_TO_8</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 5 … 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EintragungArt')]/d:wert"
                 priority="1036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('A', 'B', 'G', 'V', 'X', 'S')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('A', 'B', 'G', 'V', 'X', 'S')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_EINTRAGUNGART</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('EintragungNr')]/d:wert"
                 priority="1035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 14"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 14">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_EintragungNr_MAX_LENGTH_IS_1_TO_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 14.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9A-ZÄÖÜ]*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9A-ZÄÖÜ]*$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9A-ZÄÖÜ]*</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GbRGesellschafter')]/d:wert"
                 priority="1034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 5000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 5000">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_5000</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 5000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Geburtsdatum')]/d:wert"
                 priority="1033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 8">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_Geburtsdatum_LENGTH_IS_8</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster ((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GemeindeSchluessel')]/d:wert"
                 priority="1032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 8">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_LENGTH_IS_8</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GemeindeZusatz')]/d:wert"
                 priority="1031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 4"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 4">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_4</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 4.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GerichtSchluessel')]/d:wert"
                 priority="1030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('R3101', 'R2702', 'Y1201', 'D3101', 'D3201', 'Y1101', 'R1901', 'Y1102', 'Y1303', 'D4102', 'D2102', 'P3101', 'M1305', 'M1202', 'T2101V', 'R2108', 'Y1301', 'D4201', 'D4301', 'R2101', 'R2201', 'R3201', 'P1103', 'H1101', 'R2102', 'F1103R', 'F1103', 'U1206', 'D4401', 'R2707', 'G1103', 'M1103', 'D2201', 'R2402', 'U1104', 'R1202', 'R3103', 'R1101', 'Y1105', 'Y1106', 'R1502', 'M1602', 'R2503', 'X1112R', 'M1201', 'G1207', 'B8536', 'M1405', 'M1603', 'M1301', 'D3304', 'R1302', 'R2507', 'Y1203', 'M1406', 'Y1108', 'P2204', 'N1202', 'Y1205', 'N1303', 'R2103', 'R2602', 'K1101R', 'R2404', 'M1502', 'P2305', 'Y1109', 'R2105', 'R2203', 'Y1302', 'P2408', 'D4501', 'V1102', 'D5701', 'R2604', 'Y1206', 'T3201V', 'M1607', 'D2304', 'X1517R', 'R1304', 'T2210V', 'R3306', 'M1203', 'M1608', 'R1402', 'T3304V', 'D2404', 'V1103', 'U1308', 'R2307', 'M1706', 'X1721R', 'T3104V', 'N1305', 'P2507', 'R2406', 'T2304V', 'B8535', 'M1809', 'Y1304', 'D2505', 'V1104', 'V1116', 'R1504', 'T2214V', 'D2601', 'R2713', 'N1105', 'V1105', 'G1309', 'R1102', 'Y1111', 'D3310', 'R1206', 'M1114', 'P3210', 'P3313', 'V1107', 'R2809', 'N1107', 'D2803', 'X1321R', 'Y1209', 'Y1208', 'G1312', 'R1104', 'R2204', 'D3410', 'R1603', 'N1206', 'Y1210', 'Y1211', 'V1109', 'V1110', 'V1111', 'V1112', 'R3106', 'D4608', 'N1308', 'R3208', 'R2909', 'R1911', 'R1605', 'Y1112', 'Y1113', 'Y1307', 'P2106', 'Y1214', 'R2706', 'W1215', 'N1209', 'D3413', 'B8534', 'Y1308', 'P2613', 'D2910', 'B8537', 'V1115', 'P2716', 'R2813', 'N1112', 'R1912', 'D3508', 'Y1114', 'M1710', 'M1906', 'N1210', 'R2207', 'T2408V', 'R1608', 'D4708', 'T3403V')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('R3101', 'R2702', 'Y1201', 'D3101', 'D3201', 'Y1101', 'R1901', 'Y1102', 'Y1303', 'D4102', 'D2102', 'P3101', 'M1305', 'M1202', 'T2101V', 'R2108', 'Y1301', 'D4201', 'D4301', 'R2101', 'R2201', 'R3201', 'P1103', 'H1101', 'R2102', 'F1103R', 'F1103', 'U1206', 'D4401', 'R2707', 'G1103', 'M1103', 'D2201', 'R2402', 'U1104', 'R1202', 'R3103', 'R1101', 'Y1105', 'Y1106', 'R1502', 'M1602', 'R2503', 'X1112R', 'M1201', 'G1207', 'B8536', 'M1405', 'M1603', 'M1301', 'D3304', 'R1302', 'R2507', 'Y1203', 'M1406', 'Y1108', 'P2204', 'N1202', 'Y1205', 'N1303', 'R2103', 'R2602', 'K1101R', 'R2404', 'M1502', 'P2305', 'Y1109', 'R2105', 'R2203', 'Y1302', 'P2408', 'D4501', 'V1102', 'D5701', 'R2604', 'Y1206', 'T3201V', 'M1607', 'D2304', 'X1517R', 'R1304', 'T2210V', 'R3306', 'M1203', 'M1608', 'R1402', 'T3304V', 'D2404', 'V1103', 'U1308', 'R2307', 'M1706', 'X1721R', 'T3104V', 'N1305', 'P2507', 'R2406', 'T2304V', 'B8535', 'M1809', 'Y1304', 'D2505', 'V1104', 'V1116', 'R1504', 'T2214V', 'D2601', 'R2713', 'N1105', 'V1105', 'G1309', 'R1102', 'Y1111', 'D3310', 'R1206', 'M1114', 'P3210', 'P3313', 'V1107', 'R2809', 'N1107', 'D2803', 'X1321R', 'Y1209', 'Y1208', 'G1312', 'R1104', 'R2204', 'D3410', 'R1603', 'N1206', 'Y1210', 'Y1211', 'V1109', 'V1110', 'V1111', 'V1112', 'R3106', 'D4608', 'N1308', 'R3208', 'R2909', 'R1911', 'R1605', 'Y1112', 'Y1113', 'Y1307', 'P2106', 'Y1214', 'R2706', 'W1215', 'N1209', 'D3413', 'B8534', 'Y1308', 'P2613', 'D2910', 'B8537', 'V1115', 'P2716', 'R2813', 'N1112', 'R1912', 'D3508', 'Y1114', 'M1710', 'M1906', 'N1210', 'R2207', 'T2408V', 'R1608', 'D4708', 'T3403V')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_REGISTERGERICHTE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Geschlecht')]/d:wert"
                 priority="1029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_GESCHLECHT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GrundAbmeldungSchluessel')]/d:wert"
                 priority="1028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_GRUNDABMELDUNGSCHLUESSEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GrundAnmeldungSchluessel')]/d:wert"
                 priority="1027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_GRUNDANMELDUNGSCHLUESSEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('GrundUmmeldungSchluessel')]/d:wert"
                 priority="1026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '99')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '99')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_GRUNDUMMELDUNGSCHLUESSEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Inhalt')]/d:wert"
                 priority="1025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 200"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 200">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_200</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 200.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('KorrekturGrundSchluessel')]/d:wert"
                 priority="1024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_KORREKTUR_NACHM</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('MeldungArt')]/d:wert"
                 priority="1023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_MELDUNGSART</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('NATSchluesselVerzeichnis')]/d:wert"
                 priority="1022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_NATSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^NAT(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^NAT(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster NAT(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('NameOrganisation')]/d:wert"
                 priority="1021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 256"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 256">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_256</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 256.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('NationSchluessel')]/d:wert"
                 priority="1020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 3">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 3.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('NiederlassungArt')]/d:wert"
                 priority="1019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_NIEDERLASSUNGART</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('PersonFunktion')]/d:wert"
                 priority="1018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_PERSONFUNKTION</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('RechtsformSchluessel')]/d:wert"
                 priority="1017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('170', '180', '210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '310', '320', '321', '322', '323', '350', '351', '355', '356', '360', '400', '450', '510', '590', '610', '611', '700', '790', '911', '912', '921', '991', '992')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('170', '180', '210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '310', '320', '321', '322', '323', '350', '351', '355', '356', '360', '400', '450', '510', '590', '610', '611', '700', '790', '911', '912', '921', '991', '992')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_RECHTSFORMEN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('SGSSchluesselVerzeichnis')]/d:wert"
                 priority="1016">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 77 and string-length(.) le 96"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 77 and string-length(.) le 96">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_SGSSchluesselVerzeichnis_MAX_LENGTH_IS_77_TO_96</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 77 … 96.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:staatsangehoerigkeit_.*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:staatsangehoerigkeit_.*$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:staatsangehoerigkeit_.*</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('SatzErstellung')]/d:wert"
                 priority="1015">
      <xsl:variable name="year" select="substring(., 1, 4)"/>
      <xsl:variable name="month" select="substring(., 5, 2)"/>
      <xsl:variable name="day" select="substring(., 7, 2)"/>
      <xsl:variable name="hour" select="substring(., 9, 2)"/>
      <xsl:variable name="minute" select="substring(., 11, 2)"/>
      <xsl:variable name="second" select="substring(., 13, 2)"/>
      <xsl:variable name="date" select="string-join(($year, $month, $day), '-')"/>
      <xsl:variable name="time" select="string-join(($hour, $minute, $second), ':')"/>
      <xsl:variable name="dateTime" select="concat($date, 'T', $time)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$dateTime castable as xs:dateTime"/>
         <xsl:otherwise>
            <svrl:failed-assert test="$dateTime castable as xs:dateTime">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_DATETIME</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="$dateTime"/>
                  <xsl:text/> ist kein gültiger Zeitpunkt.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Satzart')]/d:wert"
                 priority="1014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_BERICHTSEMPFAENGER</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('StaatsangehoerigkeitSchluessel')]/d:wert"
                 priority="1013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 3">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_StaatsangehoerigkeitSchluessel_LENGTH_IS_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 3.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9]{3}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9]{3}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9]{3}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('Status')]/d:wert"
                 priority="1012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('0', '1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('0', '1', '2', '3')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_STATUS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('TaetigkeitEinzeln')]/d:wert"
                 priority="1011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 1000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 1000">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_1000</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 1000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('TaetigkeitSchluessel')]/d:wert"
                 priority="1010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 5">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_2_TO_5</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 5.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('TaetigkeitSchwerpunkt')]/d:wert"
                 priority="1009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 1000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 1000">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_2_TO_1000</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 1000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('TaetigkeitenZusammengefasst')]/d:wert"
                 priority="1008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 5000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 5000">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_2_TO_5000</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 5000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('UrsacheAbmeldungSchluessel')]/d:wert"
                 priority="1007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('10', '11', '12', '13', '14', '15', '16', '17', '18')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('10', '11', '12', '13', '14', '15', '16', '17', '18')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_URSACHEABMELDUNGSCHLUESSEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('VerdachtsmomentSchluessel')]/d:wert"
                 priority="1006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". castable as xs:integer and  xs:integer(.) = (01,02,03,04,05,06,07)"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". castable as xs:integer and xs:integer(.) = (01,02,03,04,05,06,07)">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_VERDACHTSMOMENT_SCHL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:mm[@name = ('VerdachtsmomenteText')]/d:wert"
                 priority="1005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 900"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 900">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_900</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 900.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('Bemerkungen')]/d:wert"
                 priority="1004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 256"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 256">
               <xsl:attribute name="id">MESSAGE_DATAGROUP_VARIABLE_MAX_LENGTH_IS_0_TO_256</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 256.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('BerEmpfaenger')]/d:wert"
                 priority="1003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')">
               <xsl:attribute name="id">MESSAGE_DATAGROUP_VARIABLE_CODE_IN_BERICHTSEMPFAENGER</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('BerichtseinheitID')]/d:wert"
                 priority="1002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 5 and string-length(.) le 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 5 and string-length(.) le 8">
               <xsl:attribute name="id">MESSAGE_DATAGROUP_VARIABLE_MAX_LENGTH_IS_5_TO_8</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 5 … 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('BerichtseinheitIDZusatz')]/d:wert"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 4"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 4">
               <xsl:attribute name="id">MESSAGE_DATAGROUP_VARIABLE_MAX_LENGTH_IS_0_TO_4</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 4.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6"
                 match="d:hmm[@name = ('GemeindeName')]/d:wert"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 50"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 50">
               <xsl:attribute name="id">MESSAGE_DATAGROUP_VARIABLE_MAX_LENGTH_IS_0_TO_50</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 50.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M6" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M6" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]"
                 priority="2118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für ALGID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für ALGID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für ALGID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für ALGID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für ALGID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_VerdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomenteText: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ALGID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ALGIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ALGID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Verdachtsmomente']) le 7"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Verdachtsmomente']) le 7">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Verdachtsmomente: Merkmalsgruppe wird höchstens 7 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Autor']"
                 priority="2117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="2116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="2115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="2114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für ALGID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für ALGID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für ALGID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für ALGID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ALGID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ALGID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ALGID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ALGID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ALGID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ALGID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ALGID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="2113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="2112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ALGID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ALGID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ALGID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="2111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="2110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="2109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="2108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="2107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="2106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="2105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="2104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="2103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="2102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="2101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="2100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumFirma']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumFirma']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumFirma']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumFirma']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="2099">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="2098">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="2097">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="2096">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="2095">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="2094">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="2093">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="2092">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="2091">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ALGID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="2090">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="2089">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="2088">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ALGID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="2087">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="2086">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="2085">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ALGID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ALGID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="2084">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="2083">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="2082">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="2081">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']"
                 priority="2080">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Verdachtsmomente_VerdachtsmomentSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomentSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="2079">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mm"
                 priority="2078">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr"
                 priority="2077">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="2076">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="2075">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="2074">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="2073">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2072">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2071">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="2070">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="2069">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="2068">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="2067">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="2066">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="2065">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="2064">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="2063">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="2062">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="2061">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2060">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2059">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="2058">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="2057">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2056">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2055">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="2054">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="2053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="2052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="2051">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="2048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="2047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="2046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="2045">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="2044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="2043">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="2042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="2041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="2040">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="2039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="2038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="2037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="2036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="2035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="2032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="2031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="2030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="2029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="2028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="2027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="2024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="2023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="2022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="2021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="2020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="2019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="2018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="2017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="2016">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="2015">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="2014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="2013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="2012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="2011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="2010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="2009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="2008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="2007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="2006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="2005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="2004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="2003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mm"
                 priority="2002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('VerdachtsmomentSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('VerdachtsmomentSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('VerdachtsmomentSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mmgr"
                 priority="2001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="2000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1999">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]"
                 priority="1998">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für ASID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ASID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ASIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ASID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für ASID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für ASID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Autor']"
                 priority="1997">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1996">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für ASID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für ASID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für ASID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für ASID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ASID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ASID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ASID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ASID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ASID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ASID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ASID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1995">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1994">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1993">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1992">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1991">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1990">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ASID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1989">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1988">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1987">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1986">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ASID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1985">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1984">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1983">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1982">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ASID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ASID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ASID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1981">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1980">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1979">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1978">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1977">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1976">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1975">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1974">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1973">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ASID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1972">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mm"
                 priority="1971">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr"
                 priority="1970">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1969">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1968">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1967">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1966">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1965">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1964">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1963">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1962">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1961">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1960">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1959">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1958">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1957">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1956">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1955">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1954">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1953">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1952">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1951">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1950">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1949">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1948">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1947">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1946">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1945">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1944">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1943">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1942">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1941">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1940">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1939">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1938">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1937">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1936">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1935">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1934">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1933">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1932">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1931">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1930">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1929">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1928">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1927">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1926">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1925">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1924">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1923">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1922">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1921">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1920">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1919">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1918">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]"
                 priority="1917">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für DGUID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für DGUID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_DGUIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für DGUID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für DGUID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für DGUID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für DGUID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für DGUID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Autor']"
                 priority="1916">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1915">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für DGUID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für DGUID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für DGUID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für DGUID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für DGUID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_DGUID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für DGUID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für DGUID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_DGUID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für DGUID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für DGUID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1914">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1913">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für DGUID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für DGUID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für DGUID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1912">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1911">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1910">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1909">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1908">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1907">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1906">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1905">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1904">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1903">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1902">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1901">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1900">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1899">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1898">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1897">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für DGUID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1896">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1895">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für DGUID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für DGUID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1894">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1893">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1892">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1891">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1890">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1889">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1888">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1887">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1886">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für DGUID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1885">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mm"
                 priority="1884">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr"
                 priority="1883">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1882">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1881">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1880">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1879">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1878">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1877">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1876">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1875">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1874">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1873">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1872">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1871">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1870">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1869">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1868">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1867">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1866">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1865">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1864">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1863">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1862">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1861">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1860">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1859">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1858">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1857">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1856">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1855">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1854">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1853">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1852">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1851">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1850">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1849">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1848">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1847">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1846">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1845">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1844">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1843">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1842">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1841">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1840">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1839">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1838">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1837">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1836">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1835">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1834">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1833">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1832">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1831">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1830">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1829">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1828">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1827">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1826">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1825">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1824">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1823">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1822">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1821">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1820">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1819">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]"
                 priority="1818">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für EAID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mmgr[@name eq 'TaetigkeitenGesamt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mmgr[@name eq 'TaetigkeitenGesamt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Die Bedingung für EAID.TaetigkeitenGesamt (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Autor']"
                 priority="1817">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1816">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandel']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstReisegewerbe']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstReisegewerbe']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstNebenerwerb']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstNebenerwerb']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1815">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungNr']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungNr']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungOrt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungOrt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungPLZ']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungPLZ']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungArt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1814">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1813">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für EAID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1812">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geschlecht']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geschlecht']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für EAID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1811">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1810">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungNr']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungNr']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungOrt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungOrt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungPLZ']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungPLZ']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungArt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1809">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geschlecht']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geschlecht']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für EAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1808">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für EAID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1807">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1806">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für EAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_EAID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für EAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1805">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1804">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1803">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1802">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1801">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mm"
                 priority="1800">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr"
                 priority="1799">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1798">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1797">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1796">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1795">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1794">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1793">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1792">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1791">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1790">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1789">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1788">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1787">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1786">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1785">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1784">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1783">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1782">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1781">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1780">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1779">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1778">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1777">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1776">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1775">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1774">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1773">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1772">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1771">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1770">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1769">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1768">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1767">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1766">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1765">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]"
                 priority="1764">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für FAID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für FAID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_FAIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für FAID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für FAID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für FAID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für FAID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für FAID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Autor']"
                 priority="1763">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1762">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für FAID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für FAID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für FAID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für FAID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für FAID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_FAID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für FAID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für FAID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_FAID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für FAID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für FAID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1761">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1760">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1759">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1758">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1757">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1756">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1755">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1754">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1753">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1752">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1751">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1750">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1749">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1748">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1747">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1746">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1745">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1744">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1743">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1742">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1741">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für FAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1740">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1739">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1738">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für FAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_FAID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für FAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1737">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1736">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1735">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1734">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1733">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1732">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1731">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1730">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1729">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für FAID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1728">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mm"
                 priority="1727">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr"
                 priority="1726">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1725">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1724">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1723">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1722">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1721">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1720">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1719">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1718">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1717">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1716">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1715">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1714">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1713">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1712">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1711">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1710">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1709">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1708">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1707">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1706">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1705">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1704">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1703">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1702">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1701">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1700">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1699">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1698">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1697">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1696">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1695">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1694">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1693">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1692">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1691">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1690">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1689">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1688">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1687">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1686">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1685">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1684">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1683">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1682">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1681">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1680">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1679">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1678">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1677">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1676">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1675">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1674">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1673">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1672">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1671">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1670">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1669">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1668">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1667">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1666">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1665">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1664">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1663">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1662">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1661">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1660">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1659">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1658">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1657">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1656">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1655">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1654">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]"
                 priority="1653">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für HWKID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für HWKID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_HWKIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für HWKID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für HWKID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für HWKID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für HWKID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für HWKID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Autor']"
                 priority="1652">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1651">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für HWKID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für HWKID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für HWKID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für HWKID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für HWKID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_HWKID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für HWKID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für HWKID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_HWKID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für HWKID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für HWKID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1650">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1649">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für HWKID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für HWKID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für HWKID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1648">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1647">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1646">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1645">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1644">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1643">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1642">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1641">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1640">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1639">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1638">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1637">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1636">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1635">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1634">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1633">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1632">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1631">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1630">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1629">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1628">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für HWKID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1627">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1626">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1625">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für HWKID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für HWKID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1624">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1623">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1622">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1621">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1620">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1619">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1618">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1617">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1616">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für HWKID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1615">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mm"
                 priority="1614">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr"
                 priority="1613">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1612">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1611">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1610">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1609">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1608">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1607">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1606">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1605">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1604">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1603">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1602">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1601">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1600">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1599">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1598">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1597">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1596">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1595">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1594">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1593">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1592">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1591">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1590">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1589">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1588">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1587">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1586">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1585">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1584">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1583">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1582">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1581">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1580">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1579">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1578">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1577">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1576">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1575">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1574">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1573">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1572">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1571">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1570">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1569">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1568">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1567">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1566">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1565">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1564">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1563">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1562">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1561">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1560">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1559">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1558">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1557">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1556">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1555">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1554">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1553">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1552">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1551">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1550">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1549">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1548">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1547">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1546">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1545">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1544">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1543">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1542">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1541">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1540">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1539">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1538">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1537">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]"
                 priority="1536">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für IHKID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für IHKID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_IHKIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für IHKID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für IHKID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für IHKID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für IHKID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für IHKID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Autor']"
                 priority="1535">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1534">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für IHKID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für IHKID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für IHKID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für IHKID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für IHKID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_IHKID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für IHKID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für IHKID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_IHKID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für IHKID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für IHKID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1533">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1532">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1531">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1530">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1529">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1528">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1527">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für IHKID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1526">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für IHKID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für IHKID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1525">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1524">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1523">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1522">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1521">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1520">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1519">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1518">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1517">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1516">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1515">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1514">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1513">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1512">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für IHKID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für IHKID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1511">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1510">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1509">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1508">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1507">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1506">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1505">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1504">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1503">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für IHKID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1502">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mm"
                 priority="1501">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr"
                 priority="1500">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1499">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1498">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1497">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1496">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1495">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1494">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1493">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1492">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1491">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1490">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1489">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1488">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1487">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1486">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1485">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1484">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1483">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1482">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1481">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1480">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1479">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1478">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1477">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1476">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1475">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1474">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1473">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1472">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1471">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1470">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1469">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1468">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1467">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1466">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1465">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1464">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1463">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1462">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1461">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1460">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1459">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1458">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1457">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1456">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1455">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1454">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1453">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1452">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1451">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1450">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1449">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1448">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1447">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1446">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1445">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1444">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1443">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1442">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1441">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1440">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1439">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1438">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1437">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1436">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1435">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1434">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1433">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1432">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]"
                 priority="1431">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für ISID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ISID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ISIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für ISID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für ISID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für ISID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Autor']"
                 priority="1430">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1429">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für ISID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für ISID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für ISID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für ISID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ISID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ISID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ISID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ISID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ISID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ISID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ISID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1428">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1427">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1426">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1425">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1424">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1423">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ISID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1422">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1421">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1420">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1419">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ISID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1418">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1417">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1416">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1415">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ISID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ISID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ISID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1414">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1413">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1412">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1411">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1410">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1409">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1408">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1407">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1406">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ISID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1405">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mm"
                 priority="1404">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr"
                 priority="1403">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1402">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1401">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1400">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1399">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1398">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1397">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1396">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1395">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1394">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1393">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1392">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1391">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1390">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1389">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1388">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1387">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1386">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1385">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1384">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1383">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1382">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1381">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1380">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1379">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1378">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1377">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1376">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1375">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1374">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1373">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1372">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1371">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1370">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1369">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1368">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1367">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1366">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1365">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1364">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1363">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1362">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1361">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1360">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1359">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1358">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1357">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1356">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1355">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1354">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1353">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1352">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1351">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]"
                 priority="1350">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für LUEID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für LUEID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_LUEIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für LUEID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für LUEID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für LUEID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Autor']"
                 priority="1349">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1348">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für LUEID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für LUEID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für LUEID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für LUEID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für LUEID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_LUEID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für LUEID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für LUEID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_LUEID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für LUEID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für LUEID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1347">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1346">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1345">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1344">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1343">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1342">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für LUEID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1341">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1340">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1339">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1338">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für LUEID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1337">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1336">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1335">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1334">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für LUEID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für LUEID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1333">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1332">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1331">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1330">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1329">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1328">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1327">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1326">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1325">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für LUEID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1324">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mm"
                 priority="1323">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr"
                 priority="1322">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1321">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1320">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1319">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1318">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1317">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1316">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1315">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1314">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1313">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1312">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1311">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1310">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1309">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1308">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1307">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1306">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1305">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1304">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1303">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1302">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1301">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1300">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1299">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1298">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1297">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1296">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1295">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1294">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1293">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1292">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1291">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1290">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1289">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1288">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1287">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1286">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1285">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1284">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1283">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1282">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1281">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1280">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1279">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1278">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1277">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1276">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1275">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1274">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1273">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1272">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1271">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1270">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]"
                 priority="1269">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'RGID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'Satzart'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'RGID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'Satzart'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung für RGID.Satzart (BerEmpfaenger = 'RGID' UND MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'RGID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3' or not(exists(d:mm[@name eq 'Satzart']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'RGID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' or not(exists(d:mm[@name eq 'Satzart']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_RGIDSatzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung für RGID.Satzart (BerEmpfaenger = 'RGID' UND MeldungArt = 3) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für RGID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für RGID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Autor']"
                 priority="1268">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1267">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandel']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NiederlassungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NiederlassungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstReisegewerbe']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstReisegewerbe']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Hauptniederlassung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Hauptniederlassung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1266">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1265">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1264">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1263">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1262">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für RGID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1261">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1260">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1259">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1258">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für RGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1257">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1256">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1255">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1254">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für RGID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_RGID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für RGID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1253">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1252">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1251">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1250">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1249">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1248">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für RGID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1247">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mm"
                 priority="1246">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr"
                 priority="1245">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1244">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1243">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1242">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1241">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1240">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1239">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1238">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1237">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1236">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1235">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1234">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1233">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1232">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1231">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1230">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1229">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1228">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1227">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1226">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1225">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1224">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1223">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1222">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1221">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1220">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1219">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1218">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1217">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1216">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1215">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1214">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1213">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1212">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1211">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1210">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1209">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1208">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1207">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1206">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1205">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1204">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1203">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1202">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1201">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]"
                 priority="1200">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für STAID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mmgr[@name eq 'GruendeUmmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für STAID.GruendeUmmeldung (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mmgr[@name eq 'GruendeUmmeldung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_STAIDGruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe GruendeUmmeldung: Die Bedingung für STAID.GruendeUmmeldung (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für STAID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung für STAID.GrundAbmeldungSchluessel (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung für STAID.UrsacheAbmeldung (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung für STAID.UrsacheAbmeldungSchluessel (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Autor']"
                 priority="1199">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1198">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung für STAID.Gewerbe.BetriebArtIndustrie (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung für STAID.Gewerbe.BetriebArtHandwerk (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung für STAID.Gewerbe.BetriebArtHandel (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung für STAID.Gewerbe.BetriebArtSonstiges (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für STAID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_STAID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für STAID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für STAID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_STAID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für STAID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für STAID.Gewerbe.Hauptniederlassung (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1197">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1196">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für STAID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für STAID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für STAID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1195">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1194">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1193">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1192">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1191">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1190">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1189">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1188">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1187">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1186">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1185">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1184">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1183">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für STAID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1182">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1181">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für STAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_STAID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für STAID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1180">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1179">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1178">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1177">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1176">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1175">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1174">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1173">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1172">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für STAID.KuenftigesGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1171">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mm"
                 priority="1170">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr"
                 priority="1169">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1168">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1167">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1166">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1165">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1164">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1163">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1162">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1161">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1160">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1159">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1158">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1157">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1156">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1155">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1154">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1153">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1152">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1151">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1150">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1149">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1148">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1147">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1146">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1145">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1144">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1143">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1142">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1141">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1140">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1139">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1138">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1137">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1136">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1135">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1134">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1133">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1132">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1131">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]"
                 priority="1110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'ZVID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert)) or exists(d:mm[@name eq 'Satzart'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'ZVID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert)) or exists(d:mm[@name eq 'Satzart'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung für ZVID.Satzart (BerEmpfaenger = 'ZVID' UND MeldungArt = 1 UND Verdachtsmomente[1].VerdachtsmomentSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'ZVID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert) or not(exists(d:mm[@name eq 'Satzart']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'ZVID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert) or not(exists(d:mm[@name eq 'Satzart']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVIDSatzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung für ZVID.Satzart (BerEmpfaenger = 'ZVID' UND MeldungArt = 1 UND Verdachtsmomente[1].VerdachtsmomentSchluessel /= LEER) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Autor']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Autor']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Autor: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung für ZVID.KorrekturGrundSchluessel (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung für ZVID.GrundAnmeldungSchluessel (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_VerdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomenteText: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Verdachtsmomente']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Verdachtsmomente']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Verdachtsmomente: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Autor']"
                 priority="1109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BerichtseinheitID']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BerichtseinheitID']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Autor_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameOrganisation']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameOrganisation']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Autor_NameOrganisation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameOrganisation: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Autor_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Autor_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Autor_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Autor_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Autor_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtIndustrie']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtIndustrie']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtHandwerk']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtHandwerk']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtHandel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtHandel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtSonstiges']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtSonstiges']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ZVID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung für ZVID.Gewerbe.NiederlassungArt (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ZVID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung für ZVID.Gewerbe.Anschrift (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ZVID.Gewerbe.Hauptniederlassung (MeldungArt = 1 UND Gewerbe[1].NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3') or not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3') or not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVID_GewerbeHauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung für ZVID.Gewerbe.Hauptniederlassung (MeldungArt = 1 UND Gewerbe[1].NiederlassungArt IN {2,3}) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ZVID.Gewerbe.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ZVID.Gewerbe.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ZVID.Gewerbe.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.Hauptniederlassung.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1099">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1098">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1097">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1096">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1095">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1094">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1093">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrSonstige']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrSonstige: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GbRGesellschafter']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GbRGesellschafter']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_GbRGesellschafter</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GbRGesellschafter: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1092">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Doktorgrad']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Doktorgrad']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Doktorgrad</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Doktorgrad: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.SGSSchluesselVerzeichnis (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1091">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.Staatsangehoerigkeit (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Staatangehoerigkeiten.StaatsangehoerigkeitSchluessel (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1090">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1089">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.BeteiligtePerson.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1088">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1087">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1086">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1085">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltAm (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonName (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung für ZVID.Gewerbe.BeteiligteFirma.Handwerkskarte.AusgestelltVonSchluessel (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1084">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1083">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe WeitereNeuAusgeuebteTaetigkeiten: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1082">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2') or exists(d:mm[@name eq 'NeuAusgeuebt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ZVID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '2' or not(exists(d:mm[@name eq 'NeuAusgeuebt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_SchwerpunktNeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Die Bedingung für ZVID.TaetigkeitenGesamt.Schwerpunkt.NeuAusgeuebt (MeldungArt = 2) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']"
                 priority="1081">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1080">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']"
                 priority="1079">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitenZusammengefasst']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1078">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitEinzeln']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1077">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1076">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert  eq  '276') or exists(d:mm[@name eq 'PLZ'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NationSchluessel'][1]/d:wert eq '276') or exists(d:mm[@name eq 'PLZ'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Die Bedingung für ZVID.FrueheresGewerbe.Anschrift.PLZ (NationSchluessel = 276) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']"
                 priority="1075">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Verdachtsmomente_VerdachtsmomentSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomentSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1074">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mm"
                 priority="1073">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'VerdachtsmomenteText')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'VerdachtsmomenteText')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'VerdachtsmomenteText').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr"
                 priority="1072">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Autor', 'Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Autor']/d:mm"
                 priority="1071">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'NameOrganisation', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Autor']/d:mmgr"
                 priority="1070">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Autor</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1069">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1068">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1067">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1066">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1065">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1064">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1063">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1062">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1061">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1060">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1059">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1058">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1057">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1056">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1055">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1054">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1051">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1045">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1043">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1040">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrSonstige', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RechtsformSchluessel', 'GbRGesellschafter').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'Doktorgrad', 'Familienname', 'Vorname', 'NamenZusatz', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'WeitereTaetigkeiten', 'WeitereNeuAusgeuebteTaetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1016">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mm"
                 priority="1015">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr"
                 priority="1014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt_WeitereTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mm"
                 priority="1011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr"
                 priority="1010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'Stichwort', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'WeitereNeuAusgeuebteTaetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt_WeitereNeuAusgeuebteTaetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mm"
                 priority="1003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('VerdachtsmomentSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('VerdachtsmomentSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('VerdachtsmomentSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mmgr"
                 priority="1002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041840059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041840059999000001M7" match="text()" priority="-1"/>
   <xsl:template mode="M_00041840059999000001M7" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041840059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template xmlns:sdf="http://www.destatis.de/schema/datml-sdf/2.0"
                 xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001schematron-select-full-path"
                 match="*">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="local-name()"/>
         <xsl:choose>
            <xsl:when test="local-name()='satz' and d:mm[@name='UUID']/d:wert">
               <xsl:text>[mm[@name='UUID' and wert='</xsl:text>
               <xsl:value-of select="d:mm[@name='UUID']/d:wert"/>
               <xsl:text>']]</xsl:text>
            </xsl:when>
            <xsl:when test="local-name()='satz'">
               <xsl:text>[</xsl:text>
               <xsl:value-of select="position()"/>
               <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:when test="local-name()='mmgr' or local-name()='mm'">
               <xsl:text>[@name='</xsl:text>
               <xsl:value-of select="@name"/>
               <xsl:text>']</xsl:text>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[name(.) = name(current())] or       following-sibling::*[name(.) = name(current())]">
               <xsl:text>[</xsl:text>
               <xsl:value-of select="count(preceding-sibling::*[name(.) = name(current())]) + 1"/>
               <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:otherwise/>
         </xsl:choose>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="/"/>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="text()">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.text-', 1 + count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="comment()">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.comment-', 1 + count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="processing-instruction()">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.processing-instruction-', 1 + count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="@*">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-from-path"
                 match="*"
                 priority="-0.5">
      <xsl:apply-templates mode="M_00041740059999000001generate-id-from-path" select="parent::*"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.', name(), '-', 1 + count(preceding-sibling::*[name() = name(current())]), '-')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-2"
                 match="/">U</xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-2"
                 match="*"
                 priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-2"
                 match="node()">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001generate-id-2"
                 match="@*">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(), ':', '.')"/>
   </xsl:template>
   <xsl:template xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll"
                 mode="M_00041740059999000001"
                 match="text()"
                 priority="-1"/>
   <xsl:template mode="M_00041740059999000001" match="/">
      <rep:pruefprotokoll xmlns:rep="http://www.xgewerbeanzeige.de/gwaschematronvalidierer/pruefprotokoll">
         <xsl:sequence select="/d:DatML-RAW-D/(d:optionen|d:protokoll|d:absender|d:empfaenger)"/>
         <svrl:schematron-output title="GWA-Schematron-Validierer für XGewerbeanzeige (Version 1.2)"
                                 schemaVersion="00041740059999000001">
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">APPLICATION</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Anwendbarkeit der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M2" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">MESSAGEDATAGROUP</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Erforderliche und zulässige Hilfsmerkmale</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M3" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">KNOWN_VARIABLES</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Nur Merkmale der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M4" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">KNOWN_VARIABLEGROUPS</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Nur Merkmalsgruppen der Liefervereinbarung</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M5" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">VARIABLE_TYPES</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Datentypen der Merkmale</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M6" select="/"/>
            <svrl:active-pattern>
               <xsl:attribute name="documents">
                  <xsl:value-of select="document-uri(/)"/>
               </xsl:attribute>
               <xsl:attribute name="id">OCCURRENCES_AND_CONDITIONS</xsl:attribute>
               <xsl:attribute name="name">Prüfung: Häufigkeiten und Bedingungen</xsl:attribute>
               <xsl:apply-templates mode="M_00041740059999000001"/>
            </svrl:active-pattern>
            <xsl:apply-templates mode="M_00041740059999000001M7" select="/"/>
         </svrl:schematron-output>
      </rep:pruefprotokoll>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M2"
                 match="d:nachricht/d:erhebung"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:kennung[@klasse = 'ERHID'] = '0004'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:kennung[@klasse = 'ERHID'] = '0004'">
               <xsl:attribute name="id">APPLICATION_ERHID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Element d:kennung muss vorhanden sein und den Wert 0004 haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M2"
                 match="d:nachricht/d:berichtszeitraum"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="/d:DatML-RAW-D/d:optionen/d:test or concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00')) ge '2017-05'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="/d:DatML-RAW-D/d:optionen/d:test or concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00')) ge '2017-05'">
               <xsl:attribute name="id">APPLICATION_BERICHTSZEITRAUM</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Der Berichtszeitraum der Nachricht (<xsl:text/>
                  <xsl:value-of select="concat(format-number(xs:integer(d:jahr),'0000'),'-', format-number(xs:integer(d:monat),'00'))"/>
                  <xsl:text/>) darf nicht vor der Wirksamkeit dieser Lieferbeschreibung liegen (ausgenommen Testlieferungen).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M2" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M2" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M2" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M3" match="d:nachricht" priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerichtseinheitID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerichtseinheitID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_BerichtseinheitID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerichtseinheitIDZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerichtseinheitIDZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_BerichtseinheitIDZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerichtseinheitIDZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'GemeindeName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'GemeindeName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_GemeindeName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'Bemerkungen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'Bemerkungen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_Bemerkungen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Bemerkungen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:hmm[@name eq 'BerEmpfaenger']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:hmm[@name eq 'BerEmpfaenger']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_Hilfsmerkmale_BerEmpfaenger</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BerEmpfaenger: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M3"
                 match="d:nachricht/d:hmm"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_MESSAGEDATAGROUP</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Hilfsmerkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('BerichtseinheitID', 'BerichtseinheitIDZusatz', 'GemeindeName', 'Bemerkungen', 'BerEmpfaenger').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M3" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M3" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M3" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M4" match="d:mm" priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AGSSchluesselVerzeichnis', 'ANRSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'AnredeSchluessel', 'AnschriftZusatz', 'AnzahlBeteiligte', 'AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte', 'ArtHandwerkskarte', 'Auflagen', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonOrt', 'AusgestelltVonPLZ', 'AusgestelltVonSchluessel', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'Begriff', 'Bemerkungen', 'BerEmpfaenger', 'BerichtseinheitID', 'BerichtseinheitIDZusatz', 'BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'BetriebsstaettenBezeichnung', 'DatumMeldung', 'EMailAdresse', 'EingetragenerName', 'EintragungArt', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'FKSSchluesselVerzeichnis', 'Familienname', 'FaxNummer', 'FaxVorwahl', 'Geburtsdatum', 'Geburtsland', 'Geburtsname', 'Geburtsort', 'GemeindeMeldungNr', 'GemeindeName', 'GemeindeSchluessel', 'GemeindeZusatz', 'GerichtSchluessel', 'Geschlecht', 'GewerbebetriebID', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GrundUmmeldungSchluessel', 'GueltigAb', 'HWKSchluesselVerzeichnis', 'HausNrBis', 'HausNrVon', 'Inhalt', 'IstBeteiligtAn', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'KorrekturGrundSchluessel', 'MeldungArt', 'NATSchluesselVerzeichnis', 'NTTSchluesselVerzeichnis', 'NachtitelSchluessel', 'NameFirmaGewerbetreibender', 'NamenZusatz', 'NationSchluessel', 'NeuAusgeuebt', 'NiederlassungArt', 'Ort', 'Ortsteil', 'PLZ', 'PersonFunktion', 'PostfachNummer', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachPLZ', 'RFMSchluesselVerzeichnis', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'SGSSchluesselVerzeichnis', 'STWVerzeichnis', 'SatzErstellung', 'Satzart', 'Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel', 'Status', 'Stichwort', 'Strasse', 'Strassenschluessel', 'TITSchluesselVerzeichnis', 'TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'TaetigkeitSchwerpunkt', 'TaetigkeitenZusammengefasst', 'TelefonNummer', 'TelefonVorwahl', 'Titel', 'TitelSchluessel', 'UUID', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomentSchluessel', 'VerdachtsmomenteText', 'Vorname', 'WZGSchluesselVerzeichnis', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AGSSchluesselVerzeichnis', 'ANRSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'AnredeSchluessel', 'AnschriftZusatz', 'AnzahlBeteiligte', 'AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte', 'ArtHandwerkskarte', 'Auflagen', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonOrt', 'AusgestelltVonPLZ', 'AusgestelltVonSchluessel', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'Begriff', 'Bemerkungen', 'BerEmpfaenger', 'BerichtseinheitID', 'BerichtseinheitIDZusatz', 'BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'BetriebsstaettenBezeichnung', 'DatumMeldung', 'EMailAdresse', 'EingetragenerName', 'EintragungArt', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'FKSSchluesselVerzeichnis', 'Familienname', 'FaxNummer', 'FaxVorwahl', 'Geburtsdatum', 'Geburtsland', 'Geburtsname', 'Geburtsort', 'GemeindeMeldungNr', 'GemeindeName', 'GemeindeSchluessel', 'GemeindeZusatz', 'GerichtSchluessel', 'Geschlecht', 'GewerbebetriebID', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GrundUmmeldungSchluessel', 'GueltigAb', 'HWKSchluesselVerzeichnis', 'HausNrBis', 'HausNrVon', 'Inhalt', 'IstBeteiligtAn', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'KorrekturGrundSchluessel', 'MeldungArt', 'NATSchluesselVerzeichnis', 'NTTSchluesselVerzeichnis', 'NachtitelSchluessel', 'NameFirmaGewerbetreibender', 'NamenZusatz', 'NationSchluessel', 'NeuAusgeuebt', 'NiederlassungArt', 'Ort', 'Ortsteil', 'PLZ', 'PersonFunktion', 'PostfachNummer', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachPLZ', 'RFMSchluesselVerzeichnis', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'SGSSchluesselVerzeichnis', 'STWVerzeichnis', 'SatzErstellung', 'Satzart', 'Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel', 'Status', 'Stichwort', 'Strasse', 'Strassenschluessel', 'TITSchluesselVerzeichnis', 'TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'TaetigkeitSchwerpunkt', 'TaetigkeitenZusammengefasst', 'TelefonNummer', 'TelefonVorwahl', 'Titel', 'TitelSchluessel', 'UUID', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomentSchluessel', 'VerdachtsmomenteText', 'Vorname', 'WZGSchluesselVerzeichnis', 'WebAdresse')">
               <xsl:attribute name="id">KNOWN_VARIABLE</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>:  Ist in der Liefervereinbarung nicht als Merkmal definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M4" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M4" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M4" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M4" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M5" match="d:mmgr" priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift', 'Aufenthaltsgenehmigung', 'BeteiligteFirma', 'BeteiligtePerson', 'Betrieb', 'Erlaubnis', 'FrueheresGewerbe', 'Gewerbe', 'GruendeUmmeldung', 'Handwerkskarte', 'Hauptniederlassung', 'KuenftigesGewerbe', 'Schwerpunkt', 'SpezifischeInformation', 'Staatangehoerigkeiten', 'Taetigkeit', 'Taetigkeiten', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'VertretungsberechtigtePerson')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift', 'Aufenthaltsgenehmigung', 'BeteiligteFirma', 'BeteiligtePerson', 'Betrieb', 'Erlaubnis', 'FrueheresGewerbe', 'Gewerbe', 'GruendeUmmeldung', 'Handwerkskarte', 'Hauptniederlassung', 'KuenftigesGewerbe', 'Schwerpunkt', 'SpezifischeInformation', 'Staatangehoerigkeiten', 'Taetigkeit', 'Taetigkeiten', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'VertretungsberechtigtePerson')">
               <xsl:attribute name="id">KNOWN_VARIABLEGROUP</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>:  Ist in der Liefervereinbarung nicht als Merkmalsgruppe definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M5" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M5" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M5" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M5" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltAm', 'AustrittsdatumFirma', 'AustrittsdatumPerson', 'BeginnTaetigkeit', 'DatumMeldung', 'EintrittsdatumFirma', 'EintrittsdatumPerson', 'EndeTaetigkeit', 'GueltigAb')]/d:wert"
                 priority="1061">
      <xsl:variable name="day" select="substring(., 1, 2)"/>
      <xsl:variable name="month" select="substring(., 3, 2)"/>
      <xsl:variable name="year" select="substring(., 5, 4)"/>
      <xsl:variable name="date" select="string-join(($year, $month, $day), '-')"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^\d{8}$') and $date castable as xs:date"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^\d{8}$') and $date castable as xs:date">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_VALUESPACE_DATEFORMAT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein gültiges Datum (<xsl:text/>
                  <xsl:value-of select="$date"/>
                  <xsl:text/>).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonPLZ', 'Begriff', 'EintragungPLZ', 'FaxVorwahl', 'HausNrBis', 'HausNrVon', 'PLZ', 'PostfachPLZ', 'TelefonVorwahl')]/d:wert"
                 priority="1060">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 10"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 10">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_10</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 10.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('BetriebArtHandel', 'BetriebArtHandwerk', 'BetriebArtIndustrie', 'BetriebArtSonstiges', 'IstKorrektur', 'IstNebenerwerb', 'IstReisegewerbe', 'NeuAusgeuebt')]/d:wert"
                 priority="1059">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('0', '1')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('0', '1')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_JA_NEIN</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonOrt', 'Familienname', 'Geburtsland', 'Geburtsname', 'Staatsangehoerigkeit', 'Titel', 'Vorname')]/d:wert"
                 priority="1058">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 50"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 50">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_50</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 50.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('BetriebsstaettenBezeichnung', 'EingetragenerName', 'IstBeteiligtAn', 'NameFirmaGewerbetreibender', 'Stichwort')]/d:wert"
                 priority="1057">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 250"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 250">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_250</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 250.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EintragungOrt', 'Geburtsort', 'Ort', 'Ortsteil', 'PostfachOrt')]/d:wert"
                 priority="1056">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 60"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 60">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_60</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 60.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnschriftZusatz', 'GemeindeMeldungNr', 'NamenZusatz', 'Strassenschluessel')]/d:wert"
                 priority="1055">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 30"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 30">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_30</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 30.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnlaesseUmmeldung', 'ArtHandwerkskarte', 'UrsacheAbmeldung')]/d:wert"
                 priority="1054">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 150"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 150">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_150</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 150.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnredeSchluessel', 'NachtitelSchluessel', 'TitelSchluessel')]/d:wert"
                 priority="1053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 2">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_LENGTH_IS_2</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 2.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EintragungNrAusland', 'FaxNummer', 'TelefonNummer')]/d:wert"
                 priority="1052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 20"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 20">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_20</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 20.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnzahlTeilzeitBeschaeftigte', 'AnzahlVollzeitBeschaeftigte')]/d:wert"
                 priority="1051">
      <xsl:variable name="val"
                    select="if (. castable as xs:integer and xs:integer(.) ge 0) then xs:integer(.) else 'NaN'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) ne 'NaN'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) ne 'NaN'">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein xs:nonNegativeInteger.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) le 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) le 5">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_VALUESPACE_MAX_DIGITS_5</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>:  darf maximal 5 Stellen haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonName', 'Strasse')]/d:wert"
                 priority="1050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 100"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 100">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_100</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 100.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EMailAdresse', 'WebAdresse')]/d:wert"
                 priority="1049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 80"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 80">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_80</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 80.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GewerbebetriebID', 'UUID')]/d:wert"
                 priority="1048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 36"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 36">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_GewerbebetriebID_LENGTH_IS_36</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 36.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('NationSchluessel', 'PostfachOrtNationSchluessel')]/d:wert"
                 priority="1047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 3">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 3.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('RechtsformSchluessel', 'StaatsangehoerigkeitSchluessel')]/d:wert"
                 priority="1046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 3">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_LENGTH_IS_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 3.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AGSSchluesselVerzeichnis')]/d:wert"
                 priority="1045">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_AGSSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^AGS(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^AGS(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster AGS(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('ANRSchluesselVerzeichnis')]/d:wert"
                 priority="1044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_ANRSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^ANR(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^ANR(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster ANR(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AnzahlBeteiligte')]/d:wert"
                 priority="1043">
      <xsl:variable name="val"
                    select="if (. castable as xs:integer and xs:integer(.) ge 0) then xs:integer(.) else 'NaN'"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) ne 'NaN'"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) ne 'NaN'">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist kein xs:nonNegativeInteger.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) le 3"/>
         <xsl:otherwise>
            <svrl:failed-assert test="xs:string($val) eq 'NaN' or string-length(xs:string(abs(xs:integer($val)))) le 3">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_VALUESPACE_MAX_DIGITS_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>:  darf maximal 3 Stellen haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Auflagen')]/d:wert"
                 priority="1042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 300"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 300">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_300</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 300.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('AusgestelltVonSchluessel')]/d:wert"
                 priority="1041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 3 and string-length(.) le 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 3 and string-length(.) le 5">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_3_TO_5</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 3 … 5.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EintragungArt')]/d:wert"
                 priority="1040">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('A', 'B', 'G', 'V', 'X')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('A', 'B', 'G', 'V', 'X')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_EINTRAGUNGART</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('EintragungNr')]/d:wert"
                 priority="1039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 14"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 14">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_EintragungNr_MAX_LENGTH_IS_1_TO_14</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 14.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^[0-9A-Z]*$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^[0-9A-Z]*$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster [0-9A-Z]*</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('FKSSchluesselVerzeichnis')]/d:wert"
                 priority="1038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_FKSSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^FKS(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^FKS(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_FKSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster FKS(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Geburtsdatum')]/d:wert"
                 priority="1037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 8">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_Geburtsdatum_LENGTH_IS_8</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster ((([0-2][0-9])|([3][0-1]))(([0][0-9])|([1][0-2]))[0-9]{4})</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GemeindeSchluessel')]/d:wert"
                 priority="1036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 8">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_LENGTH_IS_8</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GemeindeZusatz')]/d:wert"
                 priority="1035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 4"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 4">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_4</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 4.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GerichtSchluessel')]/d:wert"
                 priority="1034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 6 and string-length(.) le 7"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 6 and string-length(.) le 7">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_6_TO_7</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 6 … 7.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Geschlecht')]/d:wert"
                 priority="1033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_GESCHLECHT</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GrundAbmeldungSchluessel')]/d:wert"
                 priority="1032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_GRUNDABMELDUNGSCHLUESSEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GrundAnmeldungSchluessel')]/d:wert"
                 priority="1031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_GRUNDANMELDUNGSCHLUESSEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('GrundUmmeldungSchluessel')]/d:wert"
                 priority="1030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_GRUNDUMMELDUNGSCHLUESSEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('HWKSchluesselVerzeichnis')]/d:wert"
                 priority="1029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_HWKSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^HWK(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^HWK(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster HWK(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Inhalt')]/d:wert"
                 priority="1028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 200"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 200">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_200</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 200.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('KorrekturGrundSchluessel')]/d:wert"
                 priority="1027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_KORREKTUR_NACHM</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('MeldungArt')]/d:wert"
                 priority="1026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_MELDUNGSART</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('NATSchluesselVerzeichnis')]/d:wert"
                 priority="1025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_NATSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^NAT(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^NAT(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster NAT(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('NTTSchluesselVerzeichnis')]/d:wert"
                 priority="1024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_NTTSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^NTT(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^NTT(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster NTT(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('NiederlassungArt')]/d:wert"
                 priority="1023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_NIEDERLASSUNGART</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('PersonFunktion')]/d:wert"
                 priority="1022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('1', '2', '3')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_PERSONFUNKTION</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('PostfachNummer')]/d:wert"
                 priority="1021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 8">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_8</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('RFMSchluesselVerzeichnis')]/d:wert"
                 priority="1020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_RFMSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^RFM(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^RFM(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster RFM(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('RGGSchluesselVerzeichnis')]/d:wert"
                 priority="1019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_RGGSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^RGG(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^RGG(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster RGG(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('SGSSchluesselVerzeichnis')]/d:wert"
                 priority="1018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_SGSSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^SGS(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^SGS(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster SGS(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('STWVerzeichnis')]/d:wert"
                 priority="1017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_STWVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^STW(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^STW(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster STW(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('SatzErstellung')]/d:wert"
                 priority="1016">
      <xsl:variable name="year" select="substring(., 1, 4)"/>
      <xsl:variable name="month" select="substring(., 5, 2)"/>
      <xsl:variable name="day" select="substring(., 7, 2)"/>
      <xsl:variable name="hour" select="substring(., 9, 2)"/>
      <xsl:variable name="minute" select="substring(., 11, 2)"/>
      <xsl:variable name="second" select="substring(., 13, 2)"/>
      <xsl:variable name="date" select="string-join(($year, $month, $day), '-')"/>
      <xsl:variable name="time" select="string-join(($hour, $minute, $second), ':')"/>
      <xsl:variable name="dateTime" select="concat($date, 'T', $time)"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="$dateTime castable as xs:dateTime"/>
         <xsl:otherwise>
            <svrl:failed-assert test="$dateTime castable as xs:dateTime">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_VALUESPACE_DATETIME</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: <xsl:text/>
                  <xsl:value-of select="$dateTime"/>
                  <xsl:text/> ist kein gültiger Zeitpunkt.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Satzart')]/d:wert"
                 priority="1015">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_BERICHTSEMPFAENGER</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('Status')]/d:wert"
                 priority="1014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('0', '1', '2', '3')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('0', '1', '2', '3')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_STATUS</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TITSchluesselVerzeichnis')]/d:wert"
                 priority="1013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_TITSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^TIT(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^TIT(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster TIT(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TaetigkeitEinzeln')]/d:wert"
                 priority="1012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 1000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 1000">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_1000</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 1000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TaetigkeitSchluessel')]/d:wert"
                 priority="1011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 5"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 5">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_2_TO_5</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 5.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TaetigkeitSchwerpunkt')]/d:wert"
                 priority="1010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 1000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 1000">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_2_TO_1000</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 1000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('TaetigkeitenZusammengefasst')]/d:wert"
                 priority="1009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 2 and string-length(.) le 5000"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 2 and string-length(.) le 5000">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_2_TO_5000</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 2 … 5000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('UrsacheAbmeldungSchluessel')]/d:wert"
                 priority="1008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('10', '11', '12', '13', '14', '15', '16', '17', '18')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('10', '11', '12', '13', '14', '15', '16', '17', '18')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_URSACHEABMELDUNGSCHLUESSEL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('VerdachtsmomentSchluessel')]/d:wert"
                 priority="1007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". castable as xs:integer and  xs:integer(.) = (01,02,03,04,05,06,07)"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". castable as xs:integer and xs:integer(.) = (01,02,03,04,05,06,07)">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_CODE_IN_VERDACHTSMOMENT_SCHL</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('VerdachtsmomenteText')]/d:wert"
                 priority="1006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 1 and string-length(.) le 900"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 1 and string-length(.) le 900">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_MAX_LENGTH_IS_1_TO_900</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 1 … 900.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:mm[@name = ('WZGSchluesselVerzeichnis')]/d:wert"
                 priority="1005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) eq 9"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) eq 9">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_WZGSchluesselVerzeichnis_LENGTH_IS_9</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht der Vorgabe 9.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="matches(., '^WZG(0[1-9]|1[0-2])[0-9]{4}$')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="matches(., '^WZG(0[1-9]|1[0-2])[0-9]{4}$')">
               <xsl:attribute name="id">DATAGROUP_VARIABLE_PATTERN_FOR_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> entspricht nicht dem Muster WZG(0[1-9]|1[0-2])[0-9]{4}</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('Bemerkungen')]/d:wert"
                 priority="1004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 256"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 256">
               <xsl:attribute name="id">MESSAGEDATAGROUP_VARIABLE_MAX_LENGTH_IS_0_TO_256</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 256.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('BerEmpfaenger')]/d:wert"
                 priority="1003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test=". = ('STAID', 'IHKID', 'HWKID', 'EAID', 'DGUID', 'RGID', 'FAID', 'ZVID', 'ISID', 'ASID', 'LUEID', 'ALGID')">
               <xsl:attribute name="id">MESSAGEDATAGROUP_VARIABLE_CODE_IN_BERICHTSEMPFAENGER</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Der Wert <xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/> ist in der zugrundeliegenden Codeliste nicht definiert.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('BerichtseinheitID')]/d:wert"
                 priority="1002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 5 and string-length(.) le 8"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 5 and string-length(.) le 8">
               <xsl:attribute name="id">MESSAGEDATAGROUP_VARIABLE_MAX_LENGTH_IS_5_TO_8</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 5 … 8.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('BerichtseinheitIDZusatz')]/d:wert"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 4"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 4">
               <xsl:attribute name="id">MESSAGEDATAGROUP_VARIABLE_MAX_LENGTH_IS_0_TO_4</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 4.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6"
                 match="d:hmm[@name = ('GemeindeName')]/d:wert"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string-length(.) ge 0 and string-length(.) le 50"/>
         <xsl:otherwise>
            <svrl:failed-assert test="string-length(.) ge 0 and string-length(.) le 50">
               <xsl:attribute name="id">MESSAGEDATAGROUP_VARIABLE_MAX_LENGTH_IS_0_TO_50</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="../@name"/>
                  <xsl:text/>: Länge <xsl:text/>
                  <xsl:value-of select="string-length(.)"/>
                  <xsl:text/> entspricht nicht der Vorgabe 0 … 50.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M6" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M6" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M6" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]"
                 priority="2001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel'][1]/d:wert/xs:integer(.) = (1, 2, 3, 4, 5, 6, 7)) or exists(d:mm[@name eq 'FKSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel'][1]/d:wert/xs:integer(.) = (1, 2, 3, 4, 5, 6, 7)) or exists(d:mm[@name eq 'FKSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_FKSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FKSSchluesselVerzeichnis: Die Bedingung L12.15 (Verdachtsmomente[1].VerdachtsmomentSchluessel IN {01++07}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L12.08 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L12.07 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L12.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L12.09 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L12.10 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_VerdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomenteText: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Verdachtsmomente']) le 7"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Verdachtsmomente']) le 7">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Verdachtsmomente: Merkmalsgruppe wird höchstens 7 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="2000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1999">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1998">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L12.11 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L12.12 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L12.13 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L12.14 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ALGID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ALGID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1997">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1996">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1995">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1994">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1993">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1992">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1991">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1990">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1989">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1988">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1987">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1986">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1985">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1984">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumFirma']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumFirma']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumFirma']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumFirma']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1983">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1982">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintrittsdatumPerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AustrittsdatumPerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1981">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1980">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1979">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1978">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1977">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1976">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1975">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1974">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1973">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1972">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1971">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1970">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1969">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1968">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1967">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BeginnTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EndeTaetigkeit']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']"
                 priority="1966">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_Verdachtsmomente_VerdachtsmomentSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomentSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1965">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ALGID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mm"
                 priority="1964">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'AGSSchluesselVerzeichnis', 'AnlaesseUmmeldung', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GemeindeSchluessel', 'GemeindeZusatz', 'GrundAbmeldungSchluessel', 'GrundAnmeldungSchluessel', 'GueltigAb', 'IstKorrektur', 'KorrekturGrundSchluessel', 'MeldungArt', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel', 'VerdachtsmomenteText', 'GewerbebetriebID', 'UUID').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr"
                 priority="1963">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('FrueheresGewerbe', 'Gewerbe', 'KuenftigesGewerbe', 'GruendeUmmeldung', 'TaetigkeitenGesamt', 'Verdachtsmomente', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1962">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1961">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1960">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1959">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1958">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1957">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1956">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1955">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1954">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1953">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1952">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1951">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1950">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1949">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1948">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1947">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1946">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1945">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1944">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1943">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1942">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1941">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1940">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1939">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1938">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1937">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1936">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1935">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1934">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1933">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1932">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1931">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1930">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1929">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1928">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1927">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1926">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1925">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1924">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1923">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1922">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1921">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1920">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1919">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1918">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1917">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1916">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1915">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1914">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1913">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1912">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1911">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1910">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1909">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1908">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1907">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1906">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1905">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1904">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1903">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1902">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1901">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1900">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1899">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1898">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1897">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1896">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1895">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mm"
                 priority="1894">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('VerdachtsmomentSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('VerdachtsmomentSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('VerdachtsmomentSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mmgr"
                 priority="1893">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1892">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ALGID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ALGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1891">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ALGID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]"
                 priority="1890">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L11.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L11.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L11.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1889">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L11.23 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L11.24 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L11.25 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L11.26 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ASID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ASID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1888">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1887">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1886">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1885">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1884">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1883">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1882">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1881">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1880">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1879">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1878">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1877">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1876">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1875">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1874">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1873">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1872">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1871">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1870">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1869">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1868">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1867">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ASID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mm"
                 priority="1866">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr"
                 priority="1865">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1864">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1863">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1862">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1861">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1860">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1859">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1858">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1857">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1856">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1855">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1854">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1853">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1852">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1851">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1850">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1849">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1848">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1847">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1846">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1845">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1844">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1843">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1842">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1841">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1840">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1839">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1838">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1837">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1836">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1835">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1834">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1833">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1832">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1831">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1830">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1829">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1828">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1827">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1826">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1825">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1824">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1823">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1822">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1821">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1820">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ASID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ASID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1819">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ASID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]"
                 priority="1818">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L06.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L06.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L06.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L06.07 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L06.08 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1817">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L06.19 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L06.20 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L06.21 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L06.22 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_DGUID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_DGUID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1816">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1815">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1814">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1813">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1812">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1811">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1810">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1809">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1808">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1807">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1806">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1805">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1804">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1803">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1802">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1801">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1800">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1799">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1798">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1797">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1796">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1795">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1794">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1793">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1792">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1791">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1790">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1789">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_DGUID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mm"
                 priority="1788">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr"
                 priority="1787">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1786">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1785">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1784">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1783">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1782">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1781">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1780">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1779">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1778">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1777">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1776">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1775">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1774">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1773">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1772">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1771">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1770">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1769">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1768">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1767">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1766">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1765">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1764">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1763">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1762">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1761">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1760">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1759">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1758">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1757">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1756">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1755">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1754">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1753">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1752">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1751">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1750">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1749">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1748">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1747">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1746">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1745">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1744">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1743">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1742">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1741">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1740">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1739">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1738">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1737">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1736">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1735">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1734">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1733">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1732">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1731">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1730">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_DGUID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'DGUID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1729">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_DGUID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]"
                 priority="1728">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L07.01 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mmgr[@name eq 'TaetigkeitenGesamt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mmgr[@name eq 'TaetigkeitenGesamt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Die Bedingung L07.50 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1727">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandel']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstReisegewerbe']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstReisegewerbe']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstNebenerwerb']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstNebenerwerb']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_EAID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1726">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungNr']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungNr']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungOrt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungOrt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungPLZ']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungPLZ']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungArt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'RGGSchluesselVerzeichnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'RGGSchluesselVerzeichnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1725">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1724">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1723">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geschlecht']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geschlecht']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1722">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1721">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungNr']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungNr']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungOrt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungOrt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungPLZ']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungPLZ']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintragungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintragungArt']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'RGGSchluesselVerzeichnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'RGGSchluesselVerzeichnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1720">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geschlecht']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geschlecht']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1719">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1718">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1717">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1716">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1715">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1714">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_EAID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mm"
                 priority="1713">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr"
                 priority="1712">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1711">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1710">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1709">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1708">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1707">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1706">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1705">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1704">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1703">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1702">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1701">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1700">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1699">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1698">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1697">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1696">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1695">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1694">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1693">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1692">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1691">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1690">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1689">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1688">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1687">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1686">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1685">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_EAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'EAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1684">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_EAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]"
                 priority="1683">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L08.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L08.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L08.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L08.23 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L08.24 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1682">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L08.12 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L08.13 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L08.14 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L08.15 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_FAID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_FAID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1681">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1680">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1679">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1678">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1677">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1676">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1675">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1674">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1673">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1672">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1671">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1670">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1669">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1668">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1667">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1666">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1665">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1664">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1663">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1662">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1661">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1660">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1659">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1658">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1657">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1656">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1655">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1654">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1653">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1652">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1651">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1650">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_FAID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mm"
                 priority="1649">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr"
                 priority="1648">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1647">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1646">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1645">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1644">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1643">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1642">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1641">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1640">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1639">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1638">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1637">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1636">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1635">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1634">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1633">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1632">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1631">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1630">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1629">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1628">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1627">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1626">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1625">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1624">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1623">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1622">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1621">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1620">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1619">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1618">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1617">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1616">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1615">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1614">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1613">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1612">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1611">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1610">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1609">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1608">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1607">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1606">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1605">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1604">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1603">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1602">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1601">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1600">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1599">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1598">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1597">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1596">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1595">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1594">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1593">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1592">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1591">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1590">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1589">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1588">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1587">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1586">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1585">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1584">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1583">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_FAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'FAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1582">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_FAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]"
                 priority="1581">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L03.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L03.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L03.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L03.07 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L03.08 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1580">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L03.12 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L03.13 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L03.14 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L03.15 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_HWKID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_HWKID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1579">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1578">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1577">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1576">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1575">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1574">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1573">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1572">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1571">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1570">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1569">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1568">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1567">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1566">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1565">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1564">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1563">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1562">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1561">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1560">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1559">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1558">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1557">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1556">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1555">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1554">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1553">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1552">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1551">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1550">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1549">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1548">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1547">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1546">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_HWKID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mm"
                 priority="1545">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr"
                 priority="1544">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1543">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1542">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1541">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1540">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1539">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1538">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1537">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1536">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1535">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1534">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1533">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1532">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1531">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1530">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1529">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1528">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1527">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1526">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1525">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1524">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1523">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1522">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1521">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1520">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1519">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1518">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1517">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1516">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1515">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1514">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1513">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1512">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1511">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1510">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1509">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1508">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1507">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1506">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1505">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1504">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1503">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1502">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1501">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1500">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1499">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1498">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1497">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1496">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1495">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1494">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1493">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1492">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1491">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1490">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1489">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1488">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1487">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1486">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1485">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1484">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1483">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1482">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1481">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1480">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1479">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1478">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1477">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1476">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1475">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_HWKID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'HWKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1474">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_HWKID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]"
                 priority="1473">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L02.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L02.04 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L02.05 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L02.06 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L02.07 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1472">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L02.14 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L02.15 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L02.16 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L02.17 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_IHKID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_IHKID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1471">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1470">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1469">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1468">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1467">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1466">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1465">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1464">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1463">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1462">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1461">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1460">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1459">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1458">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1457">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1456">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1455">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1454">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1453">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1452">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1451">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1450">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1449">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1448">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1447">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1446">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1445">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1444">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1443">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1442">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_IHKID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mm"
                 priority="1441">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr"
                 priority="1440">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1439">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1438">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1437">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1436">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1435">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1434">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1433">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1432">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1431">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1430">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1429">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1428">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1427">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1426">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1425">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1424">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1423">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1422">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1421">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1420">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1419">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1418">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1417">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1416">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1415">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1414">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1413">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1412">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1411">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1410">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1409">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1408">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1407">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1406">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1405">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1404">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1403">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1402">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1401">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1400">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1399">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1398">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1397">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1396">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1395">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1394">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1393">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1392">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1391">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1390">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1389">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1388">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1387">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1386">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1385">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1384">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1383">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1382">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1381">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1380">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1379">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_IHKID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'IHKID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1378">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_IHKID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]"
                 priority="1377">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L05.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L05.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L05.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1376">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L05.23 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L05.24 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L05.25 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L05.26 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ISID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ISID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1375">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1374">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1373">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1372">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1371">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1370">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1369">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1368">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1367">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1366">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1365">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1364">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1363">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1362">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1361">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1360">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1359">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1358">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1357">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1356">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1355">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1354">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ISID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mm"
                 priority="1353">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr"
                 priority="1352">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1351">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1350">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1349">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1348">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1347">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1346">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1345">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1344">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1343">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1342">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1341">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1340">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1339">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1338">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1337">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1336">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1335">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1334">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1333">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1332">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1331">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1330">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1329">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1328">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1327">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1326">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1325">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1324">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1323">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1322">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1321">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1320">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1319">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1318">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1317">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1316">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1315">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1314">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1313">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1312">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1311">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1310">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1309">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1308">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1307">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ISID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ISID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1306">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ISID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]"
                 priority="1305">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L13.02 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L13.05 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L13.06 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1304">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L13.23 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L13.24 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L13.25 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L13.26 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_LUEID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_LUEID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1303">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1302">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1301">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1300">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1299">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1298">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1297">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1296">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1295">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1294">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1293">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1292">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1291">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1290">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1289">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1288">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1287">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1286">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1285">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1284">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1283">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1282">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_LUEID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mm"
                 priority="1281">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'GrundAnmeldungSchluessel', 'AnlaesseUmmeldung', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr"
                 priority="1280">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1279">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1278">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1277">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1276">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1275">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1274">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1273">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1272">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1271">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1270">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1269">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1268">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1267">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1266">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1265">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1264">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1263">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1262">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1261">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1260">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1259">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1258">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1257">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1256">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1255">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1254">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1253">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1252">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1251">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1250">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1249">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1248">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1247">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1246">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1245">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1244">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1243">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1242">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1241">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1240">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1239">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1238">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1237">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1236">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1235">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_LUEID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'LUEID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1234">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_LUEID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]"
                 priority="1233">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'RGID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'Satzart'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'RGID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'Satzart'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung L09.10 (BerEmpfaenger = 'RGID' UND MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'RGID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3' or not(exists(d:mm[@name eq 'Satzart']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'RGID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' or not(exists(d:mm[@name eq 'Satzart']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_RGIDSatzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung L09.10 (BerEmpfaenger = 'RGID' UND MeldungArt = 3) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L09.01 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L09.39 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1232">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtIndustrie']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandwerk']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtHandel']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtHandel']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BetriebArtSonstiges']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NiederlassungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NiederlassungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'IstReisegewerbe']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'IstReisegewerbe']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1231">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1230">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1229">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1228">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnzahlBeteiligte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1227">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1226">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Handwerkskarte']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Handwerkskarte: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1225">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1224">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1223">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1222">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1221">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1220">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1219">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1218">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1217">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_RGID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mm"
                 priority="1216">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'GrundAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr"
                 priority="1215">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1214">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1213">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1212">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1211">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1210">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1209">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1208">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1207">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1206">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1205">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1204">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1203">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1202">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1201">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1200">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1199">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1198">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1197">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1196">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1195">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1194">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1193">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1192">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1191">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1190">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1189">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1188">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1187">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1186">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1185">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1184">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_RGID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'RGID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1183">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_RGID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]"
                 priority="1182">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Satzart']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Satzart']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L04.01 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnlaesseUmmeldung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_AnlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnlaesseUmmeldung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L04.04 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3') or exists(d:mm[@name eq 'GrundAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_GrundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAbmeldungSchluessel: Die Bedingung L04.05 (MeldungArt = 3) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_UrsacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldung: Die Bedingung L04.06 (MeldungArt = 3 UND UrsacheAbmeldungSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '3'  and  not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '3' and not(exists(d:mm[@name eq 'UrsacheAbmeldung']/d:wert))) or exists(d:mm[@name eq 'UrsacheAbmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_UrsacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UrsacheAbmeldungSchluessel: Die Bedingung L04.07 (MeldungArt = 3 UND UrsacheAbmeldung = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1181">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtIndustrie'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Die Bedingung L04.31 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandwerk'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Die Bedingung L04.32 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtHandel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Die Bedingung L04.33 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert = ('1','3')) or exists(d:mm[@name eq 'BetriebArtSonstiges'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Die Bedingung L04.34 (MeldungArt IN {1,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_STAID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'VertretungsberechtigtePerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_STAID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung E08.04 (NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1180">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1179">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1178">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1177">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1176">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1175">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1174">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1173">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1172">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1171">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1170">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsname']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsname']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsdatum']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsdatum']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsort']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsort']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'Geburtsland']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'Geburtsland']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Erlaubnis']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Erlaubnis']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Erlaubnis: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Aufenthaltsgenehmigung']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Aufenthaltsgenehmigung: Merkmalsgruppe ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1169">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1168">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1167">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1166">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1165">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1164">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1163">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1162">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1161">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1160">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']"
                 priority="1159">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GrundUmmeldungSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_GruendeUmmeldung_GrundUmmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundUmmeldungSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']"
                 priority="1158">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NameFirmaGewerbetreibender']))">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1157">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_KuenftigesGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1156">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_STAID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mm"
                 priority="1155">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'AnlaesseUmmeldung', 'GrundAnmeldungSchluessel', 'GrundAbmeldungSchluessel', 'UrsacheAbmeldung', 'UrsacheAbmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr"
                 priority="1154">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'GruendeUmmeldung', 'KuenftigesGewerbe', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1153">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1152">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1151">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1150">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1149">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1148">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1147">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1146">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1145">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1144">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1143">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1142">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1141">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1140">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1139">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1138">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1137">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1136">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1135">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1134">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1133">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1132">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1131">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1130">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1129">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1128">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1127">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1126">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1125">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1124">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1123">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1122">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1121">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1120">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1119">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1118">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1117">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1116">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1115">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1114">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1113">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1112">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1111">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1110">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mm"
                 priority="1109">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('GrundUmmeldungSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('GrundUmmeldungSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('GrundUmmeldungSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'GruendeUmmeldung']/d:mmgr"
                 priority="1108">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_GruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mm"
                 priority="1107">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr"
                 priority="1106">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_KuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1105">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'KuenftigesGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1104">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_KuenftigesGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1103">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_STAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'STAID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1102">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_STAID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]"
                 priority="1101">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'ZVID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert)) or exists(d:mm[@name eq 'Satzart'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'ZVID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert)) or exists(d:mm[@name eq 'Satzart'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Satzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung L10.04 (BerEmpfaenger = 'ZVID' UND MeldungArt = 1 UND Verdachtsmomente[1].VerdachtsmomentSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert  eq  'ZVID'  and  d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert) or not(exists(d:mm[@name eq 'Satzart']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:nachricht/d:hmm[@name eq 'BerEmpfaenger'][1]/d:wert eq 'ZVID' and d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and exists(d:mmgr[@name eq 'Verdachtsmomente'][1]/d:mm[@name eq 'VerdachtsmomentSchluessel']/d:wert) or not(exists(d:mm[@name eq 'Satzart']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVIDSatzart</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Satzart: Die Bedingung L10.04 (BerEmpfaenger = 'ZVID' UND MeldungArt = 1 UND Verdachtsmomente[1].VerdachtsmomentSchluessel /= LEER) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'SatzErstellung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'SatzErstellung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_SatzErstellung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SatzErstellung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'MeldungArt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'MeldungArt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_MeldungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal MeldungArt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstKorrektur']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstKorrektur']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_IstKorrektur</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstKorrektur: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstKorrektur'][1]/d:wert eq '1') or exists(d:mm[@name eq 'KorrekturGrundSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_KorrekturGrundSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal KorrekturGrundSchluessel: Die Bedingung L10.01 (IstKorrektur = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GemeindeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GemeindeZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AGSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_AGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AGSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GemeindeMeldungNr']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GemeindeMeldungNr: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1') or exists(d:mm[@name eq 'GrundAnmeldungSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_GrundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GrundAnmeldungSchluessel: Die Bedingung L10.12 (MeldungArt = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GewerbebetriebID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GewerbebetriebID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'UUID']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'UUID']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_UUID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal UUID: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Gewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Gewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Gewerbe: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GueltigAb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GueltigAb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_GueltigAb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GueltigAb: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'DatumMeldung']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'DatumMeldung']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_DatumMeldung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal DatumMeldung: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'TaetigkeitenGesamt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe TaetigkeitenGesamt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'FrueheresGewerbe']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe FrueheresGewerbe: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FKSSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FKSSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FKSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FKSSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomenteText']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_VerdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomenteText: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Verdachtsmomente']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Verdachtsmomente']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Verdachtsmomente: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']"
                 priority="1100">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlVollzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_AnzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlVollzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlTeilzeitBeschaeftigte']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_AnzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlTeilzeitBeschaeftigte: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtIndustrie']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtIndustrie']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BetriebArtIndustrie</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtIndustrie: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtHandwerk']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtHandwerk']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BetriebArtHandwerk</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandwerk: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtHandel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtHandel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BetriebArtHandel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtHandel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebArtSonstiges']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebArtSonstiges']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BetriebArtSonstiges</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebArtSonstiges: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0') or exists(d:mm[@name eq 'NiederlassungArt'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0') or exists(d:mm[@name eq 'NiederlassungArt'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_NiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  eq  '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="d:mm[@name eq 'IstReisegewerbe'][1]/d:wert eq '0' or not(exists(d:mm[@name eq 'NiederlassungArt']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVID_GewerbeNiederlassungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NiederlassungArt: Die Bedingung E08.07 (IstReisegewerbe = 0) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstReisegewerbe']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_IstReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstReisegewerbe: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'VertretungsberechtigtePerson']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe VertretungsberechtigtePerson: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' )) or exists(d:mmgr[@name eq 'Anschrift'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not((empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' )) or exists(d:mmgr[@name eq 'Anschrift'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or  d:mm[@name eq 'IstReisegewerbe'][1]/d:wert  ne  '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="(empty( d:mm[@name eq 'IstReisegewerbe']/d:wert ) or d:mm[@name eq 'IstReisegewerbe'][1]/d:wert ne '1' ) or not(exists(d:mmgr[@name eq 'Anschrift']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVID_GewerbeAnschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Die Bedingung E08.09 (IstReisegewerbe /= 1) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3')) or exists(d:mmgr[@name eq 'Hauptniederlassung'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung L10.11 (MeldungArt = 1 UND Gewerbe[1].NiederlassungArt IN {2,3}) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert  eq  '1'  and  ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3') or not(exists(d:mmgr[@name eq 'Hauptniederlassung']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="ancestor::d:satz/d:mm[@name eq 'MeldungArt'][1]/d:wert eq '1' and ancestor::d:satz/d:mmgr[@name eq 'Gewerbe'][1]/d:mm[@name eq 'NiederlassungArt'][1]/d:wert = ('2','3') or not(exists(d:mmgr[@name eq 'Hauptniederlassung']))">
               <xsl:attribute name="id">STRICT_CONDITIONAL_OCCURRENCE_OF_ZVID_GewerbeHauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Hauptniederlassung: Die Bedingung L10.11 (MeldungArt = 1 UND Gewerbe[1].NiederlassungArt IN {2,3}) ist nicht erfüllt, so dass das Merkmal / die Merkmalsgruppe nicht angegeben werden darf.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']"
                 priority="1099">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1098">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1097">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']"
                 priority="1096">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_VertretungsberechtigtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_VertretungsberechtigtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1095">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']"
                 priority="1094">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']"
                 priority="1093">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_Hauptniederlassung_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1092">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1091">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1090">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1089">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1088">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1087">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']"
                 priority="1086">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstBeteiligtAn']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_IstBeteiligtAn</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstBeteiligtAn: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Betrieb']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Betrieb']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Betrieb: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_EintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumFirma']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_AustrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumFirma: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnzahlBeteiligte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_AnzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnzahlBeteiligte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']"
                 priority="1085">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EingetragenerName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EingetragenerName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EingetragenerName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EingetragenerName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'BetriebsstaettenBezeichnung']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_BetriebsstaettenBezeichnung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BetriebsstaettenBezeichnung: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNr']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNr']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNr</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNr: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungNrAusland']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungNrAusland']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungNrAusland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungNrAusland: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EintragungArt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EintragungArt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_EintragungArt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintragungArt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'GerichtSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'GerichtSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_GerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal GerichtSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'GerichtSchluessel']/d:wert)) or exists(d:mm[@name eq 'RGGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_RGGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RGGSchluesselVerzeichnis: Die Bedingung E05.05 (GerichtSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RechtsformSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_RechtsformSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RechtsformSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'RFMSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Betrieb_RFMSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal RFMSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']"
                 priority="1084">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PersonFunktion']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PersonFunktion']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_PersonFunktion</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PersonFunktion: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnredeSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnredeSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AnredeSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnredeSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AnredeSchluessel']/d:wert)) or exists(d:mm[@name eq 'ANRSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_ANRSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ANRSchluesselVerzeichnis: Die Bedingung E04.03 (AnredeSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'TITSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_TITSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TITSchluesselVerzeichnis: Die Bedingung E04.04 (TitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Titel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Titel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Titel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Titel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Familienname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Familienname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Familienname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Familienname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Vorname']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Vorname']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Vorname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Vorname: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NamenZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NamenZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NamenZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NamenZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NachtitelSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NachtitelSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NachtitelSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'NachtitelSchluessel']/d:wert)) or exists(d:mm[@name eq 'NTTSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_NTTSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NTTSchluesselVerzeichnis: Die Bedingung E04.05 (NachtitelSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geschlecht']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geschlecht']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geschlecht</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geschlecht: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsname']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsname']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsname</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsname: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsdatum']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsdatum']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsdatum: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Geburtsland']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Geburtsland']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Geburtsland</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Geburtsland: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'IstNebenerwerb']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'IstNebenerwerb']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_IstNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal IstNebenerwerb: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EintrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_EintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EintrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'AustrittsdatumPerson']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_AustrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AustrittsdatumPerson: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Staatangehoerigkeiten']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Staatangehoerigkeiten: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mmgr[@name eq 'Staatangehoerigkeiten'][1]/d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'SGSSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_SGSSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal SGSSchluesselVerzeichnis: Die Bedingung E04.10 (Staatangehoerigkeiten[1].StaatsangehoerigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) ge 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) ge 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird mindestens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']"
                 priority="1083">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel']/d:wert))) or exists(d:mm[@name eq 'Staatsangehoerigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_Staatsangehoerigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Staatsangehoerigkeit: Die Bedingung E15.01 (StaatsangehoerigkeitSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'Staatsangehoerigkeit']/d:wert))) or exists(d:mm[@name eq 'StaatsangehoerigkeitSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten_StaatsangehoerigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal StaatsangehoerigkeitSchluessel: Die Bedingung E15.02 (Staatsangehoerigkeit = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']"
                 priority="1082">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1081">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1080">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']"
                 priority="1079">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Auflagen']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Auflagen']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung_Auflagen</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Auflagen: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']"
                 priority="1078">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']"
                 priority="1077">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1') or exists(d:mm[@name eq 'AusgestelltAm'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1') or exists(d:mm[@name eq 'AusgestelltAm'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Die Bedingung E10.01 (Status = 1) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonSchluessel']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonName'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Die Bedingung E10.02 (Status = 1 UND AusgestelltVonSchluessel = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'AusgestelltVonSchluessel'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_AusgestelltVonSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonSchluessel: Die Bedingung E10.03 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(d:mm[@name eq 'Status'][1]/d:wert  eq  '1'  and  not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(d:mm[@name eq 'Status'][1]/d:wert eq '1' and not(exists(d:mm[@name eq 'AusgestelltVonName']/d:wert))) or exists(d:mm[@name eq 'HWKSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_HWKSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HWKSchluesselVerzeichnis: Die Bedingung E10.04 (Status = 1 UND AusgestelltVonName = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'ArtHandwerkskarte']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte_ArtHandwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal ArtHandwerkskarte: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']"
                 priority="1076">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Status']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Status']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_Status</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Status: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltAm']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltAm']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltAm</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltAm: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonName']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonName']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonName</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonName: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AusgestelltVonOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis_AusgestelltVonOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AusgestelltVonOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']"
                 priority="1075">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Schwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Schwerpunkt: Merkmalsgruppe wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Taetigkeiten']) le 2">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeiten: Merkmalsgruppe wird höchstens 2 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']"
                 priority="1074">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchwerpunkt']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchwerpunkt: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E13.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Schwerpunkt_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']"
                 priority="1073">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(count(d:mmgr[@name eq 'Taetigkeit'])  eq  0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(count(d:mmgr[@name eq 'Taetigkeit']) eq 0) or exists(d:mm[@name eq 'TaetigkeitenZusammengefasst'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_TaetigkeitenZusammengefasst</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitenZusammengefasst: Die Bedingung E17.01 (ANZAHL VON Taetigkeit = 0) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NeuAusgeuebt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_NeuAusgeuebt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NeuAusgeuebt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(not(exists(d:mm[@name eq 'TaetigkeitenZusammengefasst']/d:wert))) or exists(d:mmgr[@name eq 'Taetigkeit'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Taetigkeit: Die Bedingung E17.02 (TaetigkeitenZusammengefasst = LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']"
                 priority="1072">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitEinzeln']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitEinzeln: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TaetigkeitSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_TaetigkeitSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TaetigkeitSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'TaetigkeitSchluessel']/d:wert)) or exists(d:mm[@name eq 'WZGSchluesselVerzeichnis'])">
               <xsl:attribute name="id">CONDITIONAL_OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_WZGSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WZGSchluesselVerzeichnis: Die Bedingung E16.01 (TaetigkeitSchluessel /= LEER) ist erfüllt, so dass das Merkmal / die Merkmalsgruppe angegeben werden muss.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Stichwort']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Stichwort']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_Stichwort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Stichwort: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'STWVerzeichnis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'STWVerzeichnis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_STWVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal STWVerzeichnis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'BeginnTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_BeginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal BeginnTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))"/>
         <xsl:otherwise>
            <svrl:failed-assert test="not(exists(d:mm[@name eq 'EndeTaetigkeit']))">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit_EndeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EndeTaetigkeit: Merkmal ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']"
                 priority="1071">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NameFirmaGewerbetreibender']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_NameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NameFirmaGewerbetreibender: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mmgr[@name eq 'Anschrift']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mmgr[@name eq 'Anschrift']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe Anschrift: Merkmalsgruppe wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']"
                 priority="1070">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strasse']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strasse']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_Strasse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strasse: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Strassenschluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Strassenschluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_Strassenschluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Strassenschluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrVon']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrVon']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_HausNrVon</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrVon: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'HausNrBis']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'HausNrBis']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_HausNrBis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal HausNrBis: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'AnschriftZusatz']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'AnschriftZusatz']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_AnschriftZusatz</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal AnschriftZusatz: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ort']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ort']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_Ort</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ort: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Ortsteil']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Ortsteil']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_Ortsteil</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Ortsteil: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_PLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NationSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NationSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_NationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NationSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'NATSchluesselVerzeichnis']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_NATSchluesselVerzeichnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal NATSchluesselVerzeichnis: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachPLZ']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachPLZ']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_PostfachPLZ</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachPLZ: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_PostfachOrt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachOrtNationSchluessel']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_PostfachOrtNationSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachOrtNationSchluessel: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'PostfachNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'PostfachNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_PostfachNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal PostfachNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_TelefonVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'TelefonNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'TelefonNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_TelefonNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal TelefonNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxVorwahl']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxVorwahl']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_FaxVorwahl</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxVorwahl: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'FaxNummer']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'FaxNummer']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_FaxNummer</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal FaxNummer: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'EMailAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'EMailAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_EMailAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal EMailAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'WebAdresse']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'WebAdresse']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_FrueheresGewerbe_Anschrift_WebAdresse</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal WebAdresse: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']"
                 priority="1069">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'VerdachtsmomentSchluessel']) eq 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_Verdachtsmomente_VerdachtsmomentSchluessel</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal VerdachtsmomentSchluessel: Merkmal wird genau 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']"
                 priority="1068">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Begriff']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Begriff']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_SpezifischeInformation_Begriff</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Begriff: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(d:mm[@name eq 'Inhalt']) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert test="count(d:mm[@name eq 'Inhalt']) le 1">
               <xsl:attribute name="id">OCCURRENCE_OF_ZVID_SpezifischeInformation_Inhalt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal Inhalt: Merkmal wird höchstens 1 mal erwartet.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mm"
                 priority="1067">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'VerdachtsmomenteText')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'VerdachtsmomenteText')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Satzart', 'SatzErstellung', 'MeldungArt', 'IstKorrektur', 'KorrekturGrundSchluessel', 'GemeindeSchluessel', 'GemeindeZusatz', 'AGSSchluesselVerzeichnis', 'GemeindeMeldungNr', 'GrundAnmeldungSchluessel', 'GewerbebetriebID', 'UUID', 'GueltigAb', 'DatumMeldung', 'FKSSchluesselVerzeichnis', 'VerdachtsmomenteText').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr"
                 priority="1066">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Gewerbe', 'TaetigkeitenGesamt', 'FrueheresGewerbe', 'Verdachtsmomente', 'SpezifischeInformation').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mm"
                 priority="1065">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('AnzahlBeteiligte', 'AnzahlVollzeitBeschaeftigte', 'AnzahlTeilzeitBeschaeftigte', 'BetriebArtIndustrie', 'BetriebArtHandwerk', 'BetriebArtHandel', 'BetriebArtSonstiges', 'NiederlassungArt', 'IstReisegewerbe', 'IstNebenerwerb').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr"
                 priority="1064">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'Handwerkskarte', 'Erlaubnis', 'VertretungsberechtigtePerson', 'Anschrift', 'Hauptniederlassung', 'BeteiligtePerson', 'BeteiligteFirma').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1063">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1062">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1061">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1060">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1059">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1058">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mm"
                 priority="1057">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Familienname', 'Vorname')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Familienname', 'Vorname')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Familienname', 'Vorname').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'VertretungsberechtigtePerson']/d:mmgr"
                 priority="1056">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_VertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1055">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1054">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mm"
                 priority="1053">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr"
                 priority="1052">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1051">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'Hauptniederlassung']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1050">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_Hauptniederlassung_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1049">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1048">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1047">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1046">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1045">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1044">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1043">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1042">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1041">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1040">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1039">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1038">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mm"
                 priority="1037">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('IstBeteiligtAn', 'EintrittsdatumFirma', 'AustrittsdatumFirma', 'AnzahlBeteiligte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr"
                 priority="1036">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Betrieb', 'BeteiligtePerson', 'Anschrift', 'Handwerkskarte', 'Erlaubnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mm"
                 priority="1035">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('EingetragenerName', 'BetriebsstaettenBezeichnung', 'EintragungNr', 'EintragungNrAusland', 'EintragungOrt', 'EintragungPLZ', 'EintragungArt', 'GerichtSchluessel', 'RGGSchluesselVerzeichnis', 'RechtsformSchluessel', 'RFMSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Betrieb']/d:mmgr"
                 priority="1034">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_Betrieb</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mm"
                 priority="1033">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('PersonFunktion', 'AnredeSchluessel', 'ANRSchluesselVerzeichnis', 'TitelSchluessel', 'TITSchluesselVerzeichnis', 'Titel', 'Familienname', 'Vorname', 'NamenZusatz', 'NachtitelSchluessel', 'NTTSchluesselVerzeichnis', 'Geschlecht', 'Geburtsname', 'Geburtsdatum', 'Geburtsort', 'Geburtsland', 'IstNebenerwerb', 'EintrittsdatumPerson', 'AustrittsdatumPerson', 'SGSSchluesselVerzeichnis').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr"
                 priority="1032">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Staatangehoerigkeiten', 'Anschrift', 'Handwerkskarte', 'Erlaubnis', 'Aufenthaltsgenehmigung').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mm"
                 priority="1031">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Staatsangehoerigkeit', 'StaatsangehoerigkeitSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Staatangehoerigkeiten']/d:mmgr"
                 priority="1030">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1029">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1028">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1027">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1026">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1025">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1024">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mm"
                 priority="1023">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'Auflagen').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'BeteiligtePerson']/d:mmgr[@name eq 'Aufenthaltsgenehmigung']/d:mmgr"
                 priority="1022">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_BeteiligtePerson_Aufenthaltsgenehmigung</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1021">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1020">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mm"
                 priority="1019">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt', 'AusgestelltVonSchluessel', 'HWKSchluesselVerzeichnis', 'ArtHandwerkskarte').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Handwerkskarte']/d:mmgr"
                 priority="1018">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_Handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mm"
                 priority="1017">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Status', 'AusgestelltAm', 'AusgestelltVonName', 'AusgestelltVonPLZ', 'AusgestelltVonOrt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Gewerbe']/d:mmgr[@name eq 'BeteiligteFirma']/d:mmgr[@name eq 'Erlaubnis']/d:mmgr"
                 priority="1016">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Gewerbe_BeteiligteFirma_Erlaubnis</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mm"
                 priority="1015">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr"
                 priority="1014">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Schwerpunkt', 'Taetigkeiten')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Schwerpunkt', 'Taetigkeiten')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Schwerpunkt', 'Taetigkeiten').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mm"
                 priority="1013">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitSchwerpunkt', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Schwerpunkt']/d:mmgr"
                 priority="1012">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt_Schwerpunkt</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mm"
                 priority="1011">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitenZusammengefasst', 'NeuAusgeuebt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr"
                 priority="1010">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Taetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Taetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt_Taetigkeiten</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Taetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mm"
                 priority="1009">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('TaetigkeitEinzeln', 'TaetigkeitSchluessel', 'WZGSchluesselVerzeichnis', 'Stichwort', 'STWVerzeichnis', 'BeginnTaetigkeit', 'EndeTaetigkeit').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'TaetigkeitenGesamt']/d:mmgr[@name eq 'Taetigkeiten']/d:mmgr[@name eq 'Taetigkeit']/d:mmgr"
                 priority="1008">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_TaetigkeitenGesamt_Taetigkeiten_Taetigkeit</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mm"
                 priority="1007">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('NameFirmaGewerbetreibender')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('NameFirmaGewerbetreibender')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('NameFirmaGewerbetreibender').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr"
                 priority="1006">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Anschrift')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Anschrift')">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_FrueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ('Anschrift').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mm"
                 priority="1005">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Strasse', 'Strassenschluessel', 'HausNrVon', 'HausNrBis', 'AnschriftZusatz', 'Ort', 'Ortsteil', 'PLZ', 'NationSchluessel', 'NATSchluesselVerzeichnis', 'PostfachPLZ', 'PostfachOrt', 'PostfachOrtNationSchluessel', 'PostfachNummer', 'TelefonVorwahl', 'TelefonNummer', 'FaxVorwahl', 'FaxNummer', 'EMailAdresse', 'WebAdresse').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'FrueheresGewerbe']/d:mmgr[@name eq 'Anschrift']/d:mmgr"
                 priority="1004">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_FrueheresGewerbe_Anschrift</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mm"
                 priority="1003">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('VerdachtsmomentSchluessel')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('VerdachtsmomentSchluessel')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('VerdachtsmomentSchluessel').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'Verdachtsmomente']/d:mmgr"
                 priority="1002">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_Verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mm"
                 priority="1001">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ('Begriff', 'Inhalt')"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ('Begriff', 'Inhalt')">
               <xsl:attribute name="id">ALLOWED_VARIABLES_IN_ZVID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmal <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalen ('Begriff', 'Inhalt').</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7"
                 match="d:satz[d:mm[@name eq 'Satzart' and d:wert eq 'ZVID']]/d:mmgr[@name eq 'SpezifischeInformation']/d:mmgr"
                 priority="1000">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@name = ()"/>
         <xsl:otherwise>
            <svrl:failed-assert test="@name = ()">
               <xsl:attribute name="id">ALLOWED_VARIABLEGROUPS_IN_ZVID_SpezifischeInformation</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates mode="M_00041740059999000001schematron-select-full-path" select="."/>
               </xsl:attribute>
               <svrl:text>Merkmalsgruppe <xsl:text/>
                  <xsl:value-of select="@name"/>
                  <xsl:text/>: gehört nicht zu den hier zulässigen Merkmalsgruppen ().</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
   <xsl:template mode="M_00041740059999000001M7" match="text()" priority="-1"/>
   <xsl:template mode="M_00041740059999000001M7" match="@*|node()" priority="-2">
      <xsl:apply-templates mode="M_00041740059999000001M7" select="*"/>
   </xsl:template>
</xsl:stylesheet>
