<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:xga="http://www.xgewerbeanzeige.de/spezifikation/2.0"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path-2"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title=""
                              schemaVersion="2.0">
         <svrl:ns-prefix-in-attribute-values uri="http://www.xgewerbeanzeige.de/spezifikation/2.0" prefix="xga"/>
         <xsl:apply-templates select="/" mode="M1"/>
         <xsl:apply-templates select="/" mode="M2"/>
         <xsl:apply-templates select="/" mode="M3"/>
         <xsl:apply-templates select="/" mode="M4"/>
         <xsl:apply-templates select="/" mode="M5"/>
         <xsl:apply-templates select="/" mode="M6"/>
         <xsl:apply-templates select="/" mode="M7"/>
         <xsl:apply-templates select="/" mode="M8"/>
         <xsl:apply-templates select="/" mode="M9"/>
         <xsl:apply-templates select="/" mode="M10"/>
         <xsl:apply-templates select="/" mode="M11"/>
         <xsl:apply-templates select="/" mode="M12"/>
         <xsl:apply-templates select="/" mode="M13"/>
         <xsl:apply-templates select="/" mode="M14"/>
         <xsl:apply-templates select="/" mode="M15"/>
         <xsl:apply-templates select="/" mode="M16"/>
         <xsl:apply-templates select="/" mode="M17"/>
         <xsl:apply-templates select="/" mode="M18"/>
         <xsl:apply-templates select="/" mode="M19"/>
         <xsl:apply-templates select="/" mode="M20"/>
         <xsl:apply-templates select="/" mode="M21"/>
         <xsl:apply-templates select="/" mode="M22"/>
         <xsl:apply-templates select="/" mode="M23"/>
         <xsl:apply-templates select="/" mode="M24"/>
         <xsl:apply-templates select="/" mode="M25"/>
         <xsl:apply-templates select="/" mode="M26"/>
         <xsl:apply-templates select="/" mode="M27"/>
         <xsl:apply-templates select="/" mode="M28"/>
         <xsl:apply-templates select="/" mode="M29"/>
         <xsl:apply-templates select="/" mode="M30"/>
         <xsl:apply-templates select="/" mode="M31"/>
         <xsl:apply-templates select="/" mode="M32"/>
         <xsl:apply-templates select="/" mode="M33"/>
         <xsl:apply-templates select="/" mode="M34"/>
         <xsl:apply-templates select="/" mode="M35"/>
         <xsl:apply-templates select="/" mode="M36"/>
         <xsl:apply-templates select="/" mode="M37"/>
         <xsl:apply-templates select="/" mode="M38"/>
         <xsl:apply-templates select="/" mode="M39"/>
         <xsl:apply-templates select="/" mode="M40"/>
         <xsl:apply-templates select="/" mode="M41"/>
         <xsl:apply-templates select="/" mode="M42"/>
         <xsl:apply-templates select="/" mode="M43"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300//xga:abmeldung"
                 priority="1108"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300//xga:anmeldung"
                 priority="1107"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300//xga:ummeldung"
                 priority="1106"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300//xga:beteiligtePerson"
                 priority="1105"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300//xga:gewerbe"
                 priority="1104"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300//xga:kuenftigesGewerbe"
                 priority="1103"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-alg.gewerbemeldung.0300-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:abmeldung"
                 priority="1102"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Abmeldung-ursacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldungSchluessel)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Abmeldung-ursacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldungSchluessel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:anmeldung"
                 priority="1101"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:ummeldung"
                 priority="1100"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:beteiligteFirma"
                 priority="1099"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligteFirma-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligteFirma-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:beteiligtePerson"
                 priority="1098"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligtePerson-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligtePerson-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:schwerpunkt"
                 priority="1097"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:gewerbe"
                 priority="1096"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Gewerbe-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Gewerbe-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Gewerbe-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:kuenftigesGewerbe"
                 priority="1095"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-as.gewerbemeldung.0280-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280//xga:taetigkeit"
                 priority="1094"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-as.gewerbemeldung.0280-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:abmeldung"
                 priority="1093"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:anmeldung"
                 priority="1092"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:ummeldung"
                 priority="1091"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:beteiligteFirma"
                 priority="1090"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-BeteiligteFirma-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-BeteiligteFirma-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:beteiligtePerson"
                 priority="1089"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-BeteiligtePerson-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:schwerpunkt"
                 priority="1088"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:gewerbe"
                 priority="1087"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Gewerbe-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Gewerbe-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:kuenftigesGewerbe"
                 priority="1086"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-dgu.gewerbemeldung.0230-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230//xga:taetigkeit"
                 priority="1085"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-dgu.gewerbemeldung.0230-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:abmeldung"
                 priority="1084"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:datumMeldung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:kuenftigesGewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:kuenftigesGewerbe)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Abmeldung-kuenftigesGewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:kuenftigesGewerbe darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Abmeldung-ursacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldungSchluessel)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Abmeldung-ursacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldungSchluessel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:anmeldung"
                 priority="1083"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:datumMeldung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:frueheresGewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:frueheresGewerbe)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Anmeldung-frueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:frueheresGewerbe darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:ummeldung"
                 priority="1082"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:datumMeldung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:frueheresGewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:frueheresGewerbe)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Ummeldung-frueheresGewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:frueheresGewerbe darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anlaesseUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anlaesseUmmeldung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Ummeldung-anlaesseUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anlaesseUmmeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:beteiligteFirma"
                 priority="1081"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligteFirma-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligteFirma-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligteFirma-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:beteiligtePerson"
                 priority="1080"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geschlecht)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsname)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsname)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-geburtsname</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsname darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsdatum)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsort)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsland)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-BeteiligtePerson-istNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istNebenerwerb darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-ea.gewerbemeldung.0220-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:betrieb"
                 priority="1079"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:eintragungNr)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Betrieb-eintragungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintragungNr darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintragungOrt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:eintragungOrt)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Betrieb-eintragungOrt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintragungOrt darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintragungPLZ)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:eintragungPLZ)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Betrieb-eintragungPLZ</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintragungPLZ darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintragungArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:eintragungArt)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Betrieb-eintragungArt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintragungArt darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Betrieb-gerichtSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gerichtSchluessel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Betrieb-eintragungNrSonstige</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintragungNrSonstige darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:schwerpunkt"
                 priority="1078"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:gewerbe"
                 priority="1077"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:betriebArt)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-betriebArt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:betriebArt darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:hauptniederlassung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:hauptniederlassung)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-hauptniederlassung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:hauptniederlassung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-istNebenerwerb</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istNebenerwerb darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istReisegewerbe)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:niederlassungArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:niederlassungArt)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-niederlassungArt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:niederlassungArt darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220//xga:taetigkeit"
                 priority="1076"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-ea.gewerbemeldung.0220-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400//xga:abmeldung"
                 priority="1075"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400//xga:anmeldung"
                 priority="1074"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400//xga:ummeldung"
                 priority="1073"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400//xga:beteiligtePerson"
                 priority="1072"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400//xga:schwerpunkt"
                 priority="1071"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ext.gewerbemeldung.0400-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ext.gewerbemeldung.0400-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400//xga:gewerbe"
                 priority="1070"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400//xga:kuenftigesGewerbe"
                 priority="1069"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-ext.gewerbemeldung.0400-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400//xga:taetigkeit"
                 priority="1068"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ext.gewerbemeldung.0400-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ext.gewerbemeldung.0400-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:abmeldung"
                 priority="1067"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:anmeldung"
                 priority="1066"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:ummeldung"
                 priority="1065"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:beteiligteFirma"
                 priority="1064"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:beteiligtePerson"
                 priority="1063"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:schwerpunkt"
                 priority="1062"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:gewerbe"
                 priority="1061"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Gewerbe-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Gewerbe-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:kuenftigesGewerbe"
                 priority="1060"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-fa.gewerbemeldung.0250-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250//xga:taetigkeit"
                 priority="1059"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-fa.gewerbemeldung.0250-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:abmeldung"
                 priority="1058"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:anmeldung"
                 priority="1057"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:ummeldung"
                 priority="1056"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:beteiligteFirma"
                 priority="1055"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:beteiligtePerson"
                 priority="1054"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:schwerpunkt"
                 priority="1053"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:gewerbe"
                 priority="1052"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:kuenftigesGewerbe"
                 priority="1051"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-hwk.gewerbemeldung.0210-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210//xga:taetigkeit"
                 priority="1050"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-hwk.gewerbemeldung.0210-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:abmeldung"
                 priority="1049"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:anmeldung"
                 priority="1048"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:ummeldung"
                 priority="1047"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:beteiligteFirma"
                 priority="1046"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-BeteiligteFirma-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:beteiligtePerson"
                 priority="1045"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-BeteiligtePerson-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:schwerpunkt"
                 priority="1044"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:gewerbe"
                 priority="1043"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Gewerbe-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:kuenftigesGewerbe"
                 priority="1042"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-ihk.gewerbemeldung.0200-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200//xga:taetigkeit"
                 priority="1041"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-ihk.gewerbemeldung.0200-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:abmeldung"
                 priority="1040"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Abmeldung-ursacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldungSchluessel)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Abmeldung-ursacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldungSchluessel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:anmeldung"
                 priority="1039"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:ummeldung"
                 priority="1038"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:beteiligteFirma"
                 priority="1037"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligteFirma-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligteFirma-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligteFirma-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:beteiligtePerson"
                 priority="1036"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligtePerson-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligtePerson-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:schwerpunkt"
                 priority="1035"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:gewerbe"
                 priority="1034"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Gewerbe-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Gewerbe-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Gewerbe-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:kuenftigesGewerbe"
                 priority="1033"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-is.gewerbemeldung.0270-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270//xga:taetigkeit"
                 priority="1032"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-is.gewerbemeldung.0270-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:abmeldung"
                 priority="1031"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Abmeldung-ursacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldungSchluessel)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Abmeldung-ursacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldungSchluessel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:anmeldung"
                 priority="1030"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:ummeldung"
                 priority="1029"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:beteiligteFirma"
                 priority="1028"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligteFirma-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligteFirma-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:beteiligtePerson"
                 priority="1027"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligtePerson-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligtePerson-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:schwerpunkt"
                 priority="1026"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:gewerbe"
                 priority="1025"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Gewerbe-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Gewerbe-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Gewerbe-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:kuenftigesGewerbe"
                 priority="1024"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-lue.gewerbemeldung.0290-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290//xga:taetigkeit"
                 priority="1023"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-lue.gewerbemeldung.0290-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240//xga:abmeldung"
                 priority="1022"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:datumMeldung)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-rg.gewerbemeldung.0240-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-rg.gewerbemeldung.0240-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-rg.gewerbemeldung.0240-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Abmeldung-ursacheAbmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:ursacheAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:ursacheAbmeldungSchluessel)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Abmeldung-ursacheAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:ursacheAbmeldungSchluessel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-rg.gewerbemeldung.0240-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240//xga:beteiligteFirma"
                 priority="1021"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligteFirma-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligteFirma-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligteFirma-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240//xga:beteiligtePerson"
                 priority="1020"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsdatum)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsort)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsland)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-rg.gewerbemeldung.0240-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-rg.gewerbemeldung.0240-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240//xga:schwerpunkt"
                 priority="1019"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240//xga:gewerbe"
                 priority="1018"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlBeteiligte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlBeteiligte)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-anzahlBeteiligte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlBeteiligte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:betriebArt)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-betriebArt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:betriebArt darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:handwerkskarte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:handwerkskarte)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-handwerkskarte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:handwerkskarte darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istReisegewerbe)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:vertretungsberechtigtePerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:vertretungsberechtigtePerson)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-vertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:vertretungsberechtigtePerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:niederlassungArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:niederlassungArt)">
               <xsl:attribute name="id">REQUIRED-rg.gewerbemeldung.0240-Gewerbe-niederlassungArt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:niederlassungArt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240//xga:kuenftigesGewerbe"
                 priority="1017"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">REQUIRED-rg.gewerbemeldung.0240-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240//xga:taetigkeit"
                 priority="1016"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-rg.gewerbemeldung.0240-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:abmeldung"
                 priority="1015"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAbmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAbmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Abmeldung-grundAbmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAbmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:anmeldung"
                 priority="1014"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomente)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:verdachtsmomenteText)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:verdachtsmomenteText)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Anmeldung-verdachtsmomenteText</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomenteText darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:ummeldung"
                 priority="1013"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gruendeUmmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gruendeUmmeldung)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Ummeldung-gruendeUmmeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gruendeUmmeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:beteiligteFirma"
                 priority="1012"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligteFirma-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:frueheresGewerbe"
                 priority="1011"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-FrueheresGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:beteiligtePerson"
                 priority="1010"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsname)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsname)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-geburtsname</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsname darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsdatum)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsort)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:geburtsland)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:anschrift)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:aufenthaltstitel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:aufenthaltstitel)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-BeteiligtePerson-aufenthaltstitel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:aufenthaltstitel darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:schwerpunkt"
                 priority="1009"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:gewerbe"
                 priority="1008"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:erlaubnis)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty(xga:erlaubnis)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Gewerbe-erlaubnis</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:erlaubnis darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:vertretungsberechtigtePerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:vertretungsberechtigtePerson)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Gewerbe-vertretungsberechtigtePerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:vertretungsberechtigtePerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-sta.gewerbemeldung.0100-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:kuenftigesGewerbe"
                 priority="1007"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:nameFirmaGewerbetreibender)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:nameFirmaGewerbetreibender)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-KuenftigesGewerbe-nameFirmaGewerbetreibender</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:nameFirmaGewerbetreibender darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100//xga:taetigkeit"
                 priority="1006"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-sta.gewerbemeldung.0100-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260//xga:anmeldung"
                 priority="1005"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Gewerbemeldung-taetigkeitenGesamt</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitenGesamt muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:datumMeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:datumMeldung)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Gewerbemeldung-datumMeldung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:datumMeldung muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbebetriebID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbebetriebID)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Gewerbemeldung-gewerbebetriebID</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gewerbebetriebID muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-Gewerbemeldung-bisherigeUnfallversicherung</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:bisherigeUnfallversicherung darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:gemeindeMeldungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gemeindeMeldungNr)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Gewerbemeldung-gemeindeMeldungNr</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:gemeindeMeldungNr muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:grundAnmeldungSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:grundAnmeldungSchluessel)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Anmeldung-grundAnmeldungSchluessel</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:grundAnmeldungSchluessel muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:verdachtsmomente)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:verdachtsmomente)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Anmeldung-verdachtsmomente</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:verdachtsmomente muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260//xga:beteiligteFirma"
                 priority="1004"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-BeteiligteFirma-austrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumFirma)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumFirma)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-BeteiligteFirma-eintrittsdatumFirma</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumFirma darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260//xga:beteiligtePerson"
                 priority="1003"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:eintrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:eintrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-BeteiligtePerson-eintrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:eintrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:austrittsdatumPerson)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:austrittsdatumPerson)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-BeteiligtePerson-austrittsdatumPerson</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:austrittsdatumPerson darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatangehoerigkeiten)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatangehoerigkeiten)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-BeteiligtePerson-staatangehoerigkeiten</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:staatangehoerigkeiten muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:anschrift)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-BeteiligtePerson-anschrift</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anschrift muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geschlecht)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geschlecht)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-BeteiligtePerson-geschlecht</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geschlecht muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsdatum)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsdatum)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-BeteiligtePerson-geburtsdatum</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsdatum muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsort)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsort)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-BeteiligtePerson-geburtsort</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsort muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:geburtsland)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(xga:geburtsland)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-BeteiligtePerson-geburtsland</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:geburtsland muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260//xga:schwerpunkt"
                 priority="1002"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-Schwerpunkt-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-Schwerpunkt-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260//xga:gewerbe"
                 priority="1001"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlTeilzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlTeilzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Gewerbe-anzahlTeilzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlTeilzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:anzahlVollzeitBeschaeftigte)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:anzahlVollzeitBeschaeftigte)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Gewerbe-anzahlVollzeitBeschaeftigte</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:anzahlVollzeitBeschaeftigte muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:istReisegewerbe)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:istReisegewerbe)">
               <xsl:attribute name="id">REQUIRED-zv.gewerbemeldung.0260-Gewerbe-istReisegewerbe</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:istReisegewerbe muss in diesem Kontext angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beteiligungOeffentlicheHand)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beteiligungOeffentlicheHand)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-Gewerbe-beteiligungOeffentlicheHand</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beteiligungOeffentlicheHand darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260//xga:taetigkeit"
                 priority="1000"
                 mode="M1">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:beginnTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:beginnTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-Taetigkeit-beginnTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:beginnTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:endeTaetigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:endeTaetigkeit)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-Taetigkeit-endeTaetigkeit</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:endeTaetigkeit darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:taetigkeitEinzeln)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:taetigkeitEinzeln)">
               <xsl:attribute name="id">FORBIDDEN-zv.gewerbemeldung.0260-Taetigkeit-taetigkeitEinzeln</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Das Kindelement xga:taetigkeitEinzeln darf in diesem Kontext nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M1"/>
   <xsl:template match="@*|node()" priority="-2" mode="M1">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M1"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:abmeldung"
                 priority="1011"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:abmeldung"
                 priority="1010"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:abmeldung"
                 priority="1009"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:abmeldung"
                 priority="1008"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:abmeldung"
                 priority="1007"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:abmeldung"
                 priority="1006"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:abmeldung"
                 priority="1005"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:abmeldung"
                 priority="1004"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:abmeldung"
                 priority="1003"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz/xga:abmeldung"
                 priority="1002"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:abmeldung"
                 priority="1001"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M2">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAbmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251', '260', '270', '280', '290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0152</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0152] Ein Gesellschafteraustritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:grundAbmeldungSchluessel/code = '01' and xga:ursacheAbmeldungSchluessel/code = '16')">
               <xsl:attribute name="id">SCH-0153</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0153] Wenn als Grund die vollständige Aufgabe angegeben wurde, darf als Ursache nicht die Verlegung
in einen anderen Meldebezirk angegeben werden werden. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M2"/>
   <xsl:template match="@*|node()" priority="-2" mode="M2">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M2"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:anmeldung"
                 priority="1011"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:anmeldung"
                 priority="1010"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:anmeldung"
                 priority="1009"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:anmeldung"
                 priority="1008"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:anmeldung"
                 priority="1007"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:anmeldung"
                 priority="1006"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:anmeldung"
                 priority="1005"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:anmeldung"
                 priority="1004"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:anmeldung"
                 priority="1003"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz/xga:anmeldung"
                 priority="1001"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:anmeldung"
                 priority="1000"
                 mode="M3">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '05') then xga:gewerbe/xga:betrieb/xga:rechtsformSchluessel/code = ('210', '211', '220', '221', '222', '223', '230', '231', '232', '240', '241', '242', '250', '251' ,'260' ,'270' ,'280' ,'290', '921', '991') else true()">
               <xsl:attribute name="id">SCH-0151</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0151] Ein Gesellschaftereintritt (Grund "05") darf nur bei Personengesellschaften vorkommen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(descendant::xga:handwerkskarte[xga:status/code = '1'])) then xga:gewerbe/xga:betriebArt/xga:handwerk/code = '1' else true()">
               <xsl:attribute name="id">SCH-0154</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0154] Bei vorliegender aktueller Handwerkskarte muss "Handwerk" bei der Art des Betriebes angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0170</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0170] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M3"/>
   <xsl:template match="@*|node()" priority="-2" mode="M3">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1036"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1035"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1034"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1033"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1032"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1031"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1030"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1029"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1028"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1027"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1026"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1025"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1024"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1023"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1022"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1021"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1020"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1019"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1018"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1017"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1016"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1015"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1014"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1013"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1012"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1011"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1010"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1009"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1008"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1007"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1006"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1005"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1004"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1003"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/*/xga:frueheresGewerbe/xga:anschrift"
                 priority="1002"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/*/xga:gewerbe//xga:anschrift"
                 priority="1001"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/*/xga:kuenftigesGewerbe/xga:anschrift"
                 priority="1000"
                 mode="M4">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:nationSchluessel = '276') then exists(xga:plz) else true()">
               <xsl:attribute name="id">SCH-0005</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0005] Bei einer deutschen Anschrift muss die Postleitzahl angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M4"/>
   <xsl:template match="@*|node()" priority="-2" mode="M4">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:aufenthaltstitel"
                 priority="1012"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:aufenthaltstitel"
                 priority="1011"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:aufenthaltstitel"
                 priority="1010"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:aufenthaltstitel"
                 priority="1009"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:aufenthaltstitel"
                 priority="1008"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:aufenthaltstitel"
                 priority="1007"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:aufenthaltstitel"
                 priority="1006"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:aufenthaltstitel"
                 priority="1005"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:aufenthaltstitel"
                 priority="1004"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:aufenthaltstitel"
                 priority="1003"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:aufenthaltstitel"
                 priority="1002"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:aufenthaltstitel"
                 priority="1001"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:aufenthaltstitel"
                 priority="1000"
                 mode="M5">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0163</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0163] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0168</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0168] Bei An- und Ummeldung muss bei aktuellem Aufenthaltstitel eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M5"/>
   <xsl:template match="@*|node()" priority="-2" mode="M5">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1025"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:behoerdenkennung"
                 priority="1024"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1023"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:behoerdenkennung"
                 priority="1022"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1021"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:behoerdenkennung"
                 priority="1020"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1019"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:behoerdenkennung"
                 priority="1018"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1017"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:behoerdenkennung"
                 priority="1016"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1015"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:behoerdenkennung"
                 priority="1014"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1013"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:behoerdenkennung"
                 priority="1012"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1011"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:behoerdenkennung"
                 priority="1010"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1009"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:behoerdenkennung"
                 priority="1008"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1007"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:behoerdenkennung"
                 priority="1006"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1005"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:behoerdenkennung"
                 priority="1004"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1003"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:behoerdenkennung"
                 priority="1002"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:nachrichtenkopf//xga:behoerdenkennung"
                 priority="1001"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:behoerdenkennung"
                 priority="1000"
                 mode="M6">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'MELDID') then xga:kennung/@listURI = 'urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:ags' else true()">
               <xsl:attribute name="id">SCH-0043</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0043] Eine Behördenkennung mit Präfix MELDID muss einen Behördenschlüssel aus der Codeliste "Amtlicher Gemeindeschlüssel" haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:praefix/code = 'xga') then xga:kennung/@listURI = 'urn:xoev-de:xgewerbeanzeige:codeliste:weiterekommunikationspartner' else true()">
               <xsl:attribute name="id">SCH-0045</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0045] Eine Behördenkennung mit Präfix xga muss einen Behördenschlüssel aus der Codeliste "Weitere Kommunikationspartner XGewerbeanzeige" haben.	</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M6"/>
   <xsl:template match="@*|node()" priority="-2" mode="M6">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1012"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1011"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1010"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1009"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1008"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1007"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1006"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1005"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1004"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1003"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1002"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1001"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:beteiligteFirma/xga:beteiligtePerson"
                 priority="1000"
                 mode="M7">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0090</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0090] Die Angabe istNebenerwerb ist hier nicht zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:betrieb"
                 priority="1012"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:betrieb"
                 priority="1011"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:betrieb"
                 priority="1010"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:betrieb"
                 priority="1009"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:betrieb"
                 priority="1008"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:betrieb"
                 priority="1007"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:betrieb"
                 priority="1006"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:betrieb"
                 priority="1005"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:betrieb"
                 priority="1004"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:betrieb"
                 priority="1003"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:betrieb"
                 priority="1002"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:betrieb"
                 priority="1001"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:betrieb"
                 priority="1000"
                 mode="M8">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:eintragungNr) else empty(xga:eintragungNr)">
               <xsl:attribute name="id">SCH-0155</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0155] Die Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird. </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('A', 'B', 'V', 'G')) then exists(xga:gerichtSchluessel) else empty(xga:gerichtSchluessel)">
               <xsl:attribute name="id">SCH-0156</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0156] Der Gerichtsschlüssel ist dann und nur dann anzugeben, wenn die Eintragungsart "A", "B", "V", oder "G" angegeben wird.  </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungNrSonstige) else empty(xga:eintragungNrSonstige)">
               <xsl:attribute name="id">SCH-0157</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0157] Die sonstige Nummer der Eintragung ist dann und nur dann anzugeben, wenn die Eintragungsart "S" oder "X" angegeben wird.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:eintragungArt/code = ('S', 'X')) then exists(xga:eintragungOrt) else true()">
               <xsl:attribute name="id">SCH-0158</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0158] Wenn die Eintragungsart "S" oder "X" ist, muss der Ort der Eintragung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '170' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0106</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0106] Für die Rechtsform 170 "eingetragenes Einzelunternehmen (e.K.; e.Kfm.; e.Kfr.)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='180' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0107</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0107] Für die Rechtsform 180 "nicht eingetragenes Einzelunternehmen" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '210' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0108</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0108] Für die Rechtsform 210 "Offene Handelsgesellschaft (OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '211' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0109</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0109] Für die Rechtsform 211 "Kommanditgesellschaft auf Aktien &amp; Co. Offene Handelsgesellschaft (KGaA &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '220' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0110</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0110] Für die Rechtsform 220 "Kommanditgesellschaft (KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '221' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0111</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0111] Für die Rechtsform 221 "Stiftung &amp; Co. Kommanditgesellschaft (Stiftung &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '222' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0112</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0112] Für die Rechtsform 222 "eingetragene Genossenschaft &amp; Co. Kommanditgesellschaft (eG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '223' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0113</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0113] Für die Rechtsform 223 "Kommanditgesellschaft auf Aktien &amp; Co. Kommanditgesellschaft (KGaA &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '230' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0114</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0114] Für die Rechtsform 230 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft (GmbH &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '231' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0115</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0115] Für die Rechtsform 231 "Private Company Limited by Shares &amp; Co. Kommanditgesellschaft (Ltd &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '232' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0116</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0116] Für die Rechtsform 232 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.KG; auch UG (haftungsbeschränkt) &amp; Co.KG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '240' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0117</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0117] Für die Rechtsform 240 "Gesellschaft mit beschränkter Haftung &amp; Co. Offene Handelsgesellschaft (GmbH &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '241' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0118</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0118] Für die Rechtsform 241 "Private Company Limited by Shares &amp; Co. Offene Handelsgesellschaft (Ltd &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '242' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0119</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0119] Für die Rechtsform 242 "Unternehmergesellschaft (haftungsbeschränkt) &amp; Co.OHG; auch UG (haftungsbeschränkt) &amp;Co.OHG" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '250' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0120</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0120] Für die Rechtsform 250 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft (AG &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '251' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0121</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0121] Für die Rechtsform 251 "Europäische Aktiengesellschaft &amp; Co. KG (SE &amp; Co. KG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '260' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0122</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0122] Für die Rechtsform 260 "Aktiengesellschaft &amp; Co. Offene Handelsgesellschaft (AG &amp; Co. OHG)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='270' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0123</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0123] Für die Rechtsform 270 "Gesellschaft des bürgerlichen Rechts (GbR; BGB-Gesellschaft)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '280' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0124</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0124] Für die Rechtsform 280 "Europäische Wirtschaftliche Interessenvereinigung (EWIV)" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '290' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0125</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0125] Für die Rechtsform 290 "Sonstige nicht aufgeführte deutsche Personengesellschaft" darf nur die Eintragungsart "A" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '310' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0126</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0126] Für die Rechtsform 310 "Aktiengesellschaften (AG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '320' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0127</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0127] Für die Rechtsform 320 "Kommanditgesellschaft auf Aktien (KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '321' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0128</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0128] Für die Rechtsform 321 "Aktiengesellschaft &amp; Co. Kommanditgesellschaft auf Aktien (AG &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '322' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0129</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0129] Für die Rechtsform 322 "Gesellschaft mit beschränkter Haftung &amp; Co. Kommanditgesellschaft auf Aktien (GmbH &amp; Co. KGaA)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '323' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0130</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0130] Für die Rechtsform 323 "UG (haftungsbeschränkt) &amp; Co.KGaA" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '350' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0131</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0131] Für die Rechtsform 350 "Gesellschaft mit beschränkter Haftung (GmbH); auch gemeinnützige GmbH (gGmbH)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '351' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0132</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0132] Für die Rechtsform 351 "Unternehmergesellschaft (haftungsbeschränkt); auch UG (haftungsbeschränkt)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='355' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0133</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0133] Für die Rechtsform 355 "Gesellschaft mit beschränkter Haftung in Gründung (GmbH in Gründung; GmbH i.G.; auch gemeinnützige GmbH in Gründung (gGmbH i.G.)" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='356' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0134</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0134] Für die Rechtsform 356 "Unternehmergesellschaft (haftungsbeschränkt) in Gründung (UG (haftungsbeschränkt) in Gründung; UG (haftungsbeschränkt) i.G." darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '360' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0135</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0135] Für die Rechtsform 360 "Europäische Aktiengesellschaft (SE)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '400' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0136</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0136] Für die Rechtsform 400 "eingetragene Genossenschaft (eG)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '450' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'G' else true()">
               <xsl:attribute name="id">SCH-0137</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0137] Für die Rechtsform 450 "Europäische Genossenschaft (SCE)" darf nur die Eintragungsart "G" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '510' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'B' else true()">
               <xsl:attribute name="id">SCH-0138</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0138] Für die Rechtsform 510 "Versicherungsverein auf Gegenseitigkeit (VVaG)" darf nur die Eintragungsart "B" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '590' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'V' else true()">
               <xsl:attribute name="id">SCH-0139</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0139] Für die Rechtsform 590 "eingetragener Verein" darf nur die Eintragungsart "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code ='610' and not(ancestor::xga:ea.gewerbemeldung.0220)) then empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0140</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0140] Für die Rechtsform 610 "Nicht rechtsfähiger Verein" darf keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '611' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'S' or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0141</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0141] Für die Rechtsform 611 "rechtsfähige Stiftung" darf nur die Eintragungsart "S" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '700' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'B', 'G', 'V') else true()">
               <xsl:attribute name="id">SCH-0142</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0142] Für die Rechtsform 700 "Sonstige nicht aufgeführte deutsche Rechtsform – juristische Person" darf nur die Eintragungsart "A", "B", "G" oder "V" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '790' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = 'A' else true()">
               <xsl:attribute name="id">SCH-0143</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0143] Für die Rechtsform 790 "Sonstige Betriebe gewerblicher Art von Körperschaften des öffentlichen Rechts" darf nur die Eintragungsart "A" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '911' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'X') else true()">
               <xsl:attribute name="id">SCH-0144</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0144] Für die Rechtsform 911 "Private Company Limited by Shares (Ltd)" darf nur die Eintragungsart "B" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '912' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') else true()">
               <xsl:attribute name="id">SCH-0145</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0145] Für die Rechtsform 912 "Sonstige ausländische Rechtsform nach EU-Recht - juristische Person" darf nur die Eintragungsart "B", "G", "V" oder "X" eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '921' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0146</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0146] Für die Rechtsform 921 "ausländische Rechtsform nach EU-Recht - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '991' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('A', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0147</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0147] Für die Rechtsform 991 "Sonstige ausländische Rechtsform - natürliche Person und Personengesellschaften" darf nur die Eintragungsart "A", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:rechtsformSchluessel/code = '992' and not(ancestor::xga:ea.gewerbemeldung.0220)) then xga:eintragungArt/code = ('B', 'G', 'V', 'X') or empty(xga:eintragungArt) else true()">
               <xsl:attribute name="id">SCH-0148</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0148] Für die Rechtsform 992 "Sonstige ausländische Rechtsform - juristische Person" darf nur die Eintragungsart "B", "G", "V", "X" oder keine Eintragungsart eingetragen sein.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:erlaubnis"
                 priority="1012"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:erlaubnis"
                 priority="1011"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:erlaubnis"
                 priority="1010"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:erlaubnis"
                 priority="1009"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:erlaubnis"
                 priority="1008"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:erlaubnis"
                 priority="1007"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:erlaubnis"
                 priority="1006"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:erlaubnis"
                 priority="1005"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:erlaubnis"
                 priority="1004"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:erlaubnis"
                 priority="1003"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:erlaubnis"
                 priority="1002"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:erlaubnis"
                 priority="1001"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:erlaubnis"
                 priority="1000"
                 mode="M9">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0164</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0164] Bei An- und Ummeldung muss bei aktueller Erlaubnis ein Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if ((ancestor::xga:anmeldung or ancestor::xga:ummeldung) and xga:status/code = '1') then exists(xga:ausgestelltVonName) else true()">
               <xsl:attribute name="id">SCH-0169</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0169] Bei An- und Ummeldung muss bei aktueller Erlaubnis eine erteilende Behörde angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1025"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:erreichbarkeit"
                 priority="1024"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1023"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:erreichbarkeit"
                 priority="1022"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1021"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:erreichbarkeit"
                 priority="1020"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1019"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:erreichbarkeit"
                 priority="1018"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1017"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:erreichbarkeit"
                 priority="1016"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1015"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:erreichbarkeit"
                 priority="1014"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1013"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:erreichbarkeit"
                 priority="1012"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1011"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:erreichbarkeit"
                 priority="1010"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1009"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:erreichbarkeit"
                 priority="1008"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1007"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:erreichbarkeit"
                 priority="1006"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1005"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:erreichbarkeit"
                 priority="1004"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1003"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:erreichbarkeit"
                 priority="1002"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:nachrichtenkopf//xga:erreichbarkeit"
                 priority="1001"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:erreichbarkeit"
                 priority="1000"
                 mode="M10">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:kanal/code = ('01', '02', '03', '04', '09')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:kanal/code = ('01', '02', '03', '04', '09')">
               <xsl:attribute name="id">SCH-0172</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0172] Als Kommunikationskanäle sind nur Telefon Mobil, Telefon Festnetz, Telefax, E-Mail und Webseite zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(xga:kanal/code = preceding-sibling::xga:erreichbarkeit/xga:kanal/code)">
               <xsl:attribute name="id">SCH-0173</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0173] Im jeweiligen Kontext darf jeder Kommunikationskanal maximal einmal angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M10"/>
   <xsl:template match="@*|node()" priority="-2" mode="M10">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:gewerbe"
                 priority="1012"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:gewerbe"
                 priority="1011"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:gewerbe"
                 priority="1010"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:gewerbe"
                 priority="1009"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:gewerbe"
                 priority="1008"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:gewerbe"
                 priority="1007"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:gewerbe"
                 priority="1006"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:gewerbe"
                 priority="1005"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:gewerbe"
                 priority="1004"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:gewerbe"
                 priority="1003"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:gewerbe"
                 priority="1002"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:gewerbe"
                 priority="1001"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:gewerbe"
                 priority="1000"
                 mode="M11">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:niederlassungArt/code = ('2','3')) then exists(xga:hauptniederlassung) else true()">
               <xsl:attribute name="id">SCH-0006</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0006] Wenn es sich um eine Zweigniederlassung oder unselbstständige Zweigstelle handelt, muss die Hauptniederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0007</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0007] Wenn das Gewerbe kein Reisegewerbe ist, muss die Art der Niederlassung angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '0') then exists(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0008</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0008] Wenn das Gewerbe kein Reisegewerbe ist, muss die Anschrift der Betriebsstätte angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(xga:istNebenerwerb) or empty(xga:beteiligtePerson/xga:istNebenerwerb)">
               <xsl:attribute name="id">SCH-0089</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0089] Die Angabe, ob die Tätigkeit im Nebenerwerb ausgeführt wird, darf entweder nur auf Ebene des Gewerbes oder nur auf Ebene der am Gewerbe beteiligten Person angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then xga:betriebArt/(xga:handwerk|xga:handel|xga:sonstiges)/code = '1' else true()">
               <xsl:attribute name="id">SCH-0150</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0150] Wenn es sich um ein Reisegewerbe handelt, muss bei der Art des Betriebes entweder Handwerk, Handel oder Sonstiges angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:beteiligtePerson) or exists(xga:beteiligteFirma/xga:beteiligtePerson) or exists(xga:vertretungsberechtigtePerson) or ancestor::xga:sta.gewerbemeldung.0100 or ancestor::xga:rg.gewerbemeldung.0240">
               <xsl:attribute name="id">SCH-0159</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0159] Die Gewerbemeldung muss Angaben zu mindestens einer beteiligten oder vertretungsberechtigten Person enthalten.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:niederlassungArt) else true()">
               <xsl:attribute name="id">SCH-0174</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0174] Wenn das Gewerbe ein Reisegewerbe ist, darf die Art der Niederlassung nicht angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:istReisegewerbe/code = '1') then empty(xga:anschrift) else true()">
               <xsl:attribute name="id">SCH-0175</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0175] Wenn das Gewerbe ein Reisegewerbe ist, darf die Anschrift der Betriebsstätte nicht angegeben werden</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M11"/>
   <xsl:template match="@*|node()" priority="-2" mode="M11">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:abmeldung"
                 priority="1070"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:anmeldung"
                 priority="1069"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:ummeldung"
                 priority="1068"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:abmeldung"
                 priority="1067"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:anmeldung"
                 priority="1066"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:ummeldung"
                 priority="1065"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:abmeldung"
                 priority="1064"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:anmeldung"
                 priority="1063"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:ummeldung"
                 priority="1062"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:abmeldung"
                 priority="1061"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:anmeldung"
                 priority="1060"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:ummeldung"
                 priority="1059"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:abmeldung"
                 priority="1058"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:anmeldung"
                 priority="1057"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:ummeldung"
                 priority="1056"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:abmeldung"
                 priority="1055"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:anmeldung"
                 priority="1054"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:ummeldung"
                 priority="1053"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:abmeldung"
                 priority="1052"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:anmeldung"
                 priority="1051"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:ummeldung"
                 priority="1050"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:abmeldung"
                 priority="1049"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:anmeldung"
                 priority="1048"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:ummeldung"
                 priority="1047"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:abmeldung"
                 priority="1046"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:anmeldung"
                 priority="1045"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:ummeldung"
                 priority="1044"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz/xga:abmeldung"
                 priority="1043"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:abmeldung"
                 priority="1042"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:anmeldung"
                 priority="1041"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:ummeldung"
                 priority="1040"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz/xga:anmeldung"
                 priority="1039"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:abmeldung"
                 priority="1038"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:anmeldung"
                 priority="1037"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:ummeldung"
                 priority="1036"
                 mode="M12">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:korrekturGrundSchluessel) = ( xga:istKorrektur/code = '1' )">
               <xsl:attribute name="id">SCH-0004</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0004] Korrektur und Grund der Korrektur müssen gemeinsam angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:abmeldung/xga:autor"
                 priority="1034"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:anmeldung/xga:autor"
                 priority="1033"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:ummeldung/xga:autor"
                 priority="1032"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:abmeldung/xga:autor"
                 priority="1031"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:anmeldung/xga:autor"
                 priority="1030"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:ummeldung/xga:autor"
                 priority="1029"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:abmeldung/xga:autor"
                 priority="1028"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:anmeldung/xga:autor"
                 priority="1027"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:ummeldung/xga:autor"
                 priority="1026"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:abmeldung/xga:autor"
                 priority="1025"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:anmeldung/xga:autor"
                 priority="1024"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:ummeldung/xga:autor"
                 priority="1023"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:abmeldung/xga:autor"
                 priority="1022"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:anmeldung/xga:autor"
                 priority="1021"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:ummeldung/xga:autor"
                 priority="1020"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:abmeldung/xga:autor"
                 priority="1019"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:anmeldung/xga:autor"
                 priority="1018"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:ummeldung/xga:autor"
                 priority="1017"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:abmeldung/xga:autor"
                 priority="1016"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:anmeldung/xga:autor"
                 priority="1015"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:ummeldung/xga:autor"
                 priority="1014"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:abmeldung/xga:autor"
                 priority="1013"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:anmeldung/xga:autor"
                 priority="1012"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:ummeldung/xga:autor"
                 priority="1011"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:abmeldung/xga:autor"
                 priority="1010"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:anmeldung/xga:autor"
                 priority="1009"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:ummeldung/xga:autor"
                 priority="1008"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz/xga:abmeldung/xga:autor"
                 priority="1007"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:abmeldung/xga:autor"
                 priority="1006"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:anmeldung/xga:autor"
                 priority="1005"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:ummeldung/xga:autor"
                 priority="1004"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz/xga:anmeldung/xga:autor"
                 priority="1003"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:abmeldung/xga:autor"
                 priority="1002"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:anmeldung/xga:autor"
                 priority="1001"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:ummeldung/xga:autor"
                 priority="1000"
                 mode="M12">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and&#xA;       xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and&#xA;       xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID )&#xA;else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:praefix/code = 'MELDID') then ( xga:behoerdenkennung/xga:kennung/code = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/code and xga:behoerdenkennung/xga:kennung/@listURI = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listURI and xga:behoerdenkennung/xga:kennung/@listVersionID = preceding::xga:nachrichtenkopf/xga:autor/xga:behoerdenkennung/xga:kennung/@listVersionID ) else true()">
               <xsl:attribute name="id">SCH-0076</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0076] Falls der Autor der Nachricht die Gewerbebehörde einer Gemeinde ist (Präfix MELDID), so muss die Behördenkennung des Autors auf Satzebene mit der des Autors der Nachricht übereinstimmen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:handwerkskarte"
                 priority="1012"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:handwerkskarte"
                 priority="1011"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:handwerkskarte"
                 priority="1010"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:handwerkskarte"
                 priority="1009"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:handwerkskarte"
                 priority="1008"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:handwerkskarte"
                 priority="1007"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:handwerkskarte"
                 priority="1006"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:handwerkskarte"
                 priority="1005"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:handwerkskarte"
                 priority="1004"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:handwerkskarte"
                 priority="1003"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:handwerkskarte"
                 priority="1002"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:handwerkskarte"
                 priority="1001"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:handwerkskarte"
                 priority="1000"
                 mode="M13">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltAm) else true()">
               <xsl:attribute name="id">SCH-0009</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0009] Wenn die Handwerkskarte vorliegt, muss das Ausstellungsdatum angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:status/code = '1') then exists(xga:ausgestelltVonSchluessel) else true()">
               <xsl:attribute name="id">SCH-0160</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0160] Bei einer vorliegenden aktuellen Handwerkskarte ist der Schlüssel der Handwerkskammer anzugeben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:schwerpunkt"
                 priority="1012"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:schwerpunkt"
                 priority="1011"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:schwerpunkt"
                 priority="1010"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:schwerpunkt"
                 priority="1009"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:schwerpunkt"
                 priority="1008"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:schwerpunkt"
                 priority="1007"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:schwerpunkt"
                 priority="1006"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:schwerpunkt"
                 priority="1005"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:schwerpunkt"
                 priority="1004"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:schwerpunkt"
                 priority="1003"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:schwerpunkt"
                 priority="1002"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:schwerpunkt"
                 priority="1001"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:schwerpunkt"
                 priority="1000"
                 mode="M14">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:ummeldung) then exists(xga:neuAusgeuebt) else empty(xga:neuAusgeuebt)">
               <xsl:attribute name="id">SCH-0001</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0001] Im Falle einer Ummeldung muss angegeben werden, ob ein Schwerpunkt neu ausgeübt wurde. Bei An- und Abmeldungen ist die Angabe unzulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:staatangehoerigkeiten"
                 priority="1012"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:staatangehoerigkeiten"
                 priority="1011"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:staatangehoerigkeiten"
                 priority="1010"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:staatangehoerigkeiten"
                 priority="1009"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:staatangehoerigkeiten"
                 priority="1008"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:staatangehoerigkeiten"
                 priority="1007"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:staatangehoerigkeiten"
                 priority="1006"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:staatangehoerigkeiten"
                 priority="1005"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:staatangehoerigkeiten"
                 priority="1004"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:staatangehoerigkeiten"
                 priority="1003"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:staatangehoerigkeiten"
                 priority="1002"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:staatangehoerigkeiten"
                 priority="1001"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:staatangehoerigkeiten"
                 priority="1000"
                 mode="M15">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:staatsangehoerigkeitSchluessel) or exists(xga:staatsangehoerigkeit)">
               <xsl:attribute name="id">SCH-0011</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0011] Die Staatsangehörigkeit muss als Text und/oder Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1012"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1011"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1010"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1009"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1008"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1007"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1006"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1005"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1004"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1003"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1002"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1001"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:taetigkeitenGesamt/xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1000"
                 mode="M16">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="ancestor::xga:ummeldung"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="ancestor::xga:ummeldung">
               <xsl:attribute name="id">SCH-0088</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0088] Das Kindelement weitereNeuAusgeuebteTaetigkeiten darf nur bei Ummeldungen angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M16"/>
   <xsl:template match="@*|node()" priority="-2" mode="M16">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1022"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1021"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1020"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1019"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1018"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1017"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1016"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1015"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1014"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1013"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:ummeldung/xga:anlaesseUmmeldung"
                 priority="1012"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="preceding-sibling::xga:gruendeUmmeldung/xga:grundUmmeldungSchluessel/code = '99'">
               <xsl:attribute name="id">SCH-0149</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0149] Anlässe für die Ummeldung dürfen nur mitgeteilt werden, wenn als Grund der Ummeldung "Sonstige" (99) enthalten ist.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:ummeldung"
                 priority="1010"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:ummeldung"
                 priority="1009"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:ummeldung"
                 priority="1008"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:ummeldung"
                 priority="1007"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:ummeldung"
                 priority="1006"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:ummeldung"
                 priority="1005"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:ummeldung"
                 priority="1004"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:ummeldung"
                 priority="1003"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:ummeldung"
                 priority="1002"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:ummeldung"
                 priority="1001"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:ummeldung"
                 priority="1000"
                 mode="M17">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (ancestor::xga:alg.gewerbemeldung.0300) then true() else count(xga:frueheresGewerbe) le 1">
               <xsl:attribute name="id">SCH-0171</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0171] Die Übermittlung mehrerer früherer Gewerbe ist nur im allgemeinen Datensatz zulässig.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M17"/>
   <xsl:template match="@*|node()" priority="-2" mode="M17">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1012"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1011"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1010"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1009"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1008"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1007"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1006"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1005"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1004"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1003"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1002"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1001"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:weitereNeuAusgeuebteTaetigkeiten"
                 priority="1000"
                 mode="M18">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test=" if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0166</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0166] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M18"/>
   <xsl:template match="@*|node()" priority="-2" mode="M18">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz//xga:weitereTaetigkeiten"
                 priority="1012"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz//xga:weitereTaetigkeiten"
                 priority="1011"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz//xga:weitereTaetigkeiten"
                 priority="1010"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz//xga:weitereTaetigkeiten"
                 priority="1009"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz//xga:weitereTaetigkeiten"
                 priority="1008"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz//xga:weitereTaetigkeiten"
                 priority="1007"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz//xga:weitereTaetigkeiten"
                 priority="1006"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz//xga:weitereTaetigkeiten"
                 priority="1005"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz//xga:weitereTaetigkeiten"
                 priority="1004"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz//xga:weitereTaetigkeiten"
                 priority="1003"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz//xga:weitereTaetigkeiten"
                 priority="1002"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz//xga:weitereTaetigkeiten"
                 priority="1001"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz//xga:weitereTaetigkeiten"
                 priority="1000"
                 mode="M19">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (exists(xga:taetigkeit/xga:taetigkeitEinzeln)) then xga:taetigkeitenZusammengefasst = string-join(xga:taetigkeit/xga:taetigkeitEinzeln, '|') else true()">
               <xsl:attribute name="id">SCH-0165</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0165] Wenn weitere Tätigkeitstexte mittels taetigkeitEinzeln als separate Angaben übermittelt werden, ist die Zusammenfassung durch Konkatenation aus ebendiesen zu bilden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M19"/>
   <xsl:template match="@*|node()" priority="-2" mode="M19">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:anmeldung"
                 priority="1004"
                 mode="M20">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0038</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0038] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '01') then empty(xga:bisherigeUnfallversicherung) else exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '01') then empty(xga:bisherigeUnfallversicherung) else exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0097</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0097] Es sind bei allen Anmeldegründen stets Angaben zur bisherigen Unfallversicherung mitzuteilen. Ausnahme: Bei einer Neugründung dürfen diese nicht mitgeteilt werden..</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:abmeldung"
                 priority="1002"
                 mode="M20">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0039</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0039] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">SCH-0040</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0040] Die Ursache der Abmeldung muss mitgeteilt werden. Dies kann entweder als Freitext oder mittels mindestens einem Schlüssel erfolgen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0099</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0099] Bei einer Abmeldung sind Angaben zur bisherigen Unfallversicherung mitzuteilen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:alg.gewerbemeldung.0300/xga:satz/xga:ummeldung"
                 priority="1000"
                 mode="M20">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0098</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0098] Bei einer Ummeldung sind Angaben zur bisherigen Unfallversicherung mitzuteilen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M20"/>
   <xsl:template match="@*|node()" priority="-2" mode="M20">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M21">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0034</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0034] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M21">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0035</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0035] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M21"/>
   <xsl:template match="@*|node()" priority="-2" mode="M21">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:anmeldung"
                 priority="1004"
                 mode="M22">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0022</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0022] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '01') then empty(xga:bisherigeUnfallversicherung) else exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '01') then empty(xga:bisherigeUnfallversicherung) else exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0094</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0094] Bei allen Anmeldegründen außer der Neugründung sind Angaben zur bisherigen Unfallversicherung mitzuteilen. Bei einer Neugründung dürfen diese Angaben nicht mitgeteilt werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:abmeldung"
                 priority="1002"
                 mode="M22">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0023</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0023] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">SCH-0024</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0024] Die Ursache der Abmeldung muss als Freitext oder mit mindestens einem Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0096</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0096] Bei einer Abmeldung sind Angaben zur bisherigen Unfallversicherung mitzuteilen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:satz/xga:ummeldung"
                 priority="1000"
                 mode="M22">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0095</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0095] Bei einer Ummeldung sind Angaben zur bisherigen Unfallversicherung mitzuteilen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M22"/>
   <xsl:template match="@*|node()" priority="-2" mode="M22">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M23">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">SCH-0078</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0078] Bei einer Anmeldung müssen Tätigkeiten angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M23">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="exists(xga:taetigkeitenGesamt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:taetigkeitenGesamt)">
               <xsl:attribute name="id">SCH-0079</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0079] Bei einer Abmeldung müssen Tätigkeiten angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M23"/>
   <xsl:template match="@*|node()" priority="-2" mode="M23">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:anmeldung"
                 priority="1004"
                 mode="M24">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0091</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0091] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="if (xga:grundAnmeldungSchluessel/code = '01') then empty(xga:bisherigeUnfallversicherung) else exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="if (xga:grundAnmeldungSchluessel/code = '01') then empty(xga:bisherigeUnfallversicherung) else exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0100</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0100] Bei allen Anmeldegründen außer der Neugründung sind Angaben zur bisherigen Unfallversicherung mitzuteilen. Bei einer Neugründung dürfen diese Angaben nicht mitgeteilt werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:abmeldung"
                 priority="1002"
                 mode="M24">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0093</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0093] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">SCH-0092</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0092] Die Ursache der Abmeldung muss als Freitext oder mit mindestens einem Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0102</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0102] Bei einer Abmeldung sind Angaben zur bisherigen Unfallversicherung mitzuteilen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ext.gewerbemeldung.0400/xga:satz/xga:ummeldung"
                 priority="1000"
                 mode="M24">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:bisherigeUnfallversicherung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:bisherigeUnfallversicherung)">
               <xsl:attribute name="id">SCH-0101</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0101] Bei einer Ummeldung sind Angaben zur bisherigen Unfallversicherung mitzuteilen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M24"/>
   <xsl:template match="@*|node()" priority="-2" mode="M24">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M25">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0028</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0028] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M25">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">SCH-0029</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0029] Die Ursache der Abmeldung muss mitgeteilt werden. Dies kann entweder als Freitext oder mittels mindestens einem Schlüssel erfolgen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0030</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0030] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M25"/>
   <xsl:template match="@*|node()" priority="-2" mode="M25">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M26">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0019</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0019] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M26">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0020</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0020] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">SCH-0021</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0021] Die Ursache der Abmeldung muss mitgeteilt werden. Dies kann entweder als Freitext oder mittels mindestens einem Schlüssel erfolgen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M26"/>
   <xsl:template match="@*|node()" priority="-2" mode="M26">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M27">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0016</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0016] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M27">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0017</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0017] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">SCH-0018</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0018] Die Ursache der Abmeldung muss mitgeteilt werden. Dies kann entweder als Freitext oder mittels mindestens einem Schlüssel erfolgen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M27"/>
   <xsl:template match="@*|node()" priority="-2" mode="M27">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M28">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0032</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0032] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M28">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0033</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0033] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M28"/>
   <xsl:template match="@*|node()" priority="-2" mode="M28">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M29">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0036</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0036] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M29">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0037</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0037] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M29"/>
   <xsl:template match="@*|node()" priority="-2" mode="M29">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M30">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betrieb/xga:eintragungArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betrieb/xga:eintragungArt)">
               <xsl:attribute name="id">SCH-0026</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0026] Die Art der Eintragung muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="xga:gewerbe/xga:betrieb/xga:eintragungArt/code = ('A','B','G')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:gewerbe/xga:betrieb/xga:eintragungArt/code = ('A','B','G')">
               <xsl:attribute name="id">SCH-0027</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0027] Zulässige Arten der Eintragung sind die  Schlüssel "A" (für Handelsregister A), "B" (für Handelsregister B)  sowie "G" (für Genossenschftsregister).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M30"/>
   <xsl:template match="@*|node()" priority="-2" mode="M30">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M31">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0013</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0013] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:satz/xga:abmeldung"
                 priority="1000"
                 mode="M31">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0014</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0014] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:ursacheAbmeldungSchluessel) or exists(xga:ursacheAbmeldung)">
               <xsl:attribute name="id">SCH-0015</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0015] Die Ursache der Abmeldung muss als Freitext oder mit mindestens einem Schlüssel angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M31"/>
   <xsl:template match="@*|node()" priority="-2" mode="M31">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz/xga:anmeldung"
                 priority="1002"
                 mode="M32">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(xga:gewerbe/xga:betriebArt)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(xga:gewerbe/xga:betriebArt)">
               <xsl:attribute name="id">SCH-0031</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0031] Die Art des Betriebs muss angegeben werden.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:satz/*/xga:gewerbe"
                 priority="1000"
                 mode="M32">

		<!--ASSERT fachlich-->
      <xsl:choose>
         <xsl:when test="exists(.//xga:anschrift)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(.//xga:anschrift)">
               <xsl:attribute name="id">SCH-0167</xsl:attribute>
               <xsl:attribute name="role">fachlich</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0167] In der Anmeldung muss mindestens eine Anschrift vorhanden sein (zu der Betriebsstätte,  der Hauptniederlassung, einer beteiligten Person oder einer beteiligten Firma).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M32"/>
   <xsl:template match="@*|node()" priority="-2" mode="M32">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M33">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0041</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0041] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:as.gewerbemeldung.0280/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M33">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0042</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0042] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M33"/>
   <xsl:template match="@*|node()" priority="-2" mode="M33">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M34">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0046</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0046] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:dgu.gewerbemeldung.0230/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M34">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0047</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0047] Die Behördenkennung des Lesers muss das Präfix ags haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M34"/>
   <xsl:template match="@*|node()" priority="-2" mode="M34">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M35">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0049</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0049] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ea.gewerbemeldung.0220/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M35">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0050</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0050] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M35"/>
   <xsl:template match="@*|node()" priority="-2" mode="M35">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M36">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0052</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0052] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:fa.gewerbemeldung.0250/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M36">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0053</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0053] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M36"/>
   <xsl:template match="@*|node()" priority="-2" mode="M36">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M37">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0055</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0055] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:hwk.gewerbemeldung.0210/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M37">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0056</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0056] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M37"/>
   <xsl:template match="@*|node()" priority="-2" mode="M37">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M38">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0058</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0058] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:ihk.gewerbemeldung.0200/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M38">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0059</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0059] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M38"/>
   <xsl:template match="@*|node()" priority="-2" mode="M38">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M39">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0061</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0061] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:is.gewerbemeldung.0270/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M39">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0062</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0062] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M39"/>
   <xsl:template match="@*|node()" priority="-2" mode="M39">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M40">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0064</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0064] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:lue.gewerbemeldung.0290/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M40">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0065</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0065] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M40"/>
   <xsl:template match="@*|node()" priority="-2" mode="M40">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M41">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0067</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0067] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:rg.gewerbemeldung.0240/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M41">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0068</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0068] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M41"/>
   <xsl:template match="@*|node()" priority="-2" mode="M41">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M42">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0073</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0073] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:sta.gewerbemeldung.0100/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M42">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0074</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0074] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M42"/>
   <xsl:template match="@*|node()" priority="-2" mode="M42">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>

   <!--PATTERN -->


	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:nachrichtenkopf/xga:autor"
                 priority="1002"
                 mode="M43">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung[xga:praefix/code = ('MELDID', 'xga')]">
               <xsl:attribute name="id">SCH-0070</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0070] Die Behördenkennung des Autors muss das Präfix MELDID oder xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="xga:zv.gewerbemeldung.0260/xga:nachrichtenkopf/xga:leser"
                 priority="1000"
                 mode="M43">

		<!--ASSERT technisch-->
      <xsl:choose>
         <xsl:when test="xga:behoerdenkennung/xga:praefix/code = 'xga'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xga:behoerdenkennung/xga:praefix/code = 'xga'">
               <xsl:attribute name="id">SCH-0071</xsl:attribute>
               <xsl:attribute name="role">technisch</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>[SCH-0071] Die Behördenkennung des Lesers muss das Präfix xga haben.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
</xsl:stylesheet>
